<?php
/*
  ##############################################################################
  # Plugin for Shopware
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # @version $Id: Bootstrap.php 5796 2015-04-16 11:43:29Z s.thamm $
  # @copyright:   found in /lic/copyright.txt
  #
  ##############################################################################
 */


/**
 * development debug function
 */
if(!function_exists('__d'))
{
    function __d($o, $msg = null)
    {

        $filename = dirname(__FILE__) . '/debug.txt';

        // damit die datei nicht zu gross wird
        $filesize = round(filesize($filename) / (1024 * 1024), 2); // MB

        if($filesize >= 50)
        {
            @unlink($filename);
        }
        ////

        $f = fopen($filename, 'a+');

        if($msg)
        {
            fwrite($f, "$msg:\n");
        }

        fwrite($f, print_r($o, true));
        fwrite($f, "\n\n\n");
        fclose($f);
    }
}

/**
 * development debug function
 */
if(!function_exists('__debug'))
{
    function __debug($msg)
    {
        echo "<pre>";
        print_r($msg);
        echo "</pre>";
        echo "<hr />";
    }

}


/**
 * Standard Shopware Plugin Class
 */
class Shopware_Plugins_Backend_viaebay_Bootstrap extends Shopware_Components_Plugin_Bootstrap
{
    /**
     * register plugin namespaces
     */
    public function registerNamespace()
    {
        static $done = false;

        if(!$done)
        {
            $done = true;

            Shopware()->Loader()->registerNamespace('Shopware', dirname(__FILE__) . '/');
            Shopware()->Loader()->registerNamespace('Shopware\CustomModels', dirname(__FILE__) . '/Models/');
        }
    }

    
    /**
     * register components for any controllers and modules
     * @return
     */
    protected function registerComponents()
    {
        // Add snippet directory
        $this->Application()->Template()->addTemplateDir($this->Path() . 'Views/');
        //$this->Application()->Snippets()->addConfigDir($this->Path() . 'Snippets/');
    }

    
    /**
     * Plugin install method
     */
    public function install()
    {
        $this->checkLicense();

        if(!$this->assertVersionGreaterThen("4.0.0"))
        {
            throw new Enlight_Exception("This Plugin needs min shopware 4.0.0");
        }


        $plugin_switch = false;

        if($this->assertRequiredPluginsPresent(array('SwpVIAeBay')))
        {
            $sql = 'SELECT version FROM s_core_plugins WHERE name = ? AND active = 1';
            $test = Shopware()->Db()->fetchOne($sql, array('SwpVIAeBay'));
            
            if(!empty($test) && (!in_array($test, array('5.01.16', '5.01.17'))))
            {
                throw new Enlight_Exception("Plugin kann nicht installiert werden, da es bereits als 'SwpVIAeBay' installiert ist und dieses nicht mindestens die Version '5.01.16' hat");
            }
            else
            {
                $plugin_switch = true;
            }
        }
       
        
        $this->createTranslations();
        $this->subscribeEvents();


        if(!$plugin_switch)
        {
            $this->createForm();
            $this->createTables();
            $this->createPartnerEntry();
            //$this->createCronjobs(); // mit der 4.02.15 wurde die cronjobs aus der shopware-cronjob-logik geloest
        }
        else
        {
            try
            {
                $this->createFormUpdate();

                $plugin = Shopware()->Models()->getRepository('Shopware\Models\Plugin\Plugin')->findOneBy(['name' => 'SwpVIAeBay']);

                $result = $this->get('shopware_plugininstaller.plugin_manager')->uninstallPlugin($plugin);

                // throw new Enlight_Exception("Plugin 'SwpVIAeBay' wurde deinstalliert");
                // notwendig da shopware die alten eintraege loescht und diese aber noch benoetigt werden
                // mit der 4.02.15 wurde die cronjobs aus der shopware-cronjob-logik geloest
                // $this->createCronjobs();

                return $result;
            }
            catch(Exception $ex)
            {
                throw new Enlight_Exception("Fehler Beim Wechsel von Plugin 'SwpVIAeBay' auf 'viaebay': " . $ex->getMessage());
            }
        }


        return array('success' => true, 'invalidateCache' => array('frontend', 'backend', 'proxy'));
    }

    
    /**
     * Plugin update method
     */
    public function update($oldVersion)
    {
        switch($oldVersion)
        {
            case '5.02.00':
            case '5.02.01':
            case '5.02.02':
            case '5.02.03':
            case '5.02.04':
            case '5.02.05':
            case '5.02.06':
            case '5.02.07':
            case '5.02.08':

                if($dispatchId = Shopware()->Db()->fetchOne('SELECT id FROM `s_premium_dispatch` WHERE name="Versand"'))
                {
                    Shopware()->Db()->exec('UPDATE `s_premium_dispatch` SET `name` = "ebay" WHERE id = ' . $dispatchId);
                }

                if(!Shopware()->Db()->fetchOne('SELECT id FROM `s_premium_dispatch` WHERE name="ebayPLUS"'))
                {
                    Shopware()->Db()->exec('INSERT INTO `s_premium_dispatch` (`name`, `type`, `description`, `comment`, `active`, `position`, `calculation`, `surcharge_calculation`, `tax_calculation`, `bind_shippingfree`, `bind_laststock`) VALUES ("ebayPLUS", "0", "VIA eBay Versandart", "VIA eBay Versandart", "0", "0", "1", "3", "0", "0", "0")');
                }


                $config = Shopware()->Plugins()->Backend()->viaebay()->Config();

                $form = $this->Form();

                $form->setElement('select', 'paymentcompletestatus', array
                (
                    'label' => 'Zahlungsstatus für "Als bezahlt" markierte Bestellungen',
                    'description' => '',
                    'required' => true,
                    'multiSelect' => false,
                    'editable' => false,
                    'value' => $config->paymentcompletestatus,
                    'valueField' => 'id',
                    'displayField' => 'description',
                    'store' => 'base.PaymentStatus',
                    'scope' => Shopware_Components_Form::SCOPE_SHOP
                ));

                $form->setElement('select', 'shippingcompletestatus', array
                (
                    'label' => 'Bestellstatus für "Als versendet" markierte Bestellungen',
                    'description' => '',
                    'required' => true,
                    'multiSelect' => false,
                    'editable' => false,
                    'value' => $config->shippingcompletestatus,
                    'valueField' => 'id',
                    'displayField' => 'description',
                    'store' => 'base.OrderStatus',
                    'scope' => Shopware_Components_Form::SCOPE_SHOP
                ));

                $form->setElement('select', 'shipping_de', array
                (
                    'label' => 'Versandart DE',
                    'description' => '',
                    'required' => true,
                    'multiSelect' => false,
                    'editable' => false,
                    'value' => $config->shipping_de,
                    'valueField' => 'id',
                    'displayField' => 'name',
                    'store' => 'base.Dispatch',
                    'scope' => Shopware_Components_Form::SCOPE_SHOP
                ));

                $form->setElement('select', 'shipping_international', array
                (
                    'label' => 'Versandart sonstige Länder',
                    'description' => '',
                    'required' => true,
                    'multiSelect' => false,
                    'editable' => false,
                    'value' => $config->shipping_international,
                    'valueField' => 'id',
                    'displayField' => 'name',
                    'store' => 'base.Dispatch',
                    'scope' => Shopware_Components_Form::SCOPE_SHOP
                ));

                $form->setElement('boolean', 'zeroqty', array('label' => 'Deaktivierte Artikel mit Menge "0" übertragen', 'required' => true, 'value' => true, 'scope' => Shopware_Components_Form::SCOPE_SHOP));
                $form->save();

                $translations = array(
                    'en_GB' => array(
                        'zeroqty' => 'Deaktivierte Artikel mit Menge "0" übertragen',
                    )
                );

                $shopRepository = Shopware()->Models()->getRepository('\Shopware\Models\Shop\Locale');

                foreach($translations as $locale => $snippets)
                {
                    $localeModel = $shopRepository->findOneBy(array('locale' => $locale));

                    foreach($snippets as $element => $snippet)
                    {
                        if($localeModel === null)
                            continue;

                        $elementModel = $form->getElement($element);

                        if($elementModel === null)
                            continue;

                        $translationModel = new \Shopware\Models\Config\ElementTranslation();
                        $translationModel->setLabel($snippet);
                        $translationModel->setLocale($localeModel);
                        $elementModel->addTranslation($translationModel);
                    }
                }

            case '5.02.09':

                Shopware()->Models()->addAttribute('s_order_attributes', 'swp_viaebay', 'payment_option', 'TEXT', true, null);
                $this->Application()->Models()->generateAttributeModels(array(
                    's_order_attributes'
                ));


                $config = Shopware()->Plugins()->Backend()->viaebay()->Config();

                $form = $this->Form();

                $form->setElement('select', 'paymentcashcompletestatus', array
                (
                    'label' => 'Zahlungsstatus bei "Bar bei Abholung" für "Als bezahlt" markierte Bestellungen',
                    'description' => '',
                    'required' => true,
                    'multiSelect' => false,
                    'editable' => false,
                    'value' => $config->paymentcompletestatus,
                    'valueField' => 'id',
                    'displayField' => 'description',
                    'store' => 'base.PaymentStatus',
                    'scope' => Shopware_Components_Form::SCOPE_SHOP
                ));

                $form->setElement('select', 'paymentcodcompletestatus', array
                (
                    'label' => 'Zahlungsstatus bei "Nachnahme" für "Als bezahlt" markierte Bestellungen',
                    'description' => '',
                    'required' => true,
                    'multiSelect' => false,
                    'editable' => false,
                    'value' => $config->paymentcompletestatus,
                    'valueField' => 'id',
                    'displayField' => 'description',
                    'store' => 'base.PaymentStatus',
                    'scope' => Shopware_Components_Form::SCOPE_SHOP
                ));

                $form->setElement('select', 'paymentmoneyxcompletestatus', array
                (
                    'label' => 'Zahlungsstatus bei "Vorkasse / Überweisung" für "Als bezahlt" markierte Bestellungen',
                    'description' => '',
                    'required' => true,
                    'multiSelect' => false,
                    'editable' => false,
                    'value' => $config->paymentcompletestatus,
                    'valueField' => 'id',
                    'displayField' => 'description',
                    'store' => 'base.PaymentStatus',
                    'scope' => Shopware_Components_Form::SCOPE_SHOP
                ));

                $form->setElement('select', 'paymentpaypalcompletestatus', array
                (
                    'label' => 'Zahlungsstatus bei "PayPal" für "Als bezahlt" markierte Bestellungen',
                    'description' => '',
                    'required' => true,
                    'multiSelect' => false,
                    'editable' => false,
                    'value' => $config->paymentcompletestatus,
                    'valueField' => 'id',
                    'displayField' => 'description',
                    'store' => 'base.PaymentStatus',
                    'scope' => Shopware_Components_Form::SCOPE_SHOP
                ));

                $form->save();

                $translations = array(
                    'en_GB' => array(
                        'paymentcashcompletestatus' => 'Payment Status with "Cash on Pickup" for "Marked as Payed" Orders',
                        'paymentcodcompletestatus' => 'Payment Status with "Cash on Delivery" for "Marked as Payed" Orders',
                        'paymentmoneyxcompletestatus' => 'Payment Status with "PrePayment / Bank Transfer" for "Marked as Payed" Orders',
                        'paymentpaypalcompletestatus' => 'Payment Status with "PayPal" for "Marked as Payed" Orders',
                    )
                );

                $shopRepository = Shopware()->Models()->getRepository('\Shopware\Models\Shop\Locale');

                foreach($translations as $locale => $snippets)
                {
                    $localeModel = $shopRepository->findOneBy(array('locale' => $locale));

                    foreach($snippets as $element => $snippet)
                    {
                        if($localeModel === null)
                            continue;

                        $elementModel = $form->getElement($element);

                        if($elementModel === null)
                            continue;

                        $translationModel = new \Shopware\Models\Config\ElementTranslation();
                        $translationModel->setLabel($snippet);
                        $translationModel->setLocale($localeModel);
                        $elementModel->addTranslation($translationModel);
                    }
                }

            case '5.02.10':

                $form = $this->Form();

                $form->setElement('text', 'countpropertyvalues', array
                (
                    'label' => 'Anzahl der übertragenen Eigenschaften',
                    'required' => true,
                    'value' => '22',
                    'scope' => \Shopware\Models\Config\Element::SCOPE_SHOP
                ));

                $form->save();

                $translations = array(
                    'en_GB' => array(
                        'countpropertyvalues' => 'Anzahl der übertragenen Eigenschaften',
                    )
                );

                $shopRepository = Shopware()->Models()->getRepository('\Shopware\Models\Shop\Locale');

                foreach($translations as $locale => $snippets)
                {
                    $localeModel = $shopRepository->findOneBy(array('locale' => $locale));

                    foreach($snippets as $element => $snippet)
                    {
                        if($localeModel === null)
                            continue;

                        $elementModel = $form->getElement($element);

                        if($elementModel === null)
                            continue;

                        $translationModel = new \Shopware\Models\Config\ElementTranslation();
                        $translationModel->setLabel($snippet);
                        $translationModel->setLocale($localeModel);
                        $elementModel->addTranslation($translationModel);
                    }
                }

            case '5.02.11':
            case '5.02.12':
            case '5.02.13':


                // neu logik fuer attribute seit sw 5.2.2
                if($this->assertVersionGreaterThen("5.2.2"))
                {
                    $service = $this->get('shopware_attribute.crud_service');
                    
                    $service->update('s_articles_attributes', 'swp_viaebay_container_id', 'integer', [
                        'label' => 'VIA-Connect Container ID',
                        'translatable' => false,
                        'displayInBackend' => false,
                        'custom' => false,
                    ]);                    
                    $service->update('s_articles_attributes', 'swp_viaebay_id', 'integer', [
                        'label' => 'VIA-Connect ID',
                        'translatable' => false,
                        'displayInBackend' => false,
                        'custom' => false,
                    ]);
                    
                    $service->update('s_categories_attributes', 'swp_viaebay_id', 'integer', [
                        'label' => 'VIA-Connect ID',
                        'translatable' => false,
                        'displayInBackend' => false,
                        'custom' => false,
                    ]);
                    
                    $service->update('s_order_attributes', 'swp_viaebay_id', 'integer', [
                        'label' => 'VIA-Connect ID',
                        'translatable' => false,
                        'displayInBackend' => false,
                        'custom' => false,
                    ]);
                    $service->update('s_order_attributes', 'swp_viaebay_byer_package_enclosure', 'string', [
                        'label' => 'BuyerPackageEnclosure',
                        'translatable' => false,
                        'displayInBackend' => false,
                        'custom' => false,
                    ]);
                    $service->update('s_order_attributes', 'swp_viaebay_carrier_used', 'string', [
                        'label' => 'VIAeBay - Versanddienstleister',
                        'translatable' => false,
                        'displayInBackend' => true,
                        'custom' => false,
                    ]);
                    $service->update('s_order_attributes', 'swp_viaebay_payment_option', 'string', [
                        'label' => 'PaymentOption',
                        'translatable' => false,
                        'displayInBackend' => false,
                        'custom' => false,
                    ]);
                    
                    $service->update('s_order_details_attributes', 'swp_viaebay_id', 'integer', [
                        'label' => 'VIA-Connect ID',
                        'translatable' => false,
                        'displayInBackend' => false,
                        'custom' => false,
                    ]);
                    
                    $service->update('s_order_billingaddress_attributes', 'swp_viaebay_id', 'integer', [
                        'label' => 'VIA-Connect ID',
                        'translatable' => false,
                        'displayInBackend' => false,
                        'custom' => false,
                    ]);
                    
                    $service->update('s_order_shippingaddress_attributes', 'swp_viaebay_id', 'integer', [
                        'label' => 'VIA-Connect ID',
                        'translatable' => false,
                        'displayInBackend' => false,
                        'custom' => false,
                    ]);
                }

             
            case '5.02.14':
                
                $form = $this->Form();

                $form->setElement('text', 'cronjoblimitorders', array
                (
                    'label' => 'Cronjobs (Bestellungen) Schrittweite',
                    'required' => true,
                    'value' => '50',
                    'scope' => \Shopware\Models\Config\Element::SCOPE_SHOP
                ));
                
                $form->setElement('text', 'cronjoblimitarticles', array
                (
                    'label' => 'Cronjobs (Artikel) Schrittweite',
                    'required' => true,
                    'value' => '25',
                    'scope' => \Shopware\Models\Config\Element::SCOPE_SHOP
                ));
                
                $form->setElement('text', 'cronjobpass', array
                (
                    'label' => 'Cronjobs Passwort',
                    'required' => true,
                    'value' => md5(rand()),
                    'scope' => \Shopware\Models\Config\Element::SCOPE_SHOP
                ));

                $form->save();

                $translations = array(
                    'en_GB' => array(
                        'cronjoblimitorders' => 'Cronjobs (Bestellungen) Schrittweite',
                        'cronjoblimitarticles' => 'Cronjobs (Artikel) Schrittweite',
                        'cronjobpass' => 'Cronjobs Passwort',
                    )
                );

                $shopRepository = Shopware()->Models()->getRepository('\Shopware\Models\Shop\Locale');

                foreach($translations as $locale => $snippets)
                {
                    $localeModel = $shopRepository->findOneBy(array('locale' => $locale));

                    foreach($snippets as $element => $snippet)
                    {
                        if($localeModel === null)
                            continue;

                        $elementModel = $form->getElement($element);

                        if($elementModel === null)
                            continue;

                        $translationModel = new \Shopware\Models\Config\ElementTranslation();
                        $translationModel->setLabel($snippet);
                        $translationModel->setLocale($localeModel);
                        $elementModel->addTranslation($translationModel);
                    }
                }
                
                $sql = "UPDATE s_crontab SET active = 0 WHERE action LIKE 'SwpVIAeBay%'";
                Shopware()->Db()->query($sql);
            
            case '5.02.15':
                
                $form = $this->Form();

                $form->setElement('button', 'button5', array
                (
                    'label' => '<b>Cronjobs</b>',
                    'value' => '',
                ));                

                $form->save();

                $translations = array(
                    'en_GB' => array(
                        'button5' => '<b>Cronjobs</b>',
                    )
                );

                $shopRepository = Shopware()->Models()->getRepository('\Shopware\Models\Shop\Locale');

                foreach($translations as $locale => $snippets)
                {
                    $localeModel = $shopRepository->findOneBy(array('locale' => $locale));

                    foreach($snippets as $element => $snippet)
                    {
                        if($localeModel === null)
                            continue;

                        $elementModel = $form->getElement($element);

                        if($elementModel === null)
                            continue;

                        $translationModel = new \Shopware\Models\Config\ElementTranslation();
                        $translationModel->setLabel($snippet);
                        $translationModel->setLocale($localeModel);
                        $elementModel->addTranslation($translationModel);
                    }
                }
                
            case '5.02.16':
            case '5.02.17':
            case '5.02.18':
            case '5.02.19':
            case '5.02.20':
            case '5.02.21':
            case '5.02.22':
            case '5.02.23':
            case '5.02.24':
            case '5.02.25':
            case '5.02.26':
            case '5.02.27':
			case '5.02.28':			
                
                break;

            default:
                return false;
        }

        $this->setConfigElementsPositions();

        return true;
    }

    
    /**
     * checks if the given column exists in the given table
     * 
     * @param type $field
     * @param type $table
     * 
     * @return boolean
     */
    public static function FieldExists($field, $table)
    {
        $sql = "SHOW FIELDS FROM " . $table . " ";
        $fields = Shopware()->Db()->fetchAll($sql);

        if(is_array($fields) && count($fields) > 0)
        {
            foreach($fields as $key => $val)
            {
                if($field == $val['Field'])
                {
                    return true;
                }
            }
        }

        return false;
    }

    
    /**
     * correct the positions for the config-elements of the plugin after plugin-update
     * 
     * function exists since plugin version 4.02.16
     */
    public function setConfigElementsPositions()
    {
        $form = $this->Form();
        $elements = $this->getFormElements();

        foreach($elements as $position => $element)
        {
            $form->getElement($element[1])->setPosition($position);
        }
    }

    
    /**
     * Plugin uninstall method
     */
    public function uninstall()
    {
        $sql = "DROP TABLE IF EXISTS swp_viaebay_articles";
        Shopware()->Db()->query($sql);

        $sql = "DROP TABLE IF EXISTS swp_viaebay_categories";
        Shopware()->Db()->query($sql);


        $sql = "DELETE FROM s_crontab WHERE action LIKE 'SwpVIAeBay%'";
        Shopware()->Db()->query($sql);


        // Filter entfernen für SW5
        if($this->assertVersionGreaterThen("5.0.0"))
        {
            $sql = "DELETE FROM s_multi_edit_filter WHERE filter_string LIKE '%NOTVIAEBAY%' ";
            Shopware()->Db()->query($sql);

            $sql = "DELETE FROM s_multi_edit_filter WHERE filter_string LIKE '%VIAEBAY%' ";
            Shopware()->Db()->query($sql);
        }

        
        // neu logik fuer attribute seit sw 5.2.2
        if($this->assertVersionGreaterThen("5.2.2"))
        {
            $service = $this->get('shopware_attribute.crud_service');
            
            $this->get('shopware_attribute.crud_service')->delete('s_articles_attributes', 'swp_viaebay_container_id');
            $this->get('shopware_attribute.crud_service')->delete('s_articles_attributes', 'swp_viaebay_id');
            
            $this->get('shopware_attribute.crud_service')->delete('s_categories_attributes', 'swp_viaebay_id');
            
            $this->get('shopware_attribute.crud_service')->delete('s_order_attributes', 'swp_viaebay_id');
            $this->get('shopware_attribute.crud_service')->delete('s_order_attributes', 'swp_viaebay_byer_package_enclosure');
            $this->get('shopware_attribute.crud_service')->delete('s_order_attributes', 'swp_viaebay_carrier_used');
            $this->get('shopware_attribute.crud_service')->delete('s_order_attributes', 'swp_viaebay_payment_option');
            
            $this->get('shopware_attribute.crud_service')->delete('s_order_details_attributes', 'swp_viaebay_id');
            
            $this->get('shopware_attribute.crud_service')->delete('s_order_billingaddress_attributes', 'swp_viaebay_id');
            
            $this->get('shopware_attribute.crud_service')->delete('s_order_shippingaddress_attributes', 'swp_viaebay_id');
            
            // Rebuild attribute models
            $metaDataCache = Shopware()->Models()->getConfiguration()->getMetadataCacheImpl();
            $metaDataCache->deleteAll();
        }
        else
        {
            Shopware()->Models()->removeAttribute('s_articles_attributes', 'swp_viaebay', 'container_id');
            Shopware()->Models()->removeAttribute('s_articles_attributes', 'swp_viaebay', 'id');
            Shopware()->Models()->removeAttribute('s_categories_attributes', 'swp_viaebay', 'id');
            Shopware()->Models()->removeAttribute('s_order_attributes', 'swp_viaebay', 'id');
            Shopware()->Models()->removeAttribute('s_order_attributes', 'swp_viaebay', 'byer_package_enclosure');
            Shopware()->Models()->removeAttribute('s_order_attributes', 'swp_viaebay', 'carrier_used');
            Shopware()->Models()->removeAttribute('s_order_attributes', 'swp_viaebay', 'payment_option');
            Shopware()->Models()->removeAttribute('s_order_details_attributes', 'swp_viaebay', 'id');
            Shopware()->Models()->removeAttribute('s_order_billingaddress_attributes', 'swp_viaebay', 'id');
            Shopware()->Models()->removeAttribute('s_order_shippingaddress_attributes', 'swp_viaebay', 'id');
        }
        
        
        $this->Application()->Models()->generateAttributeModels(array(
            's_articles_attributes',
            's_categories_attributes',
            's_order_attributes',
            's_order_details_attributes',
            's_order_billingaddress_attributes',
            's_order_shippingaddress_attributes',
        ));

        
        return array('success' => true, 'invalidateCache' => array('frontend', 'backend', 'proxy'));
    }

    
    /**
     * activates the plugin
     */
    public function enable()
    {
        $this->checkLicense();

        return true;
    }

    
    /**
     * deactivates the plugin
     */
    public function disable()
    {
        return true;
    }

    
    /**
     * get name for this plugin
     */
    public function getLabel()
    {
        return 'VIA-Connect Schnittstelle';
    }

    
    /**
     * Get version tag of this plugin to display in manager
     */
    public function getVersion()
    {
        return '5.03.00';
    }

    
    /**
     * get the main info for the plugin
     */
    public function getInfo()
    {
        return array(
            'label' => $this->getLabel(),
            'version' => $this->getVersion(),
            'autor' => 'ViA-Online GmbH',
            'copyright' => 'Copyright (c) 2015, ViA-Online GmbH',
            'support' => 'http://www.via.de/ebay',
            'link' => 'http://www.via.de/ebay'
        );
    }

    
    /**
     * create plugin config form
     */
    protected function createForm()
    {

        $form = $this->Form();
        /*
          VIA-eBay (https://sandboxwww.via.de)
          UN: bui-hinscheSW
          PW: hinsche123

          eBay Sandbox (http://cgi.sandbox.ebay.de)
          Buyer
          UN: testuser_bui_buyer
          PW: hinsche123

          Seller
          UN: testuser_bui_itemseller
          PW: hinsche123

          Schnittstellendaten:
          Benutzername: 16223:bui-hinscheSWAPI
          Passwort: J-GybbowKMqrZYS
          SubscriptionToken: 7689d234-30a9-4bae-9ef9-f7f46612088d
         */

        $elements = $this->getFormElements();

        /**
         * $elements array 
         * 
         * array(
         *      'field_type'
         *      'field_name'
         *      'options'
         * )
         */
        foreach($elements as $element)
        {
            $form->setElement($element[0], $element[1], $element[2]);
        }

        $form->save();

        $this->setConfigElementsPositions();
    }

    
    /**
     * create plugin config form
     */
    protected function createFormUpdate()
    {
        $config = Shopware()->Plugins()->Backend()->SwpVIAeBay()->Config();

        $form = $this->Form();

        $elements = $this->getFormElements();

        /**
         * $elements array 
         * 
         * array(
         *      'field_type'
         *      'field_name'
         *      'options'
         * )
         */
        foreach($elements as $element)
        {
            $options = $element[2];

            if($element[1] != 'boarding')
            {
                $options['value'] = $config->$element[1];

                $options['hidden'] = false;
            }
            else
            {
                $options['hidden'] = true;
            }

            $form->setElement($element[0], $element[1], $options);
        }

        $form->save();

        $this->setConfigElementsPositions();
    }

    
    public function getFormElements()
    {
        $shop_domain = Shopware()->Modules()->System()->sSYSTEM->sPathStart;
        $shop_domain = rtrim(str_replace('shopware.php', '', $shop_domain), '/');


        $defaultDispatchValue = Shopware()->Db()->fetchOne('SELECT id FROM s_premium_dispatch WHERE name="eBay"');


        return array
        (
            array('button', 'boarding', array(
                    'label' => '<b><style>.viaebay-onboarding-button-over:hover{ background:#1491e7 !important; }</style><span style="color:#fff; font-size: 14px !important; text-align: center; font-weight: 600;">VIA-Connect Onboarding starten</span></b>',
                    'handler' => 'function(){
                        var boardingWindow = Ext.getCmp("VIAeBayBoardingWindow");
                        var openerWindow = this.up("plugin-manager-detail-window");

                        if(!openerWindow.plugin.data.active)
                        {
                            Ext.Msg.alert("VIA-Connect", "Sie müssen das Plugin erst aktivieren.");
                            return;
                        }

                        if(boardingWindow == undefined)
                        {
                            Shopware.app.Application.addSubApplication({
                                name: "Shopware.apps.viaebay",
                                localizedName: "VIAeBay Boarding", 
                                openerWindow: openerWindow,
                            });
                        }
                        else
                        {
                            boardingWindow.toFront();
                        }
                    }',
                    'cls' => 'viaebay-onboarding-button-over',
                    'maxWidth' => '200',
                    'style' => "
                        margin-left:300px;
                        padding: 8px 25px;
                        border: 2px solid #C2C2C2;
                        border-radius: 25px !important;
                        cursor: pointer;
                        border: 0 none;
                        color: #fff !important;
                        background: -moz-linear-gradient(left, #1fb3fb 0, #1491e7 100%);
                        background: -webkit-gradient(left top, right top, color-stop(0, #1fb3fb), color-stop(100%, #1491e7));
                        background: -webkit-linear-gradient(left, #1fb3fb 0, #1491e7 100%);
                        background: -o-linear-gradient(left, #1fb3fb 0, #1491e7 100%);
                        background: -ms-linear-gradient(left, #1fb3fb 0, #1491e7 100%);
                        background: linear-gradient(to right, #1fb3fb 0%, #1491e7 100%);
                        filter: progid:DXImageTransform.Microsoft.gradient(startColorstr=#1491e7, endColorstr=#1fb3fb, GradientType=1);
                    ",
                )),
            
            array('button', 'button0', array('hidden' => true, 'label' => '<b>Schnittstellendaten</b>', 'value' => '')),
            array('text', 'username', array('hidden' => true, 'label' => 'Benutzername', 'required' => true, 'value' => '', 'scope' => Shopware_Components_Form::SCOPE_SHOP)),
            array('text', 'password', array('hidden' => true, 'label' => 'Passwort', 'required' => true, 'value' => '', 'scope' => Shopware_Components_Form::SCOPE_SHOP)),
            array('text', 'subscriptiontoken', array('hidden' => true, 'label' => 'VIA-Connect Token', 'required' => true, 'value' => '', 'scope' => Shopware_Components_Form::SCOPE_SHOP)),
            array('boolean', 'testmode', array('hidden' => true, 'label' => 'Testmodus', 'required' => true, 'value' => false, 'scope' => Shopware_Components_Form::SCOPE_SHOP)),
            array('text', 'shop_domain', array('hidden' => true, 'label' => 'Shop-Domain', 'required' => true, 'value' => $shop_domain, 'scope' => Shopware_Components_Form::SCOPE_SHOP)),
            array('button', 'logintest', array('hidden' => true, 'label' => '<b><font color="#1991EC">Zugangsdaten testen (funktioniert nur wenn das Plugin konfiguriert und aktiviert gespeichert wurde)</b></font>', 'handler' => 'function() {
                        Ext.Ajax.request({
                            url: window.location.pathname+"viaebay/checkLogin",
                            scope: me,
                            success:function (response) {
                                var result = Ext.decode(response.responseText);

                                if(result.success == "true") {
                                    Ext.MessageBox.alert("Erfolgreich", "Die Zugangsdaten sind korrekt.");
                                } else {
                                    Ext.MessageBox.alert("Fehlgeschlagen", "Die Zugangsdaten sind nicht korrekt.");
                                }
                            },
                            failure:function () {
                                Ext.MessageBox.alert("Fehlgeschlagen", "Der Login-Check konnte aufgrund eines Fehlers nicht durchgeführt werden. Wurde das Plugin konfiguriert und aktiv gespeichert?");
                            }
                        });
                    }')),
            
            array('button', 'button1', array('hidden' => true, 'label' => '<b>Bestell-Import</b>', 'value' => '')),
            array('select', 'shippingcompletestatus', array
                    (
                    'hidden' => true,
                    'label' => 'Bestellstatus für "Als versendet" markierte Bestellungen',
                    'description' => '',
                    'required' => true,
                    'multiSelect' => false,
                    'editable' => false,
                    'value' => '',
                    'valueField' => 'id',
                    'displayField' => 'description',
                    'store' => 'base.OrderStatus',
                    'scope' => Shopware_Components_Form::SCOPE_SHOP
                )),
            array('select', 'paymentcompletestatus', array
                    (
                    'hidden' => true,
                    'label' => 'Zahlungsstatus für "Als bezahlt" markierte Bestellungen',
                    'description' => '',
                    'required' => true,
                    'multiSelect' => false,
                    'editable' => false,
                    'value' => '',
                    'valueField' => 'id',
                    'displayField' => 'description',
                    'store' => 'base.PaymentStatus',
                    'scope' => Shopware_Components_Form::SCOPE_SHOP
                )),
            array('select', 'paymentcashcompletestatus', array
                    (
                    'hidden' => true,
                    'label' => 'Zahlungsstatus bei "Bar bei Abholung" für "Als bezahlt" markierte Bestellungen',
                    'description' => '',
                    'required' => true,
                    'multiSelect' => false,
                    'editable' => false,
                    'value' => '',
                    'valueField' => 'id',
                    'displayField' => 'description',
                    'store' => 'base.PaymentStatus',
                    'scope' => Shopware_Components_Form::SCOPE_SHOP
                )),
            array('select', 'paymentcodcompletestatus', array
                    (
                    'hidden' => true,
                    'label' => 'Zahlungsstatus bei "Nachnahme" für "Als bezahlt" markierte Bestellungen',
                    'description' => '',
                    'required' => true,
                    'multiSelect' => false,
                    'editable' => false,
                    'value' => '',
                    'valueField' => 'id',
                    'displayField' => 'description',
                    'store' => 'base.PaymentStatus',
                    'scope' => Shopware_Components_Form::SCOPE_SHOP
                )),
            array('select', 'paymentmoneyxcompletestatus', array
                    (
                    'hidden' => true,
                    'label' => 'Zahlungsstatus bei "Vorkasse / Überweisung" für "Als bezahlt" markierte Bestellungen',
                    'description' => '',
                    'required' => true,
                    'multiSelect' => false,
                    'editable' => false,
                    'value' => '',
                    'valueField' => 'id',
                    'displayField' => 'description',
                    'store' => 'base.PaymentStatus',
                    'scope' => Shopware_Components_Form::SCOPE_SHOP
                )),
            array('select', 'paymentpaypalcompletestatus', array
                    (
                    'hidden' => true,
                    'label' => 'Zahlungsstatus bei "PayPal" für "Als bezahlt" markierte Bestellungen',
                    'description' => '',
                    'required' => true,
                    'multiSelect' => false,
                    'editable' => false,
                    'value' => '',
                    'valueField' => 'id',
                    'displayField' => 'description',
                    'store' => 'base.PaymentStatus',
                    'scope' => Shopware_Components_Form::SCOPE_SHOP
                )),
            
            array('button', 'button2', array('hidden' => true, 'label' => '<b>Sonstiges</b>', 'value' => '')),
            array('boolean', 'debugmode', array('hidden' => true, 'label' => 'Debug-Modus aktivieren', 'required' => true, 'value' => false, 'scope' => Shopware_Components_Form::SCOPE_SHOP)),
            array('boolean', 'modeleventsarticles', array('hidden' => true, 'label' => 'Model-Events bei Artikeln aktivieren', 'required' => true, 'value' => true, 'scope' => Shopware_Components_Form::SCOPE_SHOP)),
            array('boolean', 'modeleventsorders', array('hidden' => true, 'label' => 'Model-Events bei Bestellungen aktivieren', 'required' => true, 'value' => true, 'scope' => Shopware_Components_Form::SCOPE_SHOP)),
            array('boolean', 'usebestoffer', array('hidden' => true, 'label' => 'VIA-Connect - Preisvorschlag nutzen', 'required' => true, 'value' => false, 'scope' => Shopware_Components_Form::SCOPE_SHOP)),
            array('boolean', 'zeroqty', array('hidden' => true, 'label' => 'Deaktivierte Artikel mit Menge "0" übertragen', 'required' => true, 'value' => true, 'scope' => Shopware_Components_Form::SCOPE_SHOP)),
            array('text', 'countpropertyvalues', array('hidden' => true, 'label' => 'Anzahl der übertragenen Eigenschaften', 'required' => true, 'value' => '22', 'scope' => Shopware_Components_Form::SCOPE_SHOP)),
            array('boolean', 'reviseinventorystatusondetailsave', array('hidden' => true, 'label' => 'Nur Preis/Menge beim Artikel-Speichern abgleichen', 'required' => true, 'value' => false, 'scope' => Shopware_Components_Form::SCOPE_SHOP)),
            array('text', 'articleexportcustomergroupprice', array('hidden' => true, 'label' => 'Preise von dieser Kundengruppe exportieren', 'required' => true, 'value' => 'EK', 'scope' => \Shopware\Models\Config\Element::SCOPE_SHOP)),
            array('datetime', 'update_articles_date', array('hidden' => true, 'label' => 'Letzte Artikel-Aktualisierung', 'required' => false, 'value' => '', 'scope' => Shopware_Components_Form::SCOPE_SHOP)),
            
            array('button', 'button3', array('hidden' => true, 'label' => '<b>Versandarten</b>', 'value' => '')),
            array('select', 'shipping_de', array
                    (
                    'hidden' => true,
                    'label' => 'Versandart DE',
                    'description' => '',
                    'required' => true,
                    'multiSelect' => false,
                    'editable' => false,
                    'value' => (int) $defaultDispatchValue,
                    'valueField' => 'id',
                    'displayField' => 'name',
                    'store' => 'base.Dispatch',
                    'scope' => Shopware_Components_Form::SCOPE_SHOP
                )),
            array('select', 'shipping_international', array
                    (
                    'hidden' => true,
                    'label' => 'Versandart sonstige Länder',
                    'description' => '',
                    'required' => true,
                    'multiSelect' => false,
                    'editable' => false,
                    'value' => (int) $defaultDispatchValue,
                    'valueField' => 'id',
                    'displayField' => 'name',
                    'store' => 'base.Dispatch',
                    'scope' => Shopware_Components_Form::SCOPE_SHOP
                )),
            
            array('button', 'button4', array('hidden' => true, 'label' => '<b>Abverkauf</b>', 'value' => '')),
            array('boolean', 'sale_actice', array('hidden' => true, 'label' => 'Abverkauf zulassen', 'required' => true, 'value' => false, 'scope' => Shopware_Components_Form::SCOPE_SHOP)),
            array('number', 'default_stock_amount', array('hidden' => true, 'label' => 'Default Menge übergeben', 'minValue' => 0, 'required' => true, 'value' => 5, 'scope' => Shopware_Components_Form::SCOPE_SHOP)),
            
            array('button', 'button5', array('hidden' => true, 'label' => '<b>Cronjobs</b>', 'value' => '')),
            array('text', 'cronjobpass', array('hidden' => true, 'label' => 'Cronjobs Passwort', 'required' => true, 'value' => md5(rand()), 'scope' => Shopware_Components_Form::SCOPE_SHOP)),
            array('text', 'cronjoblimitorders', array('hidden' => true, 'label' => 'Cronjobs (Bestellungen) Schrittweite', 'required' => true, 'value' => '50', 'scope' => Shopware_Components_Form::SCOPE_SHOP)),
            array('text', 'cronjoblimitarticles', array('hidden' => true, 'label' => 'Cronjobs (Artikel) Schrittweite', 'required' => true, 'value' => '25', 'scope' => Shopware_Components_Form::SCOPE_SHOP)),
            array('text', 'daysfororderscronjob', array('hidden' => true, 'label' => 'Anzahl Tage für Cronjob "Bestelldaten aktualisieren"', 'required' => true, 'value' => '3', 'scope' => Shopware_Components_Form::SCOPE_SHOP)),
            
        );
    }
    

    /**
     * create plugin config form translations
     */
    protected function createTranslations()
    {
        $form = $this->Form();

        $translations = array(
            'en_GB' => array(
                'button0' => '<b>API Data</b>',
                'testmode' => 'Sandbox-Mode',
                'username' => 'Username',
                'password' => 'Password',
                'subscriptiontoken' => 'SubscriptionToken',
                'button1' => 'Order-Import',
                'paymentcompletestatus' => 'Payment Status for "Marked as Payed" Orders',
                'paymentcashcompletestatus' => 'Payment Status with "Cash on Pickup" for "Marked as Payed" Orders',
                'paymentcodcompletestatus' => 'Payment Status with "Cash on Delivery" for "Marked as Payed" Orders',
                'paymentmoneyxcompletestatus' => 'Payment Status with "PrePayment / Bank Transfer" for "Marked as Payed" Orders',
                'paymentpaypalcompletestatus' => 'Payment Status with "PayPal" for "Marked as Payed" Orders',
                'shippingcompletestatus' => 'Order Status for "Marked as Shipped" Orders',
                'button2' => 'Other',
                'debugmode' => 'activate Debug-Mode',
                'reviseinventorystatusondetailsave' => 'Sync only stock and price on article save',
                'articleexportcustomergroupprice' => 'Abbreviation of the customer group which prices are to be exported',
                'logintest' => '<b><font color="#1991EC">Test access (only works if the plugin has been configured and saved activated)</b></font>',
                'update_articles_date' => 'date of last article update',
                'button3' => 'Shipping Methods',
                'shipping_de' => 'Shipping method DE',
                'shipping_international' => 'Shipping method other countrys',
                'button4' => 'Sale',
                'sale_actice' => 'Allow Sale',
                'default_stock_amount' => 'Send Default Stock Amount',
                'shop_domain' => 'Shop-Domain',
                'modeleventsarticles' => 'activate Model-Events for articles',
                'modeleventsorders' => 'activate Model-Events for orders',
                'usebestoffer' => 'VIA-Connect - Preisvorschlag nutzen',
                'zeroqty' => 'Deaktivierte Artikel mit Menge "0" übertragen',
                'daysfororderscronjob' => 'Anzahl Tage für Cronjob "Bestelldaten aktualisieren"',
                'countpropertyvalues' => 'Anzahl der übertragenen Eigenschaften',
                'cronjoblimitorders' => 'Cronjobs (Bestellungen) Schrittweite',
                'cronjoblimitarticles' => 'Cronjobs (Artikel) Schrittweite',
                'cronjobpass' => 'Cronjobs Passwort',
                'button5' => '<b>Cronjobs</b>',
            )
        );

        $shopRepository = Shopware()->Models()->getRepository('\Shopware\Models\Shop\Locale');

        foreach($translations as $locale => $snippets)
        {
            $localeModel = $shopRepository->findOneBy(array('locale' => $locale));

            foreach($snippets as $element => $snippet)
            {
                if($localeModel === null)
                    continue;

                $elementModel = $form->getElement($element);

                if($elementModel === null)
                    continue;

                $translationModel = new \Shopware\Models\Config\ElementTranslation();
                $translationModel->setLabel($snippet);
                $translationModel->setLocale($localeModel);
                $elementModel->addTranslation($translationModel);
            }
        }
    }

    
    /**
     * create database entries
     */
    protected function createTables()
    {

        if(!$this->assertRequiredPluginsPresent(array('SwpVIAeBay')))
        {
            $sql = "
                    CREATE TABLE IF NOT EXISTS swp_viaebay_articles (
                        id int(11) NOT NULL auto_increment,
                        articleID int(11) NULL,
                        articledetailsID int(11) NULL,
                        swp_viaebay_container_id int(11) NULL,
                        swp_viaebay_id int(11) NULL,
                        best_offer_auto_accept_price double NULL DEFAULT 0.00,
                        best_offer_minimum_price double NULL DEFAULT 0.00,
                        PRIMARY KEY (id),
                        UNIQUE (articledetailsID)
                    ) ENGINE=MyISAM DEFAULT CHARSET=utf8;
            ";
            Shopware()->Db()->query($sql);


            $sql = "
                    CREATE TABLE IF NOT EXISTS swp_viaebay_categories (
                        id int(11) NOT NULL auto_increment,
                        categoryID int(11) NULL,
                        swp_viaebay_id int(11) NULL,  				
                        PRIMARY KEY (id),
                        UNIQUE (categoryID)
                    ) ENGINE=MyISAM DEFAULT CHARSET=utf8;
            ";
            Shopware()->Db()->query($sql);

            
            //////
            // Filter hinzufügen für SW5
            if($this->assertVersionGreaterThen("5.0.0"))
            {
                $sql = "INSERT INTO s_multi_edit_filter (name, filter_string) VALUES ('nicht bei VIA-Connect', 'NOTVIAEBAY');";
                Shopware()->Db()->query($sql);

                $sql = "INSERT INTO s_multi_edit_filter (name, filter_string) VALUES ('bei VIA-Connect', 'VIAEBAY');";
                Shopware()->Db()->query($sql);
            }
            //////                
            

            if(!Shopware()->Db()->fetchOne('SELECT id FROM `s_premium_dispatch` WHERE name="eBay"'))
            {
                Shopware()->Db()->exec('INSERT INTO `s_premium_dispatch` (`name`, `type`, `description`, `comment`, `active`, `position`, `calculation`, `surcharge_calculation`, `tax_calculation`, `bind_shippingfree`, `bind_laststock`) VALUES ("eBay", "0", "VIA eBay Versandart", "VIA eBay Versandart", "0", "0", "1", "3", "0", "0", "0")');
            }

            if(!Shopware()->Db()->fetchOne('SELECT id FROM `s_premium_dispatch` WHERE name="ebayPLUS"'))
            {
                Shopware()->Db()->exec('INSERT INTO `s_premium_dispatch` (`name`, `type`, `description`, `comment`, `active`, `position`, `calculation`, `surcharge_calculation`, `tax_calculation`, `bind_shippingfree`, `bind_laststock`) VALUES ("ebayPLUS", "0", "VIA eBay Versandart", "VIA eBay Versandart", "0", "0", "1", "3", "0", "0", "0")');
            }


            // neu logik fuer attribute seit sw 5.2.2
            if($this->assertVersionGreaterThen("5.2.2"))
            {
                $service = $this->get('shopware_attribute.crud_service');

                $service->update('s_articles_attributes', 'swp_viaebay_container_id', 'integer', [
                    'label' => 'VIA-Connect Container ID',
                    'translatable' => false,
                    'displayInBackend' => false,
                    'custom' => false,
                ]);                    
                $service->update('s_articles_attributes', 'swp_viaebay_id', 'integer', [
                    'label' => 'VIA-Connect ID',
                    'translatable' => false,
                    'displayInBackend' => false,
                    'custom' => false,
                ]);

                $service->update('s_categories_attributes', 'swp_viaebay_id', 'integer', [
                    'label' => 'VIA-Connect ID',
                    'translatable' => false,
                    'displayInBackend' => false,
                    'custom' => false,
                ]);

                $service->update('s_order_attributes', 'swp_viaebay_id', 'integer', [
                    'label' => 'VIA-Connect ID',
                    'translatable' => false,
                    'displayInBackend' => false,
                    'custom' => false,
                ]);
                $service->update('s_order_attributes', 'swp_viaebay_byer_package_enclosure', 'string', [
                    'label' => 'BuyerPackageEnclosure',
                    'translatable' => false,
                    'displayInBackend' => false,
                    'custom' => false,
                ]);
                $service->update('s_order_attributes', 'swp_viaebay_carrier_used', 'string', [
                    'label' => 'VIA-Connect - Versanddienstleister',
                    'translatable' => false,
                    'displayInBackend' => true,
                    'custom' => false,
                ]);
                $service->update('s_order_attributes', 'swp_viaebay_payment_option', 'string', [
                    'label' => 'PaymentOption',
                    'translatable' => false,
                    'displayInBackend' => false,
                    'custom' => false,
                ]);

                $service->update('s_order_details_attributes', 'swp_viaebay_id', 'integer', [
                    'label' => 'VIA-Connect ID',
                    'translatable' => false,
                    'displayInBackend' => false,
                    'custom' => false,
                ]);

                $service->update('s_order_billingaddress_attributes', 'swp_viaebay_id', 'integer', [
                    'label' => 'VIA-Connect ID',
                    'translatable' => false,
                    'displayInBackend' => false,
                    'custom' => false,
                ]);

                $service->update('s_order_shippingaddress_attributes', 'swp_viaebay_id', 'integer', [
                    'label' => 'VIA-Connect ID',
                    'translatable' => false,
                    'displayInBackend' => false,
                    'custom' => false,
                ]);
            }
            else
            {
                // alter weg - spalten beibehalten damit ids aus aelteren plugin-versionen beim update nicht verloren gehen
                Shopware()->Models()->addAttribute('s_articles_attributes', 'swp_viaebay', 'container_id', 'INT(11)', true, null);
                Shopware()->Models()->addAttribute('s_articles_attributes', 'swp_viaebay', 'id', 'INT(11)', true, null);
                Shopware()->Models()->addAttribute('s_categories_attributes', 'swp_viaebay', 'id', 'INT(11)', true, null);
                /////
                
                Shopware()->Models()->addAttribute('s_order_attributes', 'swp_viaebay', 'id', 'INT(11)', true, null);
                Shopware()->Models()->addAttribute('s_order_attributes', 'swp_viaebay', 'byer_package_enclosure', 'TEXT', true, null);
                Shopware()->Models()->addAttribute('s_order_attributes', 'swp_viaebay', 'carrier_used', 'TEXT', true, null);
                Shopware()->Models()->addAttribute('s_order_attributes', 'swp_viaebay', 'payment_option', 'TEXT', true, null);
                Shopware()->Models()->addAttribute('s_order_details_attributes', 'swp_viaebay', 'id', 'INT(11)', true, null);
                Shopware()->Models()->addAttribute('s_order_billingaddress_attributes', 'swp_viaebay', 'id', 'INT(11)', true, null);
                Shopware()->Models()->addAttribute('s_order_shippingaddress_attributes', 'swp_viaebay', 'id', 'INT(11)', true, null);
                
                $this->Application()->Models()->generateAttributeModels(array(
                    's_articles_attributes',
                    's_categories_attributes',
                    's_order_attributes',
                    's_order_details_attributes',
                    's_order_billingaddress_attributes',
                    's_order_shippingaddress_attributes',
                ));
            }
         
         
        }
    }
    

    /**
     * create database entry for partnerprogramm
     */
    protected function createPartnerEntry()
    {
        if(!$this->assertRequiredPluginsPresent(array('SwpVIAeBay')))
        {
            $sql = "INSERT INTO `s_emarketing_partner` (`idcode`, `datum`, `company`, `active`) VALUES ('viaconnect', now(), 'VIA-Connect', 1);";
            Shopware()->Db()->query($sql);
        }
    }

    
    /**
     * create Events/Hooks for the plugin
     */
    protected function subscribeEvents()
    {
        // Backend Artikel-Fenster-Erweiterung (Hinzufügen von Elementen für VIA-eBay)
        $this->subscribeEvent('Enlight_Controller_Action_PostDispatch_Backend_ArticleList', 'onPostDispatchBackendArticleList');
        $this->subscribeEvent('Enlight_Controller_Action_PreDispatch_Backend_ArticleList', 'onPreDispatchBackendArticleList');

        // Backend Bestell-Fenster-Erweiterung (Hinzufügen von Elementen für VIA-eBay)
        $this->subscribeEvent('Enlight_Controller_Action_PostDispatch_Backend_Order', 'onPostDispatchBackendOrders');

        // Backend Plugin-Controller
        $this->subscribeEvent('Enlight_Controller_Dispatcher_ControllerPath_Backend_viaebay', 'onGetControllerPathBackend');

        // Backend beforeSaveOrder-Action-Erweiterung (Aktualisieren des Tracking-Codes und des Bestellstatus)
        $this->subscribeEvent('Shopware_Controllers_Backend_Order::saveAction::before', 'before_onSaveOrderBackend');

        // Backend beforeBatchProcessAction-Erweiterung (bei der Stapelverarbeitung ebenso den Bestellstatus in VIA-eBay aktualisieren)
        $this->subscribeEvent('Shopware_Controllers_Backend_Order::batchProcessAction::before', 'before_onBatchProcessOrdersBackend');

        // Frontend Checkout afterFinish-Action-Erweiterung (Aktualisierung der Artikelanzahl bei VIA-eBay nach einer Shop-Bestellung)
        $this->subscribeEvent('Shopware_Controllers_Frontend_Checkout::finishAction::after', 'after_finishAction');

        // Backend afterArticle-Action-Erweitrung (Aktualisierung geänderter Artikel-Daten an VIA-eBay)
        $this->subscribeEvent('Enlight_Controller_Action_PostDispatch_Backend_Article', 'afterArticle');
        $this->subscribeEvent('Enlight_Controller_Action_PostDispatch_Backend_ArticleList', 'afterArticleList');

        // Backend beforeArticleDeleteAction-Erweiterung (wenn ein Artikel in Shopware gelöscht wird, wird dieser auch in VIA-eBay gelöscht)
        $this->subscribeEvent('Shopware_Controllers_Backend_Article::deleteAction::before', 'before_onDeleteArticleBackend');
        $this->subscribeEvent('Shopware_Controllers_Backend_ArticleList::deleteAction::before', 'before_onDeleteArticleBackend');

        // Backend afterDuplicateArticleAction-Erweiterung (lösche VIA-eBay IDs des duplizierten Artikels)
        $this->subscribeEvent('Shopware_Controllers_Backend_Article::duplicateArticleAction::after', 'after_onDuplicateArticleBackend');

        // Backend afterSaveDetailCategory-Erweiterung (lösche deaktivierte Kategorien und übertragene umbenannte Kategorien bei VIA-eBay)
        $this->subscribeEvent('Shopware_Controllers_Backend_Category::saveDetail::after', 'after_onSaveDetailCategoryBackend');

        // Backend afterMoveCategoryTreeItemAction-Erweiterung (übertrage neue Kategoriestruktur, durch verschieben von Kategorien, an VIA-eBay)
        $this->subscribeEvent('Shopware_Controllers_Backend_Category::moveTreeItemAction::after', 'after_onMoveCategoryTreeItemBackend');

        // Backend beforeDeleteCategoryBackendAction-Erweiterung (wenn in Shopware Kategorien gelöscht werden, sollen diese ebenfalls in VIA-eBay gelöscht werden)
        $this->subscribeEvent('Shopware_Controllers_Backend_Category::deleteAction::before', 'before_onDeleteCategoryBackend');

        // Backend beforeOnDeleteVariantsAction-Erweiterung (wenn in Shopware Varianten gelöscht werden, sollen diese auch in VIA-eBay gelöscht werden)
        $this->subscribeEvent('Shopware_Controllers_Backend_Article::deleteDetailAction::before', 'before_onDeleteVariants');

        // Cronjobs für VIA-eBay
        //$this->subscribeEvent('Shopware_CronJob_SwpVIAeBayImportOrders', 'importOrdersCronjob');
        //$this->subscribeEvent('Shopware_CronJob_SwpVIAeBayUpdateOrdersData', 'updateOrdersDataCronjob');
        //$this->subscribeEvent('Shopware_CronJob_SwpVIAeBayExportArticles', 'exportArticlesCronjob');
        //$this->subscribeEvent('Shopware_CronJob_SwpVIAeBayExportOnlySubmittedArticles', 'exportOnlySubmittedArticlesCronjob');
        //$this->subscribeEvent('Shopware_CronJob_SwpVIAeBayExportOnlyUpdatedArticles', 'exportOnlyUpdatedArticlesCronjob');
        //$this->subscribeEvent('Shopware_CronJob_SwpVIAeBayExportReviseInventoryStatus', 'exportReviseInventoryStatusCronjob');


        // Backend Artikel-Übersicht (Filter, Suche hinzufügen) - SW4
        $this->subscribeEvent('Shopware_Controllers_Backend_ArticleList_SQLParts', 'onShopwareControllersBackendArticleListSQLParts');

        // Backend Artikel-Übersicht (Sortierung hinzufügen) - SW4
        $this->subscribeEvent('Shopware_Controllers_Backend_ArticleList_ListSQL', 'onShopwareControllersBackendArticleListListSQL');


        // Backend Artikel-Übersicht (Filter, Suche hinzufügen) - SW5
        $this->subscribeEvent('SwagMultiEdit_Product_Grammar_getGrammar_filterGrammar', 'onSwagMultiEditProductGrammarGetGrammarFilterGrammar');
        $this->subscribeEvent('SwagMultiEdit_Product_DqlHelper_getDqlFromTokens_Token_Nullaryoperators', 'onSwagMultiEditProductDqlHelperGetDqlFromTokensTokenNullaryOperators');
        $this->subscribeEvent('SwagMultiEdit_Product_DqlHelper_getDqlFromTokens_filterTokens', 'onSwagMultiEditProductDqlHelperGetDqlFromTokensFilterTokens');


        // Model Events fuer WaWi und Co.
        // Artikel - Insert
        $this->subscribeEvent('Shopware\Models\Article\Article::prePersist', 'prePersistArticle');
        $this->subscribeEvent('Shopware\Models\Article\Article::postPersist', 'postPersistArticle');
        // Artikel - Update
        $this->subscribeEvent('Shopware\Models\Article\Article::preUpdate', 'preUpdateArticle');
        $this->subscribeEvent('Shopware\Models\Article\Article::postUpdate', 'postUpdateArticle');
        // Artikel - Remove
        $this->subscribeEvent('Shopware\Models\Article\Article::preRemove', 'preRemoveArticle');
        $this->subscribeEvent('Shopware\Models\Article\Article::postRemove', 'postRemoveArticle');
        // Bestellung - Update
        $this->subscribeEvent('Shopware\Models\Order\Order::postUpdate', 'postUpdateOrder');
    }

    
    /**
     * Create Plugin Cronjobs
     */
    protected function createCronjobs()
    {return; // mit der 4.02.15 wurde die cronjobs aus der shopware-cronjob-logik geloest
        //if(!$this->assertRequiredPluginsPresent(array('SwpVIAeBay')))
        {
            $this->createCronJob("VIA eBay Bestellungen importieren", "SwpVIAeBayImportOrders", 3600, false);
            $this->createCronJob("VIA eBay Bestelldaten aktualisieren (TrackingId, Bestellstatus, Zahlstatus)", "SwpVIAeBayUpdateOrdersData", 3600, false);
            $this->createCronJob("VIA eBay Alle Artikel exportieren", "SwpVIAeBayExportArticles", 3600, false);
            $this->createCronJob("VIA eBay nur übertr. Artikel exportieren", "SwpVIAeBayExportOnlySubmittedArticles", 3600, false);
            $this->createCronJob("VIA eBay nur aktualisierte Artikel exportieren", "SwpVIAeBayExportOnlyUpdatedArticles", 3600, false);
            $this->createCronJob("VIA eBay Übertragene Artikel exportieren Preis/Menge", "SwpVIAeBayExportReviseInventoryStatus", 3600, false);
        }
    }

    
    /**
     * add the plugin template path
     */
    public function onPostDispatchBackendArticleList(Enlight_Event_EventArgs $args)
    {
        $this->checkLicense();

        $this->registerNamespace();

        $args->getSubject()->View()->addTemplateDir($this->Path() . 'Views/');

        if(!$this->assertVersionGreaterThen("5.0.0"))
        {
            $use_backend_version = 'sw4/';
        }
        else
        {
            $use_backend_version = 'sw5/';
        }

        //__d($args->getRequest()->getActionName());
        //__d($args->getSubject()->View()->getAssign('data'));

        if($args->getRequest()->getActionName() === 'load')
        {
            $args->getSubject()->View()->extendsTemplate($use_backend_version . 'backend/article_list/controller/viaebayMain.js');
            $args->getSubject()->View()->extendsTemplate($use_backend_version . 'backend/article_list/view/main/viaebayWindow.js');
            $args->getSubject()->View()->extendsTemplate($use_backend_version . 'backend/article_list/view/main/viaebayGrid.js');
            $args->getSubject()->View()->extendsTemplate($use_backend_version . 'backend/article_list/model/viaebayModel.js');
        }
        else if($args->getRequest()->getActionName() === 'list' || $args->getRequest()->getActionName() === 'filter')
        {
            $assignedData = $args->getSubject()->View()->getAssign('data');

            foreach($assignedData as $key => $article)
            {
                if(!$this->assertVersionGreaterThen("5.0.0"))
                {
                    // SW4
                    $assignedData[$key]["swp_viaebay_container_id"] = Shopware()->Db()->fetchOne('SELECT IFNULL((SELECT swp_viaebay_container_id FROM swp_viaebay_articles WHERE articledetailsID = ?),0)', array($article["detailId"]));
                    $assignedData[$key]["swp_viaebay_id"] = Shopware()->Db()->fetchOne('SELECT IFNULL((SELECT swp_viaebay_id FROM swp_viaebay_articles WHERE articledetailsID = ?),0)', array($article["detailId"]));
                }
                else
                {
                    // SW5
                    $assignedData[$key]["swp_viaebay_container_id"] = Shopware()->Db()->fetchOne('SELECT IFNULL((SELECT swp_viaebay_container_id FROM swp_viaebay_articles WHERE articledetailsID = ?),0)', array($article["Detail_id"]));
                    $assignedData[$key]["swp_viaebay_id"] = Shopware()->Db()->fetchOne('SELECT IFNULL((SELECT swp_viaebay_id FROM swp_viaebay_articles WHERE articledetailsID = ?),0)', array($article["Detail_id"]));
                }
            }

            //__d($assignedData);

            $args->getSubject()->View()->data = $assignedData;
        }
    }

    
    /**
     * before saveing an article in backend article list
     */
    public function onPreDispatchBackendArticleList(Enlight_Event_EventArgs $args)
    {
        $request = $args->getRequest();

        if($this->assertVersionGreaterThen("5.0.0"))
        {
            if($args->getRequest()->getActionName() == 'saveSingleEntity')
            {
                $request->setPost('swp_viaebay_id', null);
                $request->setPost('swp_viaebay_container_id', null);

                return $args;
            }
        }
    }

    
    /**
     * add the plugin template path
     */
    public function onPostDispatchBackendOrders(Enlight_Event_EventArgs $args)
    {
        $this->checkLicense();

        $this->registerNamespace();

        $view = $args->getSubject()->View();
        $assignedData = $view->getAssign('data');

        $args->getSubject()->View()->addTemplateDir($this->Path() . 'Views/');

        if(!$this->assertVersionGreaterThen("5.0.0"))
        {
            $use_backend_version = 'sw4/';
        }
        else
        {
            $use_backend_version = 'sw5/';
        }

        
        if($args->getRequest()->getActionName() === 'load')
        {
            if($this->assertVersionGreaterThen("5.2.2"))
            {
                $args->getSubject()->View()->extendsTemplate($use_backend_version . 'backend/order/Shopware.attribute.Form.js');
                $args->getSubject()->View()->extendsTemplate($use_backend_version . 'backend/order/controller/viaebayList.js');
                $args->getSubject()->View()->extendsTemplate($use_backend_version . 'backend/order/view/list/viaebayList.js');
                $args->getSubject()->View()->extendsTemplate($use_backend_version . 'backend/order/model/viaebayOrder.js');
            }
            else
            {
                $args->getSubject()->View()->extendsTemplate($use_backend_version . 'backend/order/controller/viaebayList.js');
                $args->getSubject()->View()->extendsTemplate($use_backend_version . 'backend/order/view/list/viaebayList.js');
                $args->getSubject()->View()->extendsTemplate($use_backend_version . 'backend/order/view/detail/viaebayOverview.js');
                $args->getSubject()->View()->extendsTemplate($use_backend_version . 'backend/order/model/viaebayOrder.js');
            }
        }
        else if($args->getRequest()->getActionName() === 'getList')
        {
            foreach($assignedData as $key => $order)
            {
                $assignedData[$key]["swp_viaebay_id"] = Shopware()->Db()->fetchOne('SELECT IFNULL((SELECT swp_viaebay_id FROM s_order_attributes WHERE orderID = ?),0)', array($order["id"]));
                $assignedData[$key]["swp_viaebay_carrier_used"] = Shopware()->Db()->fetchOne('SELECT IFNULL((SELECT swp_viaebay_carrier_used FROM s_order_attributes WHERE orderID = ?),"-")', array($order["id"]));
            }

            $view->data = $assignedData;
        }
    }

    
    /**
     * get the backend controller path
     */
    public function onGetControllerPathBackend(Enlight_Event_EventArgs $args)
    {
        $this->checkLicense();

        $this->registerComponents();
        $this->registerNamespace();

        return dirname(__FILE__) . '/Controllers/Backend/viaebay.php';
    }

    
    /**
     * Update the VIA eBay tracking number and Order status when the status in Shopware is changed
     */
    public function before_onSaveOrderBackend(Enlight_Hook_HookArgs $args)
    {
        $this->checkLicense();

        $this->registerNamespace();


        $request = $args->getSubject()->Request();


        // swp_viaebay_carrier_used abspeichern
        $swp_viaebay_carrier_used = $request->getParam('swp_viaebay_carrier_used');

        if($swp_viaebay_carrier_used != '' && $request->getParam('id') != '')
        {
            Shopware()->Db()->exec('UPDATE s_order_attributes SET swp_viaebay_carrier_used = "' . $swp_viaebay_carrier_used . '" WHERE orderID = ' . $request->getParam('id') . '');
        }


        // normaler weg oder model-events?
        $config = Shopware()->Plugins()->Backend()->viaebay()->Config();

        if(!$config->modeleventsorders)
        {
            Shopware_Controllers_Backend_viaebay::updateVIAeBayTrackingCode($request);
            Shopware_Controllers_Backend_viaebay::updateVIAeBayOrderStatus($request);
        }
    }

    
    /**
     * Update the VIA eBay Order status when the status in Shopware is changed in the batch prcessing (Stapelverarbeitung)
     */
    public function before_onBatchProcessOrdersBackend(Enlight_Hook_HookArgs $args)
    {
        $this->checkLicense();

        $this->registerNamespace();


        // normaler weg oder model-events?
        $config = Shopware()->Plugins()->Backend()->viaebay()->Config();

        if(!$config->modeleventsorders)
        {
            $request = $args->getSubject()->Request();

            Shopware_Controllers_Backend_viaebay::updateVIAeBayOrderStatusInBatchProcessing($request);
        }
    }

    
    /**
     * submit new inStock to VIA eBay
     */
    public function after_finishAction(Enlight_Hook_HookArgs $args)
    {
        $this->checkLicense();

        $this->registerNamespace();

        $caller = $args->getSubject();
        $request = $caller->Request();
        $view = $caller->View();

        if(Shopware()->Modules()->Basket()->sCountBasket() > 0 && empty($view->sUserData['additional']['payment']['embediframe']))
            if(!Shopware()->Config()->get('IgnoreAGB') && !$request->getParam('sAGB'))
                return;

        Shopware_Controllers_Backend_viaebay::updateStockAmountAfterOrder($_SESSION['Shopware']['sOrderVariables']);
    }

    
    /**
     * update VIA-eBay article informations when edit article in the backend article deatil window
     */
    public function afterArticle(Enlight_Event_EventArgs $args)
    {
        $this->checkLicense();

        $this->registerNamespace();


        $config = Shopware()->Plugins()->Backend()->viaebay()->Config();


        $request = $args->getSubject()->Request();
        $view = $args->getSubject()->View();
        $assignedData = $view->getAssign('data');

        $args->getSubject()->View()->addTemplateDir($this->Path() . 'Views/');

        if(!$this->assertVersionGreaterThen("5.0.0"))
        {
            $use_backend_version = 'sw4/';
        }
        else
        {
            $use_backend_version = 'sw5/';
        }

        //__d($request->getActionName());

        switch($request->getActionName())
        {
            case 'load':
                
                if($this->assertVersionGreaterThen("5.0.0") && !$this->assertVersionGreaterThen("5.2.0"))
        	{
                    $args->getSubject()->View()->extendsTemplate($use_backend_version.'backend/article/model/viaebayVariantList.js');
        	}

                if($config->usebestoffer)
                {
                    if($this->assertVersionGreaterThen("5.2.2"))
                    {
                        $args->getSubject()->View()->extendsTemplate($use_backend_version . 'backend/article/controller/viaebayDetail_controller_sw522.js');

                        $args->getSubject()->View()->extendsTemplate($use_backend_version . 'backend/article/view/detail/viaebayDetail_sw522.js');
                    }
                    else
                    {
                        $args->getSubject()->View()->extendsTemplate($use_backend_version . 'backend/article/view/detail/viaebayDetail.js');
                    }
                }
                

                break;

            case 'detailList':
                foreach($assignedData as &$articleDetail)
                    $articleDetail["swp_viaebay_id"] = Shopware()->Db()->fetchOne('SELECT IFNULL((SELECT swp_viaebay_id FROM swp_viaebay_articles WHERE articledetailsID = ?),0)', array($articleDetail['id']));


                $view->data = $assignedData;

                break;

            case 'getArticle':
                $config = Shopware()->Plugins()->Backend()->viaebay()->Config();

                //__d($assignedData);

                if($config->usebestoffer)
                {
                    if($assignedData[0])
                    {
                        $articleID = $assignedData[0]['id'];
                        $articleDetailID = $assignedData[0]['mainDetailId'];
                        $taxData = $assignedData[0]['tax'];

                        $fallbackPrice = false;
                        $customerGroupPrice = false;

                        if(is_array($assignedData[0]['mainPrices']) && count($assignedData[0]['mainPrices']) > 1)
                        {
                            foreach($assignedData[0]['mainPrices'] as $price)
                            {
                                if($price['from'] == '1')
                                {
                                    if($price['customerGroupKey'] == $config->articleexportcustomergroupprice)
                                    {
                                        $customerGroupPrice = $price['price'];
                                    }
                                    else if($price['customerGroupKey'] == 'EK')
                                    {
                                        $fallbackPrice = $price['price'];
                                    }
                                }
                            }
                        }
                        else
                        {
                            foreach($assignedData[0]['mainPrices'] as $price)
                            {
                                if($price['customerGroupKey'] == $config->articleexportcustomergroupprice)
                                {
                                    $customerGroupPrice = $price['price'];
                                }
                                else if($price['customerGroupKey'] == 'EK')
                                {
                                    $fallbackPrice = $price['price'];
                                }
                            }
                        }
                        reset($assignedData[0]['mainPrices']);


                        if($viaebayData = Shopware_Controllers_Backend_viaebay::getDataFromVIAeBayArticleTable($articleDetailID))
                        {
                            $best_offer_auto_accept_price = $viaebayData['best_offer_auto_accept_price'];
                            $best_offer_auto_accept_price = $best_offer_auto_accept_price / 100 * (100 + $taxData['tax']);
                            $best_offer_auto_accept_price = round($best_offer_auto_accept_price, 2);

                            $best_offer_minimum_price = $viaebayData['best_offer_minimum_price'];
                            $best_offer_minimum_price = $best_offer_minimum_price / 100 * (100 + $taxData['tax']);
                            $best_offer_minimum_price = round($best_offer_minimum_price, 2);
                        }
                        else
                        {
                            $best_offer_auto_accept_price = round(0, 2);

                            $best_offer_minimum_price = round(0, 2);
                        }
                        
                        $assignedData[0]['attribute']['viaeabyprice'] = round(($customerGroupPrice) ? $customerGroupPrice : $fallbackPrice, 2);
                        $assignedData[0]['attribute']['bestofferautoacceptprice'] = $best_offer_auto_accept_price;
                        $assignedData[0]['attribute']['bestofferminimumprice'] = $best_offer_minimum_price;

                        $view->data = $assignedData;
                    }
                }

                break;

            case 'loadStores':
                $config = Shopware()->Plugins()->Backend()->viaebay()->Config();

                if($config->usebestoffer)
                {
                    if($assignedData['article'] && $assignedData['article'][0])
                    {
                        $articleID = $assignedData['article'][0]['id'];
                        $articleDetailID = $assignedData['article'][0]['mainDetailId'];
                        $taxData = $assignedData['article'][0]['tax'];

                        $fallbackPrice = false;
                        $customerGroupPrice = false;

                        if(is_array($assignedData['article'][0]['mainPrices']) && count($assignedData['article'][0]['mainPrices']) > 1)
                        {
                            foreach($assignedData['article'][0]['mainPrices'] as $price)
                            {
                                if($price['from'] == '1')
                                {
                                    if($price['customerGroupKey'] == $config->articleexportcustomergroupprice)
                                    {
                                        $customerGroupPrice = $price['price'];
                                    }
                                    else if($price['customerGroupKey'] == 'EK')
                                    {
                                        $fallbackPrice = $price['price'];
                                    }
                                }
                            }
                        }
                        else
                        {
                            foreach($assignedData['article'][0]['mainPrices'] as $price)
                            {
                                if($price['customerGroupKey'] == $config->articleexportcustomergroupprice)
                                {
                                    $customerGroupPrice = $price['price'];
                                }
                                else if($price['customerGroupKey'] == 'EK')
                                {
                                    $fallbackPrice = $price['price'];
                                }
                            }
                        }
                        reset($assignedData['article'][0]['mainPrices']);


                        if($viaebayData = Shopware_Controllers_Backend_viaebay::getDataFromVIAeBayArticleTable($articleDetailID))
                        {
                            $best_offer_auto_accept_price = $viaebayData['best_offer_auto_accept_price'];
                            $best_offer_auto_accept_price = $best_offer_auto_accept_price / 100 * (100 + $taxData['tax']);
                            $best_offer_auto_accept_price = round($best_offer_auto_accept_price, 2);

                            $best_offer_minimum_price = $viaebayData['best_offer_minimum_price'];
                            $best_offer_minimum_price = $best_offer_minimum_price / 100 * (100 + $taxData['tax']);
                            $best_offer_minimum_price = round($best_offer_minimum_price, 2);
                        }
                        else
                        {
                            $best_offer_auto_accept_price = round(0, 2);

                            $best_offer_minimum_price = round(0, 2);
                        }
                        
                        $assignedData['article'][0]['attribute']['viaeabyprice'] = round(($customerGroupPrice) ? $customerGroupPrice : $fallbackPrice, 2);
                        $assignedData['article'][0]['attribute']['bestofferautoacceptprice'] = $best_offer_auto_accept_price;
                        $assignedData['article'][0]['attribute']['bestofferminimumprice'] = $best_offer_minimum_price;

                        $view->data = $assignedData;
                    }
                    else
                    {
                        $assignedData['article']['attribute']['viaeabyprice'] = 0;
                        $assignedData['article']['attribute']['bestofferautoacceptprice'] = 0;
                        $assignedData['article']['attribute']['bestofferminimumprice'] = 0;

                        $view->data = $assignedData;
                    }
                }

                break;

            case 'save':
                $config = Shopware()->Plugins()->Backend()->viaebay()->Config();

                $requestData = $request->getParam('attribute');

                if($config->usebestoffer)
                {
                    if($requestData[0])
                    {
                        $articleID = $assignedData[0]['id'];
                        $articleDetailID = $assignedData[0]['mainDetailId'];
                        $taxData = $assignedData[0]['tax'];

                        $articlePrice = $requestData[0]['viaeabyprice'];

                        $best_offer_auto_accept_price = str_replace(',', '.', ($requestData[0]['bestofferautoacceptprice']) ? $requestData[0]['bestofferautoacceptprice'] : 0);
                        $best_offer_minimum_price = str_replace(',', '.', ($requestData[0]['bestofferminimumprice']) ? $requestData[0]['bestofferminimumprice'] : 0);


                        $viaeabymessage = "-";
                        $viaebayerror = false;

                        if($best_offer_auto_accept_price >= $articlePrice)
                        {

                            $viaebayerror = true;
                            $viaeabymessage = "BestOfferAutoAcceptPrice muss kleiner dem Verkaufspreis sein!!";
                        }
                        else if($best_offer_minimum_price >= $best_offer_auto_accept_price && $best_offer_minimum_price != 0)
                        {

                            $viaebayerror = true;
                            $viaeabymessage = "BestOfferMinimumPrice muss kleiner dem BestOfferAutoAcceptPrice sein!!";
                        }

                        $assignedData[0]['attribute']['viaeabyprice'] = $articlePrice;
                        $assignedData[0]['attribute']['bestofferautoacceptprice'] = $best_offer_auto_accept_price;
                        $assignedData[0]['attribute']['bestofferminimumprice'] = $best_offer_minimum_price;

                        $view->data = $assignedData;

                        if($viaebayerror == false)
                        {
                            $best_offer_auto_accept_price = $best_offer_auto_accept_price / (100 + $taxData['tax']) * 100;
                            $best_offer_minimum_price = $best_offer_minimum_price / (100 + $taxData['tax']) * 100;

                            Shopware_Controllers_Backend_viaebay::setDataFromVIAeBayArticleTable($articleDetailID, $best_offer_auto_accept_price, $best_offer_minimum_price);
                        }
                        else
                        {
                            //Shopware_Controllers_Backend_VIAeBay::setDataFromVIAeBayArticleTable($articleDetailID, 0, 0);
                        }
                    }
                }


                // normaler weg oder model-events?
                if(!$config->modeleventsarticles)
                {
                    $articleID = (int) $request->id ? : $view->data[0]['id'];

                    if($config->reviseinventorystatusondetailsave)
                    {
                        if($articleID)
                            if(Shopware()->Db()->fetchCol('SELECT swp_viaebay_id FROM swp_viaebay_articles WHERE articleID=' . $articleID . ' AND swp_viaebay_id IS NOT NULL'))
                                Shopware_Controllers_Backend_viaebay::updateArticleReviseInventoryStatusInVIAeBay($articleID);
                    }
                    else
                    {
                        if($articleID)
                            if(Shopware()->Db()->fetchCol('SELECT swp_viaebay_id FROM swp_viaebay_articles WHERE articleID=' . $articleID . ' AND swp_viaebay_id IS NOT NULL'))
                                Shopware_Controllers_Backend_viaebay::updateArticleInVIAeBay($articleID);
                    }
                }

                break;

            case 'saveDetail':
                // normaler weg oder model-events?
                if(!$config->modeleventsarticles)
                {
                    $articleID = (int) $request->articleId ? : $view->data['articleId'];

                    $config = Shopware()->Plugins()->Backend()->viaebay()->Config();

                    if($config->reviseinventorystatusondetailsave)
                    {
                        if($articleID)
                            if(Shopware()->Db()->fetchCol('SELECT swp_viaebay_id FROM swp_viaebay_articles WHERE articleID=' . $articleID . ' AND swp_viaebay_id IS NOT NULL'))
                                Shopware_Controllers_Backend_viaebay::updateArticleReviseInventoryStatusInVIAeBay($articleID);
                    }
                    else
                    {
                        if($articleID)
                            if(Shopware()->Db()->fetchCol('SELECT swp_viaebay_id FROM swp_viaebay_articles WHERE articleID=' . $articleID . ' AND swp_viaebay_id IS NOT NULL'))
                                Shopware_Controllers_Backend_viaebay::updateArticleInVIAeBay($articleID);
                    }
                }

                break;

            case 'createConfiguratorVariants':
                $articleID = (int) $request->articleId ? : $view->data['articleId'];

                if($articleID)
                {
                    if(Shopware()->Db()->fetchCol('SELECT swp_viaebay_id FROM swp_viaebay_articles WHERE articleID=' . $articleID . ' AND swp_viaebay_id IS NOT NULL'))
                    {
                        Shopware_Controllers_Backend_viaebay::deleteMultipleArticlesIneBayAction(array($articleID), true);
                    }
                }


            case 'saveConfiguratorSet':
                $articleID = (int) $request->articleId ? : $view->data['articleId'];

                if($articleID)
                {
                    if(Shopware()->Db()->fetchCol('SELECT swp_viaebay_id FROM swp_viaebay_articles WHERE articleID=' . $articleID))
                    {
                        Shopware_Controllers_Backend_viaebay::onArticleDetailSaveConfiguratorSet($articleID);
                    }
                }

                break;

            default:
                return;
        }
    }

    
    /**
     * update VIA-eBay article informations when edit article in the backend article list window
     */
    public function afterArticleList(Enlight_Event_EventArgs $args)
    {
        $this->checkLicense();

        $this->registerNamespace();

        $request = $args->getSubject()->Request();
        $view = $args->getSubject()->View();

        switch($request->getActionName())
        {
            case 'update':
                $articleID = (int) $request->articleId ? : $view->data['articleId'];

                $config = Shopware()->Plugins()->Backend()->viaebay()->Config();

                if($config->reviseinventorystatusondetailsave)
                {
                    if($articleID)
                        if(Shopware()->Db()->fetchCol('SELECT swp_viaebay_id FROM swp_viaebay_articles WHERE articleID=' . $articleID . ' AND swp_viaebay_id IS NOT NULL'))
                            Shopware_Controllers_Backend_viaebay::updateArticleReviseInventoryStatusInVIAeBay($articleID);
                }
                else
                {
                    if($articleID)
                        if(Shopware()->Db()->fetchCol('SELECT swp_viaebay_id FROM swp_viaebay_articles WHERE articleID=' . $articleID . ' AND swp_viaebay_id IS NOT NULL'))
                            Shopware_Controllers_Backend_viaebay::updateArticleInVIAeBay($articleID);
                }

                break;
            default:
                return;
        }
    }

    
    /**
     * delete article in VIA-eBay when they deleted in Shopware
     */
    public function before_onDeleteArticleBackend(Enlight_Hook_HookArgs $args)
    {
        $this->checkLicense();

        $this->registerNamespace();

        $request = $args->getSubject()->Request();

        $articleID = $request->getParam('articleId') ? $request->getParam('articleId') : $request->getParam('id');

        // prueft ob eine variante geloescht wird in shopware
        $model = Shopware()->Models()->find('Shopware\Models\Article\Detail', $request->getParam('id'));
        if($model instanceof \Shopware\Models\Article\Detail)
        {
            if($article === null)
            {
                $article = $model->getArticle();
            }

            if($model->getId() !== $article->getMainDetail()->getId())
            {
                Shopware_Controllers_Backend_viaebay::deleteVariantsInVIAeBay(array(array('id' => $request->getParam('id'))));

                Shopware()->Models()->flush();

                return;
            }
        }

        Shopware()->Models()->flush();

        // normaler weg oder model-events?
        $config = Shopware()->Plugins()->Backend()->viaebay()->Config();

        if(!$config->modeleventsarticles)
        {
            Shopware_Controllers_Backend_viaebay::deleteMultipleArticlesIneBayAction(array($articleID), true);
        }
    }

    
    /**
     * remove the swp_viaebay_container_id and swp_viaebay_id from the duplicated article
     */
    public function after_onDuplicateArticleBackend(Enlight_Hook_HookArgs $args)
    {
        $this->checkLicense();

        $this->registerNamespace();

        $caller = $args->getSubject();
        $request = $caller->Request();
        $view = $caller->View();

        Shopware()->Db()->exec('UPDATE swp_viaebay_articles SET swp_viaebay_container_id=NULL, swp_viaebay_id=NULL, best_offer_auto_accept_price=NULL, best_offer_minimum_price=NULL WHERE articleID=' . $view->articleId);
    }

    
    /**
     * delete deactivated categories and submit edited category names in VIA-eBay
     */
    public function after_onSaveDetailCategoryBackend(Enlight_Hook_HookArgs $args)
    {
        $this->checkLicense();

        $this->registerNamespace();

        $caller = $args->getSubject();
        $request = $caller->Request();

        $categoryID = $request->getParam('id');

        if(!$categoryID)
            return false;

        Shopware_Controllers_Backend_viaebay::updateCategoryInVIAeBay($categoryID);
    }

    
    /**
     * submit new category structure when moving an category
     */
    public function after_onMoveCategoryTreeItemBackend(Enlight_Hook_HookArgs $args)
    {
        $this->checkLicense();

        $this->registerNamespace();

        $caller = $args->getSubject();
        $request = $caller->Request();

        $categoryID = $request->getParam('id');
        $categoryParentID = $request->getParam('parentId', 1);

        Shopware_Controllers_Backend_viaebay::submitNewCategoryStructureByMovingCategory($categoryID, $categoryParentID);
    }

    
    /**
     * delete categories in VIA-eBay when they delet in Shopware
     */
    public function before_onDeleteCategoryBackend(Enlight_Hook_HookArgs $args)
    {
        $this->checkLicense();

        $this->registerNamespace();

        $caller = $args->getSubject();
        $request = $caller->Request();

        Shopware_Controllers_Backend_viaebay::deleteCategoriesStructureInVIAeBay($request->getParam('id'));
    }

    
    public function before_onDeleteVariants(Enlight_Hook_HookArgs $args)
    {
        $this->checkLicense();

        $this->registerNamespace();

        $caller = $args->getSubject();
        $request = $caller->Request();

        Shopware_Controllers_Backend_viaebay::deleteVariantsInVIAeBay($request->getParam('details', array(array('id' => $request->getParam('id')))));
    }

    
    /**
     * Cronjob for Order Import from VIA eBay
     */
    public function importOrdersCronjob(Shopware_Components_Cron_CronJob $job)
    {
        $this->checkLicense();

        $this->registerNamespace();

        require_once dirname(__FILE__) . '/Controllers/Backend/viaebay.php';

        Shopware_Controllers_Backend_viaebay::getVIAeBayOrdersAction('cron');

        return true;
    }

    
    /**
     * Cronjob to update Order-Data in VIA eBay
     */
    public function updateOrdersDataCronjob(Shopware_Components_Cron_CronJob $job)
    {
        $this->checkLicense();

        $this->registerNamespace();

        require_once dirname(__FILE__) . '/Controllers/Backend/viaebay.php';

        Shopware_Controllers_Backend_viaebay::updateVIAeBayOrderData();

        return true;
    }

    
    /**
     * Cronjob for complete Article Export to VIA eBay
     */
    public function exportArticlesCronjob(Shopware_Components_Cron_CronJob $job)
    {
        $this->checkLicense();

        $this->registerNamespace();

        require_once dirname(__FILE__) . '/Controllers/Backend/viaebay.php';

        Shopware_Controllers_Backend_viaebay::sendAllArticlesToeBayAction('cron');

        return true;
    }

    
    /**
     * Cronjob for only submitted Article Export to VIA eBay
     */
    public function exportOnlySubmittedArticlesCronjob(Shopware_Components_Cron_CronJob $job)
    {
        $this->checkLicense();

        $this->registerNamespace();

        require_once dirname(__FILE__) . '/Controllers/Backend/viaebay.php';

        Shopware_Controllers_Backend_viaebay::sendOnlySubmittedArticlesToeBayAction('cron');

        return true;
    }

    
    /**
     * Cronjob for only updated Article Export to VIA eBay
     */
    public function exportOnlyUpdatedArticlesCronjob(Shopware_Components_Cron_CronJob $job)
    {
        $this->checkLicense();

        $this->registerNamespace();

        require_once dirname(__FILE__) . '/Controllers/Backend/viaebay.php';

        Shopware_Controllers_Backend_viaebay::sendOnlyUpdatedArticlesToeBayAction('cron');

        return true;
    }

    
    /**
     * Cronjob for update Stock and Price for only submitted Article Export to VIA eBay
     */
    public function exportReviseInventoryStatusCronjob(Shopware_Components_Cron_CronJob $job)
    {
        $this->checkLicense();

        $this->registerNamespace();

        require_once dirname(__FILE__) . '/Controllers/Backend/viaebay.php';

        Shopware_Controllers_Backend_viaebay::sendReviseInventoryStatusToeBayAction('cron');

        Shopware_Controllers_Backend_viaebay::keepCronjobActive('VIA eBay Übertragene Artikel exportieren Preis/Menge', 'Fertig.');

        // damit der cron aktiv bleibt. sw4 hatte da irgendwie so seine macken.
        if(!$this->assertVersionGreaterThen("5.0.0"))
        {
            exit(0);
            return true;
        }
        else
        {
            return true;
            exit(0);
        }
    }

    
    /**
     * Backend Artikel-Übersicht (Filter, Suche hinzufügen) - SW4
     * 
     * @param Enlight_Event_EventArgs $args 
     */
    public function onShopwareControllersBackendArticleListSQLParts(Enlight_Event_EventArgs $args)
    {
        $return = $args->getReturn();
        $subject = $args->get('subject');

        $filterParams = $subject->Request()->getParam('filter', array());
        $filterBy = $subject->Request()->getParam('filterBy');
        $sort = $subject->Request()->getParam('sort', null);
        $sqlParams = $return[0];
        $filterSql = $return[1];
        $order = $return[4];


        // Search
        $filters = array();
        foreach($filterParams as $singleFilter)
        {
            $filters[$singleFilter['property']] = $singleFilter['value'];
        }

        if(isset($filters['search']))
        {
            $newSearchSqlPart = " details.id IN (SELECT DISTINCT articledetailsID FROM swp_viaebay_articles WHERE swp_viaebay_id LIKE :viaebayid) OR details.id IN (SELECT DISTINCT articledetailsID FROM swp_viaebay_articles WHERE swp_viaebay_container_id LIKE :viaebaycontainerid) OR details.ordernumber LIKE :orderNumber ";
            $filterSql = str_replace('details.ordernumber LIKE :orderNumber', $newSearchSqlPart, $filterSql);
            $searchFilter = '%' . $filters['search'] . '%';

            $sqlParams["viaebayid"] = $searchFilter;
            $sqlParams["viaebaycontainerid"] = $searchFilter;
        }


        // Filter
        if($filterBy == 'notviaebay')
        {
            $filterSql .= " AND (details.id NOT IN (SELECT DISTINCT articledetailsID FROM swp_viaebay_articles) OR details.id IN (SELECT DISTINCT articledetailsID FROM swp_viaebay_articles WHERE swp_viaebay_id IS NULL OR swp_viaebay_id = 0)) ";
        }

        if($filterBy == 'viaebay')
        {
            $filterSql .= " AND (details.id IN (SELECT DISTINCT articledetailsID FROM swp_viaebay_articles WHERE swp_viaebay_id IS NOT NULL AND swp_viaebay_id > 0)) ";
        }


        // Order
        // Make sure that whe don't get a cold here
        $columns = array('swp_viaebay_id', 'swp_viaebay_container_id');
        $directions = array('ASC', 'DESC');

        if(null !== $sort && in_array($sort[0]['property'], $columns) && in_array($sort[0]['direction'], $directions))
        {
            $sort = array_shift($sort);
            $order = 'va.' . $sort['property'] . ' ' . $sort['direction'];
        }


        $return[0] = $sqlParams;
        $return[1] = $filterSql;
        $return[4] = $order;
        
        return $return;
    }

    
    /**
     * Backend Artikel-Übersicht (Sortierung hinzufügen) - SW4
     * 
     * @param Enlight_Event_EventArgs $args 
     */
    public function onShopwareControllersBackendArticleListListSQL(Enlight_Event_EventArgs $args)
    {
        $return = $args->getReturn();
        $subject = $args->get('subject');

        $sort = $subject->Request()->getParam('sort', null);


        // Order
        // Make sure that whe don't get a cold here
        $columns = array('swp_viaebay_id', 'swp_viaebay_container_id');
        $directions = array('ASC', 'DESC');

        if(null !== $sort && in_array($sort[0]['property'], $columns) && in_array($sort[0]['direction'], $directions))
        {
            // add needed colums to sql
            $return = str_replace('details.id as id,', 'details.id as id, va.swp_viaebay_id, va.swp_viaebay_container_id,', $return);
            $return = str_replace('ON tax.id = articles.taxID', 'ON tax.id = articles.taxID LEFT JOIN swp_viaebay_articles AS va ON details.id = va.articledetailsID', $return);
        }


        return $return;
    }

    
    /**
     * Backend Artikel-Übersicht (Filter, Suche hinzufügen) - SW5
     * 
     * @param Enlight_Event_EventArgs $args 
     */
    public function onSwagMultiEditProductGrammarGetGrammarFilterGrammar(Enlight_Event_EventArgs $args)
    {
        $return = $args->getReturn();

        if($this->assertVersionGreaterThen("5.0.0"))
        {
            $return['nullaryOperators']['VIAEBAY'] = '';
            $return['nullaryOperators']['NOTVIAEBAY'] = '';
        }

        return $return;
    }

    
    /**
     * Backend Artikel-Übersicht (Filter, Suche hinzufügen) - SW5
     * 
     * @param Enlight_Event_EventArgs $args 
     */
    public function onSwagMultiEditProductDqlHelperGetDqlFromTokensTokenNullaryOperators(Enlight_Event_EventArgs $args)
    {
        if($this->assertVersionGreaterThen("5.0.0"))
        {
            $currentToken = $args->get('currentToken');

            $_viaebay_ids = Shopware()->Db()->fetchCol(
                    'SELECT articledetailsID FROM swp_viaebay_articles WHERE swp_viaebay_id IS NOT NULL AND swp_viaebay_id > 0'
            );

            if(is_array($_viaebay_ids) && count($_viaebay_ids) > 0)
            {
                if($currentToken['type'] == 'nullaryOperators' && $currentToken['token'] == 'VIAEBAY')
                {
                    return ' detail.id IN (' . implode(', ', $_viaebay_ids) . ')';
                }

                if($currentToken['type'] == 'nullaryOperators' && $currentToken['token'] == 'NOTVIAEBAY')
                {
                    return ' detail.id NOT IN (' . implode(', ', $_viaebay_ids) . ')';
                }                
            }
            else
            {
                if($currentToken['type'] == 'nullaryOperators' && ($currentToken['token'] == 'VIAEBAY' || $currentToken['token'] == 'NOTVIAEBAY'))
                {
                    return ' detail.id > 0 '; // muss so sein als workaround, da es sonst zu problmen mit dem filter kommt wenn noch keine artikel übertragen
                }
            }
        }

        //return ' detail.id > 0 '; // muss so sein als workaround, da es sonst zu problmen mit dem filter kommt wenn noch keine artikel übertragen
    }

    
    /**
     * Backend Artikel-Übersicht (Filter, Suche hinzufügen) - SW5
     * 
     * @param Enlight_Event_EventArgs $args 
     */
    public function onSwagMultiEditProductDqlHelperGetDqlFromTokensFilterTokens(Enlight_Event_EventArgs $args)
    {
        $return = $args->getReturn();


        if($this->assertVersionGreaterThen("5.0.0"))
        {
            if(is_array($return['tokens']) && count($return['tokens']) > 0 && is_array($return['params']) && count($return['params']) > 0)
            {
                $old_tokens = $return['tokens'];
                $new_tokens = array();


                $_viaebay_ids = Shopware()->Db()->fetchCol(
                        'SELECT articledetailsID FROM swp_viaebay_articles WHERE swp_viaebay_id LIKE ("%' . $return['params'][0] . '%") OR swp_viaebay_container_id LIKE ("%' . $return['params'][0] . '%")'
                );


                if(is_array($_viaebay_ids) && count($_viaebay_ids) > 0)
                {
                    foreach($old_tokens as $key => $val)
                    {
                        if($val == ')')
                        {
                            $new_tokens[] = ' OR detail.id IN (' . implode(', ', $_viaebay_ids) . ')';
                        }

                        $new_tokens[] = $val;
                    }
                    reset($old_tokens);


                    if(is_array($new_tokens) && count($new_tokens) > 0)
                    {
                        $return['tokens'] = $new_tokens;
                    }
                }
            }
        }

        return $return;
    }

    
    // Model Events fuer WaWi und Co.
    // Artikel - Insert
    /**
     * Listener fuer pre* Event wenn ein Model neu in der Datenbank hinzugefuegt wird
     */
    public function prePersistArticle(Enlight_Event_EventArgs $arguments)
    {
        // hier sind noch nicht alle daten da
        /*
          $this->checkLicense();

          $this->registerNamespace();

          require_once dirname(__FILE__).'/Controllers/Backend/viaebay.php'; *


          $modelManager = $arguments->get('entityManager');
          $model = $arguments->get('entity');

          Shopware()->Models()->flush();

          //__d($model->getId(), 'pre insert article id');
          $articleID = $model->getId();
         */
    }

    
    /**
     * Listener fuer post* Event wenn ein Model neu in der Datenbank hinzugefuegt wird
     */
    public function postPersistArticle(Enlight_Event_EventArgs $arguments)
    {
        // derzeit noch nicht benoetigt
        /*
          $this->checkLicense();

          $this->registerNamespace();

          require_once dirname(__FILE__).'/Controllers/Backend/viaebay.php';


          $modelManager = $arguments->get('entityManager');
          $model = $arguments->get('entity');

          Shopware()->Models()->flush();

          //__d($model->getId(), 'post insert article id');
          $articleID = $model->getId();
         */
    }

    
    // Artikel - Update
    /**
     * Listener fuer pre* Event wenn ein Model neu in der Datenbank aktualisiert wird
     */
    public function preUpdateArticle(Enlight_Event_EventArgs $arguments)
    {
        // hier sind noch nicht alle daten aktualisiert
        /*
          $this->checkLicense();

          $this->registerNamespace();

          require_once dirname(__FILE__).'/Controllers/Backend/viaebay.php';


          $modelManager = $arguments->get('entityManager');
          $model = $arguments->get('entity');

          Shopware()->Models()->flush();

          //__d($model->getId(), 'pre update article id');
          $articleID = $model->getId();
         */
    }

    
    /**
     * Listener fuer post* Event wenn ein Model neu in der Datenbank aktualisiert wird
     */
    public function postUpdateArticle(Enlight_Event_EventArgs $arguments)
    {
        $this->checkLicense();

        $this->registerNamespace();


        // normaler weg oder model-events?
        $config = Shopware()->Plugins()->Backend()->viaebay()->Config();

        if($config->modeleventsarticles)
        {
            require_once dirname(__FILE__) . '/Controllers/Backend/viaebay.php';


            $modelManager = $arguments->get('entityManager');
            $model = $arguments->get('entity');

            Shopware()->Models()->flush();

            //__d($model->getId(), 'post update article id');
            $articleID = $model->getId();

            if($config->reviseinventorystatusondetailsave)
            {
                if($articleID)
                    if(Shopware()->Db()->fetchCol('SELECT swp_viaebay_id FROM swp_viaebay_articles WHERE articleID=' . $articleID . ' AND swp_viaebay_id IS NOT NULL'))
                        Shopware_Controllers_Backend_viaebay::updateArticleReviseInventoryStatusInVIAeBay($articleID);
            }
            else
            {
                if($articleID)
                    if(Shopware()->Db()->fetchCol('SELECT swp_viaebay_id FROM swp_viaebay_articles WHERE articleID=' . $articleID . ' AND swp_viaebay_id IS NOT NULL'))
                        Shopware_Controllers_Backend_viaebay::updateArticleInVIAeBay($articleID);
            }
        }
    }

    
    // Artikel - Remove
    /**
     * Listener fuer pre* Event wenn ein Model neu in der Datenbank geloescht wird
     */
    public function preRemoveArticle(Enlight_Event_EventArgs $arguments)
    {
        $this->checkLicense();

        $this->registerNamespace();


        // normaler weg oder model-events?
        $config = Shopware()->Plugins()->Backend()->viaebay()->Config();

        if($config->modeleventsarticles)
        {
            require_once dirname(__FILE__) . '/Controllers/Backend/viaebay.php';

            $modelManager = $arguments->get('entityManager');
            $model = $arguments->get('entity');

            //Shopware()->Models()->flush();
            //__d($model->getId(), 'pre remove article id');
            $articleID = $model->getId();

            Shopware()->Models()->flush();

            Shopware_Controllers_Backend_viaebay::deleteMultipleArticlesIneBayAction(array($articleID), true, true);
        }
    }

    
    /**
     * Listener fuer post* Event wenn ein Model neu in der Datenbank geloescht wird
     */
    public function postRemoveArticle(Enlight_Event_EventArgs $arguments)
    {
        // hier sind dann schon alle daten weg
        /*
          $this->checkLicense();

          $this->registerNamespace();

          require_once dirname(__FILE__).'/Controllers/Backend/viaebay.php';


          $modelManager = $arguments->get('entityManager');
          $model = $arguments->get('entity');

          Shopware()->Models()->flush();

          //__d($model->getId(), 'post remove article id');
          $articleID = $model->getId();
         */
    }

    
    // Bestellung - Update
    /**
     * Listener fuer post* Event wenn ein Model neu in der Datenbank aktualisiert wird
     */
    public function postUpdateOrder(Enlight_Event_EventArgs $arguments)
    {
        $this->checkLicense();

        $this->registerNamespace();


        // normaler weg oder model-events?
        $config = Shopware()->Plugins()->Backend()->viaebay()->Config();

        if($config->modeleventsorders)
        {
            require_once dirname(__FILE__) . '/Controllers/Backend/viaebay.php';


            $modelManager = $arguments->get('entityManager');
            $model = $arguments->get('entity');

            // Auskommentiert, da diese Funktion schon von Shopware selber aufgerufen wird bevor
            // das Plugin eingreift. Dies hat bei einem Kunden zu Problemen in der Stapelverarbeitung
            // bei den Bestellungen im Backend gefuehrt
            // Shopware()->Models()->flush();
            //__d($model->getId(), 'post update article id');
            $orderID = $model->getId();

            Shopware_Controllers_Backend_viaebay::updateVIAeBayOrderByModelEvents($orderID);
        }
    }

    
    /**
     * Shopware standard license check method
     */
    public function checkLicense()
    {
        return true;
    }
}
?>