<?php
/*
  ##############################################################################
  # Plugin for Shopware
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # @version $Id: VIAeBay.php 5795 2015-04-16 11:39:16Z s.thamm $
  # @copyright:   found in /lic/copyright.txt
  #
  ##############################################################################
 */

	require_once dirname(__FILE__).'/VIAeBayRESTClient.php';

	/**
	 * VIAeBay API Class
	 */
	class VIAeBay {
		##################
		### MAIN START ###
		##################

		/**
		 * register VIAeBay properties and get cookie
		 */
		public function __construct() {
			$config = Shopware()->Plugins()->Backend()->viaebay()->Config();

			if($config->testmode == true) {
				$this->ApiUrl = 'https://sandboxapi.via.de/publicapi/v1/api.svc/';
				$this->authenticationUrl = 'https://sandboxapi.via.de/Authentication_JSON_AppService.axd/Login';
			} else {
				$this->ApiUrl = 'https://ebayapi.via.de/PublicApi/v1/Api.svc/';
				$this->authenticationUrl = 'https://ebayapi.via.de/Authentication_JSON_AppService.axd/Login';
			}
                        
                        
                        $plg_version = Shopware_Plugins_Backend_viaebay_Bootstrap::getVersion();
                        $shop_version = 'Shopware|'.Shopware()->Config()->get('version');
                        

			$this->authenticationHeader = array('Content-Type: application/json', 'Version: '.(string)$plg_version, 'Vendor: '.(string)$shop_version);
			$this->authenticationBody = json_encode(array('userName' => $config->username, 'password' => $config->password, 'createPersistentCookie' => 'false'));

			$this->productsUrl = $this->ApiUrl.'Products';
			$this->productsImagesUrl = $this->ApiUrl.'ProductImages';
			$this->productsSpecificsUrl = $this->ApiUrl.'ProductSpecifics';
			$this->optionalProductAttributes = $this->ApiUrl.'OptionalProductAttributes';
			$this->productsVariationsUrl = $this->ApiUrl.'ProductVariations';
			$this->productVariationSpecificsUrl = $this->ApiUrl.'ProductVariationSpecifics';
                        //$this->productVariationImagesUrl = $this->ApiUrl.'ProductVariationImages';
                        $this->productVariationImagesUrl = $this->ApiUrl.'ProductVariationPictures';
			$this->discountOffersUrl = $this->ApiUrl.'DiscountOffers';
                        $this->reviseInventoryStatusUrl = $this->ApiUrl.'ReviseInventoryStatus';

			$this->catalogsUrl = $this->ApiUrl.'Catalogs';

                        // only for debug !!! - liefert dann immer alle bestellung
                        //$this->salesOrdersUrl = $this->ApiUrl.'SalesOrders?&$expand=SalesOrderItems,Address,ShippingAddress,Buyer';
                        
                        // liefert nur bestellungen die in viaebay noch keine ForeignOrderId haben, sprich noch nicht importiert wurden
			$this->salesOrdersUrl = $this->ApiUrl.'SalesOrders?&$expand=SalesOrderItems,Address,ShippingAddress,Buyer&$filter=(ForeignOrderId+eq+null)+or+(ForeignOrderId+eq+\'\')';
                        
                        $this->salesOrderItemsUrl = $this->ApiUrl.'SalesOrderItems';
			$this->updateSalesOrdersUrl = $this->ApiUrl.'SalesOrders';

			$this->RESTClient = new VIAeBayRESTClient();

			$this->cookie = $this->RESTClient->post($this->authenticationUrl, $this->authenticationHeader, $this->authenticationBody);

			$this->jsonHeader = array('Content-Type: application/json','Accept: application/json' , 'SubscriptionToken: '.$config->subscriptiontoken, 'Cookie: '.$this->cookie);
		}

		################
		### MAIN END ###
		################

		#####################
		### PRODUCT START ###
		#####################

		public function getProductType($ressourceID) {
			$response = $this->RESTClient->get($this->productsUrl.'('.$ressourceID.'L)/ProductType', $this->jsonHeader, json_encode($request));

			return (string)$response->d->ProductType;
		}

		/**
		 * set base product ressource data
		 * @param Array $articleData Article Data
		 * @param String $type Product type
		 * @return Int ressource ID for created product
		 */
		public function setProducts($articleData, $type) {
			$request = array(
				'ForeignId' => $articleData['ForeignId'],
				'Title' => $articleData['Title'],
				'Description' => $articleData['Description'],
				'Price' => (string)$articleData['Price'],
				'StockAmount' => $articleData['StockAmount'],
				'Ean' => $articleData['Ean'],
				'ProductType' => $type,
				'UnitQuantity' => $articleData['UnitQuantity'],
				'UnitType' => $articleData['UnitType'],
				'VatPercent' => $articleData['VatPercent'],
				'ShortDescription' => $articleData['ShortDescription']
			);
                        
                        
                        if(!isset($articleData['BestOfferNOTSUPPORTED'])) {
                        
                            if(isset($articleData['BestOfferAutoAcceptPrice']) && $articleData['BestOfferAutoAcceptPrice'] != '' 
                                    && $articleData['BestOfferAutoAcceptPrice'] > 0 && $articleData['BestOfferAutoAcceptPrice'] != false) {

                                $request['BestOfferAutoAcceptPrice'] = (string)$articleData['BestOfferAutoAcceptPrice'];
                                $request['BestOfferMinimumPrice'] = (string)$articleData['BestOfferMinimumPrice'];

                            }
                            
                        }
                        

			$response = $this->RESTClient->post($this->productsUrl, $this->jsonHeader, json_encode($request));

			if($articleData['PsuedoPrice'])
				$this->RESTClient->post($this->discountOffersUrl, $this->jsonHeader, json_encode(array('ProductId' => $response->d->Id, 'Price' => (string)$articleData['PsuedoPrice'], 'Type' => '1')));
                        
			return $response->d->Id;
		}

		/**
		 * update base product ressource data
		 * @param Array $articleData Article Data
		 * @param String $type Product type
		 * @return Int ressource ID for created product
		 */
		public function updateProducts($articleData, $type, $ressourceID) {
                    
			$this->RESTClient->put($this->productsUrl.'('.$ressourceID.'L)/ForeignId', $this->jsonHeader, json_encode(array('ForeignId' => $articleData['ForeignId'])));
			$this->RESTClient->put($this->productsUrl.'('.$ressourceID.'L)/Title', $this->jsonHeader, json_encode(array('Title' => $articleData['Title'])));
			$this->RESTClient->put($this->productsUrl.'('.$ressourceID.'L)/Description', $this->jsonHeader, json_encode(array('Description' => $articleData['Description'])));
			$this->RESTClient->put($this->productsUrl.'('.$ressourceID.'L)/Price', $this->jsonHeader, json_encode(array('Price' => (string)$articleData['Price'])));
			$this->RESTClient->put($this->productsUrl.'('.$ressourceID.'L)/StockAmount', $this->jsonHeader, json_encode(array('StockAmount' => $articleData['StockAmount'])));
			$this->RESTClient->put($this->productsUrl.'('.$ressourceID.'L)/Ean', $this->jsonHeader, json_encode(array('Ean' => $articleData['Ean'])));
			$this->RESTClient->put($this->productsUrl.'('.$ressourceID.'L)/ProductType', $this->jsonHeader, json_encode(array('ProductType' => $type)));
			$this->RESTClient->put($this->productsUrl.'('.$ressourceID.'L)/VatPercent', $this->jsonHeader, json_encode(array('VatPercent' => $articleData['VatPercent'])));
			$this->RESTClient->put($this->productsUrl.'('.$ressourceID.'L)/ShortDescription', $this->jsonHeader, json_encode(array('ShortDescription' => $articleData['ShortDescription'])));

			if($articleData['UnitQuantity'] && $articleData['UnitType']) {
                            // $this->RESTClient->put($this->productsUrl.'('.$ressourceID.'L)', $this->jsonHeader, json_encode(array('UnitQuantity' => $articleData['UnitQuantity'], 'UnitType' => $articleData['UnitType'])));
                            	
                            $this->RESTClient->put($this->productsUrl.'('.$ressourceID.'L)/UnitType', $this->jsonHeader, json_encode(array('UnitType' => $articleData['UnitType'])));
                            $this->RESTClient->put($this->productsUrl.'('.$ressourceID.'L)/UnitQuantity', $this->jsonHeader, json_encode(array('UnitQuantity' => $articleData['UnitQuantity'])));
                                                        
                        } else {
                            
                            $this->RESTClient->put($this->productsUrl.'('.$ressourceID.'L)/UnitQuantity', $this->jsonHeader, json_encode(array('UnitQuantity' => 0)));
                            $this->RESTClient->put($this->productsUrl.'('.$ressourceID.'L)/UnitType', $this->jsonHeader, json_encode(array('UnitType' => '')));
                            
                        }
                        
                        
                        if(!isset($articleData['BestOfferNOTSUPPORTED'])) {
                        
                            if(isset($articleData['BestOfferAutoAcceptPrice']) && $articleData['BestOfferAutoAcceptPrice'] != '' 
                                    && $articleData['BestOfferAutoAcceptPrice'] > 0 && $articleData['BestOfferAutoAcceptPrice'] != false) {

                                    $this->RESTClient->put($this->productsUrl.'('.$ressourceID.'L)/BestOfferAutoAcceptPrice', $this->jsonHeader, json_encode(array('BestOfferAutoAcceptPrice' => (string)$articleData['BestOfferAutoAcceptPrice'])));
                                    $this->RESTClient->put($this->productsUrl.'('.$ressourceID.'L)/BestOfferMinimumPrice', $this->jsonHeader, json_encode(array('BestOfferMinimumPrice' => (string)$articleData['BestOfferMinimumPrice'])));

                            } else {

                                    $this->RESTClient->put($this->productsUrl.'('.$ressourceID.'L)/BestOfferAutoAcceptPrice', $this->jsonHeader, json_encode(array('BestOfferAutoAcceptPrice' => NULL)));
                                    $this->RESTClient->put($this->productsUrl.'('.$ressourceID.'L)/BestOfferMinimumPrice', $this->jsonHeader, json_encode(array('BestOfferMinimumPrice' => NULL)));

                            }
                        
                        }
                        

			$result = $this->RESTClient->get($this->productsUrl.'('.$ressourceID.'L)/DiscountOffers', $this->jsonHeader, '');

			if($articleData['PsuedoPrice']) {
				if($result->d[0]->Id)
					$this->RESTClient->put($this->discountOffersUrl.'('.$result->d[0]->Id.'L)', $this->jsonHeader, json_encode(array('ProductId' => $ressourceID, 'Price' => (string)$articleData['PsuedoPrice'], 'Type' => '1')));
				else
					$this->RESTClient->post($this->discountOffersUrl, $this->jsonHeader, json_encode(array('ProductId' => $ressourceID, 'Price' => (string)$articleData['PsuedoPrice'], 'Type' => '1')));
			} else
				if($result->d[0]->Id)
					$this->RESTClient->delete($this->discountOffersUrl.'('.$result->d[0]->Id.'L)', $this->jsonHeader, '');
		}
                
                /**
		 * update stock and price ressource data
		 * @param Int $productId Article Data
		 * @param Int $productVariationId Product type
                 * @param Int $stockAmount Product type
                 * @param Float $price Product type
		 */
		public function reviseInventoryStatus($productId, $productVariationId, $stockAmount, $price, $pseudoPrice = false) {
                    
                    if ($productVariationId !== false) {
                    
                        $result = $this->RESTClient->post($this->reviseInventoryStatusUrl.'?productId='.$productId.'L&productVariationId='.$productVariationId.'L&stockAmount='.$stockAmount.'&price='.(string)$price.'m', $this->jsonHeader, json_encode(array()));
                        
                    } else {
                        
                        $result = $this->RESTClient->post($this->reviseInventoryStatusUrl.'?productId='.$productId.'L&stockAmount='.$stockAmount.'&price='.(string)$price.'m', $this->jsonHeader, json_encode(array()));
                        
                    }
                    
                    
                    // damit pseudopreis auch beim reviseInventoryStatus aktualisiert werden
                    $resultPseudoPrice = $this->RESTClient->get($this->productsUrl.'('.$productId.'L)/DiscountOffers', $this->jsonHeader, '');

                    if($pseudoPrice != false && $pseudoPrice > 0)
                    {
                        if($resultPseudoPrice->d[0]->Id)
                        {
                            $this->RESTClient->put($this->discountOffersUrl.'('.$resultPseudoPrice->d[0]->Id.'L)', $this->jsonHeader, json_encode(array('ProductId' => $productId, 'Price' => (string)$pseudoPrice, 'Type' => '1')));
                        }
                        else
                        {
                            $this->RESTClient->post($this->discountOffersUrl, $this->jsonHeader, json_encode(array('ProductId' => $productId, 'Price' => (string)$pseudoPrice, 'Type' => '1')));
			}
                    }
                    else
                    {
                        if($resultPseudoPrice->d[0]->Id)
                        {
                            $this->RESTClient->delete($this->discountOffersUrl.'('.$resultPseudoPrice->d[0]->Id.'L)', $this->jsonHeader, '');
                        }                  
                    }
		}

		/**
		 * Delete the Product in VIA-eBay
		 * @param Int $articleRessourceID article ressource ID from VIA eBay
		 */
		public function deleteProduct($articleRessourceID) {
			return $this->RESTClient->delete($this->productsUrl.'('.$articleRessourceID.'L)', $this->jsonHeader, '');
		}

		/**
		 * set images to the product ressource
		 * @param Array $images Array of image urls
		 * @param Int $id product ressource id
		 */
		public function setProductImages($images, $id) {
			$type = 1;

			foreach($images as $image) {
				$request = array(
					'ProductId' => $id,
					'ImageUrl' => $image,
					'Type' => $type
				);

				$this->RESTClient->post($this->productsImagesUrl, $this->jsonHeader, json_encode($request));

				if($type == 1) {
					$type++;

					$request = array(
						'ProductId' => $id,
						'ImageUrl' => $image,
						'Type' => $type
					);

					$this->RESTClient->post($this->productsImagesUrl, $this->jsonHeader, json_encode($request));
				}

				$type++;
			}
		}

		/**
		 * delete images from the product ressource
		 * @param Int $id product ressource id
		 */
		public function deleteProductImages($id) {
			$response = $this->RESTClient->get($this->productsUrl.'('.$id.'L)/ProductImages', $this->jsonHeader, '');

			if(isset($response->d) && is_array($response->d) && count($response->d)>0)
				foreach($response->d as $key => $image)
					$this->RESTClient->delete($this->productsImagesUrl.'('.$image->Id.'L)', $this->jsonHeader, '');
		}

		/**
		 * set product attributes to an single product in a set
		 * @param Int $articleResponseId Product Ressource ID
		 * @param Array $attributes Product Attributes (Configurator)
		 */
		public function setProductSpecifics($articleResponseId, $attributes) {
			foreach($attributes as $group => $value) {
				$foundForUpdate = false;

				$request = array(
					'ProductId' => $articleResponseId,
					'Name' => $group,
					'Value' => $value
				);

				$result = $this->RESTClient->get($this->productsUrl.'('.$articleResponseId.'L)/ProductSpecifics', $this->jsonHeader);

				foreach($result->d as $productSpecific) {
					if($productSpecific->Name == $group) {
						$foundForUpdate = true;

						$this->RESTClient->put($this->productsSpecificsUrl.'('.$productSpecific->Id.'L)', $this->jsonHeader, json_encode($request));
					}
				}

				if(!$foundForUpdate)
					$this->RESTClient->post($this->productsSpecificsUrl, $this->jsonHeader, json_encode($request));
			}
		}
                
                /**
		 * delete product attributes from an single product in a set
		 * @param Int $articleResponseId Product Ressource ID
		 */
		public function deleteProductSpecifics($articleResponseId) {
                        
                        $result = $this->RESTClient->get($this->productsUrl.'('.$articleResponseId.'L)/ProductSpecifics', $this->jsonHeader);

			foreach($result->d as $productSpecific) {
                                    
                            $delete_result = $this->RESTClient->delete($this->productsSpecificsUrl.'('.$productSpecific->Id.'L)', $this->jsonHeader, '');
			
			}
		}

		public function setProductOptionalAttributes($articleResponseId, $optionalAttributes) {
			foreach($optionalAttributes as $group => $value) {
				$foundForUpdate = false;

				$request = array(
					'ProductId' => $articleResponseId,
					'Name' => $group,
					'Value' => (string)$value // muss laut viaebay-api als string-datentyp uebermittelt werden
				);

				$result = $this->RESTClient->get($this->productsUrl.'('.$articleResponseId.'L)/OptionalProductAttributes', $this->jsonHeader);

				foreach($result->d as $optionalProductAttributes) {
					if($optionalProductAttributes->Name == $group) {
						$foundForUpdate = true;

						$this->RESTClient->put($this->optionalProductAttributes.'('.$optionalProductAttributes->Id.'L)', $this->jsonHeader, json_encode($request));
					}
				}

				if(!$foundForUpdate)
					$this->RESTClient->post($this->optionalProductAttributes, $this->jsonHeader, json_encode($request));
			}
		}
                
                public function setBrandAndMpn($ressourceID, $brand, $mpn) {
                    
                        $this->RESTClient->put($this->productsUrl.'('.$ressourceID.'L)/Brand', $this->jsonHeader, json_encode(array('Brand' => $brand)));
                        $this->RESTClient->put($this->productsUrl.'('.$ressourceID.'L)/Mpn', $this->jsonHeader, json_encode(array('Mpn' => $mpn)));
		}
                
                public function setBrandAndMpnVariation($ressourceID, $brand, $mpn, $ean) {
                    
                        //$this->RESTClient->put($this->productsVariationsUrl.'('.$ressourceID.'L)/Brand', $this->jsonHeader, json_encode(array('Brand' => $brand)));
                        $this->RESTClient->put($this->productsVariationsUrl.'('.$ressourceID.'L)/Mpn', $this->jsonHeader, json_encode(array('Mpn' => $mpn)));
                        $this->RESTClient->put($this->productsVariationsUrl.'('.$ressourceID.'L)/Ean', $this->jsonHeader, json_encode(array('Ean' => $ean)));
		}

		/**
		 * set product variation for an products with variants
		 * @param Array $articleVariationsData Article Variation Data
		 * @return Int VIA eBay Variation Ressource ID
		 */
		public function setProductVariations($articleVariationsData) {
			$request = array(
				'ProductId' => $articleVariationsData['ProductId'],
				'Price' => (string)$articleVariationsData['Price'],
				'StockAmount' => $articleVariationsData['StockAmount'],
				'Sku' => $articleVariationsData['Sku']
			);

			$response = $this->RESTClient->post($this->productsVariationsUrl, $this->jsonHeader, json_encode($request));

			return $response->d->Id;
		}

		/**
		 * set product variation for an products with variants
		 * @param Int $VIAeBayID VIA-eBay Article Ressource ID
		 * @param Array $articleVariationsData Article Variation Data
		 * @return Int VIA eBay Variation Ressource ID
		 */
		public function updateProductVariations($ressourceID, $articleVariationsData) {
			$this->RESTClient->put($this->productsVariationsUrl.'('.$ressourceID.'L)/Price', $this->jsonHeader, json_encode(array('Price' => (string)$articleVariationsData['Price'])));
			$this->RESTClient->put($this->productsVariationsUrl.'('.$ressourceID.'L)/StockAmount', $this->jsonHeader, json_encode(array('StockAmount' => $articleVariationsData['StockAmount'])));
			$this->RESTClient->put($this->productsVariationsUrl.'('.$ressourceID.'L)/Sku', $this->jsonHeader, json_encode(array('Sku' => $articleVariationsData['Sku'])));
		}

		public function deleteProductVariations($articleRessourceID) {
			// eBay kann keine Variationen löschen, daher Menge 0 übergeben
			$this->RESTClient->put($this->productsVariationsUrl.'('.$articleRessourceID.'L)/StockAmount', $this->jsonHeader, json_encode(array('StockAmount' => (int)0)));
		}

		/**
		 * set the specifics to the product variation
		 * @param Int $articleResponseId VIA-eBay Ressource ID for the product variation
		 * @param Array $attributes Attributes for the product variant
		 */
		public function setProductVariationSpecifics($articleResponseId, $attributes) {
			foreach($attributes as $group => $value) {
				$request = array(
					'ProductVariationId' => $articleResponseId,
					'Name' => $group,
					'Value' => $value
				);

				$this->RESTClient->post($this->productVariationSpecificsUrl, $this->jsonHeader, json_encode($request));
			}
		}
                
                /**
		 * set the images to the product variation
		 * @param Int $articleResponseId VIA-eBay Ressource ID for the product variation
		 * @param Array $images Images for the product variant
		 */
		public function setProductVariationImages($articleResponseId, $images) {
                        
                        $position = 1;
                    
			foreach($images as $img) {
				$request = array(
					'ProductVariationId' => $articleResponseId,
					'ImageUrl' => $img,
					'ImagePosition' => $position
				);
                                
                                $position++;

				$this->RESTClient->post($this->productVariationImagesUrl, $this->jsonHeader, json_encode($request));
			}
		}
                
                /**
		 * delete images from the product variation
		 * @param Int $articleResponseId VIA-eBay Ressource ID for the product variation
		 */
		public function deleteProductVariationImages($articleResponseId) {
			$response = $this->RESTClient->get($this->productVariationImagesUrl, $this->jsonHeader, '');

			if(isset($response->d) && is_array($response->d) && count($response->d)>0) {
                                @set_time_limit(0);                            
				foreach($response->d as $image) {
                                    if($image->ProductVariationId == $articleResponseId)
                                    {
                                        $this->RESTClient->delete($this->productVariationImagesUrl.'('.$image->Id.'L)', $this->jsonHeader, '');
                                    }
                                }
                        }
		}

		/**
		 * assign products to catalogs
		 * @param Int $articleRessourceID
		 * @param Int $catalogRessourceID
		 */
		public function setProductCatalogs($articleRessourceID, $catalogRessourceID) {
			$this->RESTClient->post($this->productsUrl.'('.$articleRessourceID.'L)/$links/Catalogs', $this->jsonHeader, json_encode(array('uri' => $this->ApiUrl.'Catalogs('.$catalogRessourceID.'L)')));
		}

		/**
		 * check assignment between product and catalog and delete it
		 * @param Int $articleRessourceID
		 */
		public function deleteProductCatalogs($articleRessourceID) {
			$result = $this->RESTClient->get($this->productsUrl.'('.$articleRessourceID.'L)/$links/Catalogs', $this->jsonHeader, '');

			if($result !== false) {
				if(is_array($result->d) && count($result->d) > 0) {
					foreach($result->d as $catalog) {
						preg_match('/\((\d+)L\)/', $catalog->uri, $matches);

						if($matches[1])
							$this->RESTClient->delete($this->productsUrl.'('.$articleRessourceID.'L)/$links/Catalogs('.$matches[1].'L)', $this->jsonHeader, '');
					}
				}
			}
		}

		###################
		### PRODUCT END ###
		###################

		#####################
		### CATALOG START ###
		#####################

		/**
		 * set catalog ressource to VIA-eBay
		 * @param Array $catalogData Category Data
		 * @return Int Catalog Ressource ID
		 */
		public function setCatalogs($catalogData) {
			$request = array(
				'ForeignId' => $catalogData['ForeignId'],
				'Name' => substr($catalogData['Name'], 0, 30),
				'IsRootLevel' => $catalogData['IsRootLevel']
			);

			$response = $this->RESTClient->post($this->catalogsUrl, $this->jsonHeader, json_encode($request));

			return $response->d->Id;
		}

		/**
		 * update catalog data in VIA-eBay
		 * @param Int $catalogRessourceID category/catalog ressource id from VIAeBay
		 * @param Array $catalogData Array of category data
		 */
		public function updateCatalogs($catalogRessourceID, $catalogData) {
			$response = $this->RESTClient->put($this->catalogsUrl.'('.$catalogRessourceID.'L)/Name', $this->jsonHeader, json_encode(array('Name' => $catalogData['Name'])));
		}

		/**
		 * delete catalog in VIA-eBay
		 * @param Int $catalogRessourceID category/catalog ressource id from VIAeBay
		 */
		public function deleteCatalogs($catalogRessourceID) {
			$this->RESTClient->delete($this->catalogsUrl.'('.$catalogRessourceID.'L)', $this->jsonHeader, '');
		}

		/**
		 * set Catalog relations to other Catalogs
		 * @param Int $parentRessourceID
		 * @param Int $childRessourceID
		 */
		public function setCatalogsRelations($parentRessourceID, $childRessourceID) {
			$this->RESTClient->post($this->catalogsUrl.'('.$parentRessourceID.'L)/$links/ChildCatalogs', $this->jsonHeader, json_encode(array('uri' => $this->ApiUrl.'Catalogs('.$childRessourceID.'L)')));
		}

		/**
		 * update the catalog relations to other catalogs
		 * @param Int $parentRessourceID
		 * @param Int $childRessourceID
		 */
		public function updateCatalogsRelations($parentRessourceID, $childRessourceID) {
			$oldParentRessourceID = $this->RESTClient->get($this->catalogsUrl.'('.$childRessourceID.'L)/$links/ParentCatalogs', $this->jsonHeader);

			preg_match('/\((\d+)L\)/', $oldParentRessourceID->d[0]->uri, $matches);

			if($matches[1])
				$this->deleteCatalogsRelations($matches[1], $childRessourceID);

			$this->setCatalogsRelations($parentRessourceID, $childRessourceID);
		}

		/**
		 * delete catalog relations to other catalogs
		 * @param Int $parentRessourceID
		 * @param Int $childRessourceID
		 */
		public function deleteCatalogsRelations($parentRessourceID, $childRessourceID) {
			$this->RESTClient->delete($this->catalogsUrl.'('.$childRessourceID.'L)/$links/ParentCatalogs('.$parentRessourceID.'L)', $this->jsonHeader, '');
		}

		###################
		### CATALOG END ###
		###################

		###################
		### ORDER START ###
		###################

		/**
		 * get Orders from VIA eBay
		 * @param Date $creationDate Date of last imported Order creation Date
		 * @return Object Orders from VIA-eBay
		 */
		public function getSalesOrders() {
			return $this->RESTClient->get($this->salesOrdersUrl, $this->jsonHeader);
		}

		/**
		 * Update the VIA eBay Order to Payed
		 * @param Int $orderRessourceID Orders Ressource ID from VIA-eBay
		 * @param Double $paidAmount the paid amount from the order
		 */
		public function updateOrderPaidStatus($orderRessourceID, $paidAmount) {
			$request = array(
				'PaidAmount' => $paidAmount
			);

			$this->RESTClient->put($this->updateSalesOrdersUrl.'('.$orderRessourceID.'L)/PaidAmount', $this->jsonHeader, json_encode($request));
		}

		/**
		 * Update the VIA eBay Order to Shipped
		 * @param Int $orderRessourceID Orders Ressource ID from VIA-eBay
		 */
		public function updateOrderShippingStatus($orderRessourceID) {
			$request = array(
				'ShippingStatus' => '1'
			);

			$this->RESTClient->put($this->updateSalesOrdersUrl.'('.$orderRessourceID.'L)/ShippingStatus', $this->jsonHeader, json_encode($request));
		}

		/**
		 * Update the tracking code from Shopware to VIA-eBay
		 * @param Int $orderRessourceID Orders Ressource ID from VIA-eBay
		 * @param String $trackingCode Orders Tracking Code
		 */
		public function updateOrderTrackingCode($orderRessourceIDs, $trackingCode) {
			foreach($orderRessourceIDs as $orderRessourceID) {
                                $request = array(
                                        'CarrierUsed' => $orderRessourceID['swp_viaebay_carrier_used']?$orderRessourceID['swp_viaebay_carrier_used']:'-'
				);

				$this->RESTClient->put($this->salesOrderItemsUrl.'('.$orderRessourceID['swp_viaebay_id'].'L)/CarrierUsed', $this->jsonHeader, json_encode($request));
                            
                            
				$request = array(
					'TrackingNumbers' => $trackingCode
				);

				$this->RESTClient->put($this->salesOrderItemsUrl.'('.$orderRessourceID['swp_viaebay_id'].'L)/TrackingNumbers', $this->jsonHeader, json_encode($request));
			}
		}

		/**
		 * Update the VIA eBay Foreign Order ID
		 * @param Int $orderRessourceID Orders Ressource ID from VIA-eBay
		 * @param Int $ordernumber ordernumber from shop
		 */
		public function updateForeignOrderID($orderRessourceID, $ordernumber) {
			$request = array(
				'ForeignOrderId' => $ordernumber
			);

			$this->RESTClient->put($this->updateSalesOrdersUrl.'('.$orderRessourceID.'L)/ForeignOrderId', $this->jsonHeader, json_encode($request));
		}

		/**
		 * Update the Stock Amount in VIA-eBay
		 * @param Int $articleRessourceID article ressource ID from VIA-eBay
		 * @param Int $newStock new stock amount
		 */
		public function updateStockAmount($articleRessourceID, $newStock, $type) {
			$request = array(
				'StockAmount' => $newStock
			);

			if($type == 'default')
				$this->RESTClient->put($this->productsUrl.'('.$articleRessourceID.'L)/StockAmount', $this->jsonHeader, json_encode($request));
			else
				$this->RESTClient->put($this->productsVariationsUrl.'('.$articleRessourceID.'L)/StockAmount', $this->jsonHeader, json_encode($request));
		}

		#################
		### ORDER END ###
		#################

		###################
		### OTHER START ###
		###################

		/**
		 * check if the via ebay api occurs any errors while the runtime
		 */
		public function checkApiError() {
			return array('error' => $this->RESTClient->errorOccurred, 'list' => $this->RESTClient->errorList);
		}

		public function resetApiError() {
			$this->RESTClient->errorOccurred = false;
			$this->RESTClient->errorList = array();
		}

		#################
		### OTHER END ###
		#################
	}
?>
