<?php
/*
  ##############################################################################
  # Plugin for Shopware
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # @version $Id: VIAeBayRESTClient.php 3853 2014-05-05 10:02:38Z a.aust $
  # @copyright:   found in /lic/copyright.txt
  #
  ##############################################################################
 */

	/**
	 * REST Client for VIA eBay
	 */
	class VIAeBayRESTClient {
		const GET = 'GET';
		const POST = 'POST';
		const PUT = 'PUT';
		const MERGE = 'MERGE';
		const DELETE = 'DELETE';

		const AUTHENTIFICATION_OR_GET_OK = '200';
		const ADD_OK = '201';
		const MERGEDELETE_OK = '204';
		const NOTFOUND = '404';
		const MERGEDELETE_ERROR = '405';

		static $errorOccurred = false;
		static $errorList = array();

		/**
		 * call the VIA eBay REST Client with a POST Call
		 * @param String $url URL for the REST Call
		 * @param Array $header Header for the REST Call
		 * @param Mixed $data Data for the REST CALL
		 * @return Mixed Response of the REST Call
		 */
		public function post($url, $header, $data) {
			return $this->_exec(self::POST, $url, $header, $data);
		}

		/**
		 * call the VIA eBay REST Client with a GET Call
		 * @param String $url URL for the REST Call
		 * @param Array $header Header for the REST Call
		 * @param Mixed $data Data for the REST CALL
		 * @return Mixed Response of the REST Call
		 */
		public function get($url, $header) {
			return $this->_exec(self::GET, $url, $header);
		}

		/**
		 * call the VIA eBay REST Client with a MERGE Call
		 * @param String $url URL for the REST Call
		 * @param Array $header Header for the REST Call
		 * @param Mixed $data Data for the REST CALL
		 * @return Mixed Response of the REST Call
		 */
		public function merge($url, $header, $data) {
			return $this->_exec(self::MERGE, $url, $header, $data);
		}

		/**
		 * call the VIA eBay REST Client with a DELETE Call
		 * @param String $url URL for the REST Call
		 * @param Array $header Header for the REST Call
		 * @param Mixed $data Data for the REST CALL
		 * @return Mixed Response of the REST Call
		 */
		public function delete($url, $header, $data) {
			return $this->_exec(self::DELETE, $url, $header, $data);
		}

		/**
		 * call the VIA eBay REST Client with a PUT Call
		 * @param String $url URL for the REST Call
		 * @param Array $header Header for the REST Call
		 * @param Mixed $data Data for the REST CALL
		 * @return Mixed Response of the REST Call
		 */
		public function put($url, $header, $data = null) {
			return $this->_exec(self::PUT, $url, $header, $data);
		}

		/**
		 * set options for the VIA eBay REST Client and Call with cURL
		 * @param type $type Request Method
		 * @param String $url URL for the REST Call
		 * @param Array $header Header for the REST Call
		 * @param Mixed $body Data for the REST CALL
		 * @return Mixed Response of the REST Call
		 * @throws Exception Exception on Error
		 */
		protected function _exec($type, $url, $header, $data) {
			$config = Shopware()->Plugins()->Backend()->viaebay()->Config();

			$ch = curl_init();

			curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
			curl_setopt($ch, CURLOPT_HEADER, true);
			curl_setopt($ch, CURLINFO_HEADER_OUT, true);
			curl_setopt($ch, CURLOPT_URL, $url);
			curl_setopt($ch, CURLOPT_HTTPHEADER, $header);

			switch($type) {
				case self::POST:
					curl_setopt($ch, CURLOPT_POST, true);
					curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
					break;
				case self::GET:
					curl_setopt($ch, CURLOPT_CUSTOMREQUEST, self::GET);
					break;
				case self::MERGE:
					curl_setopt($ch, CURLOPT_CUSTOMREQUEST, self::MERGE);
					curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
					break;
				case self::DELETE:
					curl_setopt($ch, CURLOPT_CUSTOMREQUEST, self::DELETE);
					break;
				case self::PUT:
					curl_setopt($ch, CURLOPT_CUSTOMREQUEST, self::PUT);
					curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
					break;
			}

			$response = curl_exec($ch);

			if($config->debugmode) {
				__d($url, 'Url');
				__d($header, 'Header');
				__d($data, 'Anfrage');
				__d($response, 'Antwort');
			}

			$status = curl_getinfo($ch, CURLINFO_HTTP_CODE);
			$header_size = curl_getinfo($ch, CURLINFO_HEADER_SIZE);
			$content_type = curl_getinfo($ch, CURLINFO_CONTENT_TYPE);
			$header = substr($response, 0, $header_size);
			$body = substr($response, $header_size);

			curl_close($ch);

			switch($status) {
				case self::AUTHENTIFICATION_OR_GET_OK:
					switch($content_type) {
						case 'application/json; charset=utf-8';
							$body = json_decode($body);

							preg_match('/^Set-Cookie: (.*?);/m', $header, $match);

							if(isset($match[1]))
								return $match[1];
							else {
								$this->errorOccurred = true;
								$this->errorList[] = $body->error->message->value;

								throw new Exception("Fehler: Die API-Anmeldung bei VIA-Connect ist gescheitert. Bitte prüfen ob Sie Ihre Zugangsdaten korrekt im Plugin-Maager hinterlegt haben.");
							}

							break;
						default:
							return json_decode($body);

							break;
					}

					break;
				case self::ADD_OK:
				case self::MERGEDELETE_OK:
					if(!$body) $body = true;

					return json_decode($body);

					break;
				case self::NOTFOUND:
				case self::MERGEDELETE_ERROR:
					$this->errorOccurred = true;
					$this->errorList[] = json_decode($body)->error->message->value;

					return false;

					break;
				default:
					$this->errorOccurred = true;
					$this->errorList[] = json_decode($body)->error->message->value;

					return false;

					break;
			}
		}
	}
?>