<?php
/*
  ##############################################################################
  # Plugin for Shopware
  # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  # @version $Id: viaebay.php 5795 2015-04-16 11:39:16Z s.thamm $
  # @copyright:   found in /lic/copyright.txt
  #
  ##############################################################################
 */
        
        // fuer SW kleiner 5.2. da ist das interface noch nicht enthalten
        //if(!version_compare(Shopware()->Config()->version, "5.2.0", '>='))
        if(!interface_exists('Shopware\Components\CSRFWhitelistAware'))
	{
            require_once dirname(__FILE__).'/../../Components/CSRFWhitelistAware.php';
	}


	require_once dirname(__FILE__).'/../../Components/VIAeBay/VIAeBay.php';

        use Shopware\Components\CSRFWhitelistAware;
        
	/**
	 * VIA-eBay backend class
	 */
	class Shopware_Controllers_Backend_viaebay extends Shopware_Controllers_Backend_ExtJs implements CSRFWhitelistAware {
		static $fp;
		static $articleFailure = 0;
		static $articleSuccess = 0;
		static $orderFailure = 0;
		static $orderSuccess = 0;
		static $deleteSuccess = 0;
		static $deleteFailure = 0;
		static $logFile;

		#############################
		### Backend Part ENDE     ###
		#############################
        
        const BOARDING_SUBJECT = 'Download Shopware Store';
        //const BOARDING_RECEIVER_MAIL = 'dev.rl@bui-hinsche.de'; 
        //const BOARDING_RECEIVER_MAIL = 'fturan@ebay.de'; 
        //const BOARDING_RECEIVER_MAIL = 'fatih.turan@me.com'; 
        const BOARDING_RECEIVER_MAIL = 'shopware@via.de'; 
        const BOARDING_RECEIVER_NAME = 'Fatih Turan';
        
        function runBoardingAction()
        {
            try 
            {
                $this->sendBoardingMail();
                $this->switchConfiguration();
            } 
            catch (\Exception $e) 
            {
                $this->View()->assign(array('success' => false, 'message' => $e->getMessage()));
                return;
            }

            $this->View()->assign(array('success' => true));
        }
        
        function skipBoardingAction()
        {
            try 
            {
                $this->switchConfiguration();
            } 
            catch (\Exception $e) 
            {
                $this->View()->assign(array('success' => false, 'message' => $e->getMessage()));
                return;
            }

            $this->View()->assign(array('success' => true));
        }
        
        function switchConfiguration()
        {
            $form_id = Shopware()->Db()->fetchOne('SELECT id FROM s_core_config_forms WHERE name="viaebay"');
            
            $elements = Shopware()->Db()->fetchAll('SELECT * FROM s_core_config_elements WHERE form_id="' . $form_id . '"');
            
            foreach($elements as $element)
            {
                $options = unserialize($element['options']);
                
                if($element['name'] == 'boarding')
                {
                    $options['hidden'] = true;
                }
                else
                {
                    $options['hidden'] = false;    
                }
                
                $element['options'] = addslashes(serialize($options));
                
                Shopware()->Db()->Exec('UPDATE s_core_config_elements SET options="' . $element['options'] . '" WHERE name="' . $element['name'] . '" AND form_id="' . $form_id . '"');
            }
        }
        
        
        function sendBoardingMail()
        {    
            $params = $this->request->getParams();
            $params['shopurl'] = $_SERVER['SERVER_NAME'];
            $params['shopversion'] = Shopware()->Config()->get('version');
            
            /*
             * @path engine/Library/Enlight/Components/Mail.php
             * @var $mail Enlight_Components_Mail
             */  
            $mail = clone Shopware()->Mail();
            $mail->setSubject(self::BOARDING_SUBJECT . ' (' . $params['shopurl'] . ')');
            $mail->addTo(self::BOARDING_RECEIVER_MAIL, self::BOARDING_RECEIVER_NAME);
            $mail->setFrom($params['email'], $params['company'] . ' | ' . $params['contact']);
            
            $view = $this->view();
            $view->addTemplateDir(dirname (__FILE__) . '/../../Views/');
            $view->setTemplate();
            
            foreach($params as $param => $value)
            {
                $view->assign($param, $value);
            }
            
            $html = clone $view; 
            $html->loadTemplate('mail/viaebay/boarding_html.tpl');
            
            $mail->setBodyHtml($html->render());
            
            $text = clone $view; 
            $text->loadTemplate('mail/viaebay/boarding_text.tpl');
            
            $mail->setBodyText($text->render());

            $mail->send();
        }
        
        
		#############################
		### Backend Part START    ###
		#############################
        
        
                /**
                * this function is called initially
                * @return void
                */
               public function init()
               {
                   if((Shopware()->Front()->Request()->getParam('pass', '-') != '') || (Shopware()->Front()->Request()->getParam('cronjob', 0) == 1)) {
                       Shopware()->Plugins()->Backend()->Auth()->setNoAuth();
                   }

                   parent::init();
               }
               
               /**
                * 
                * @return type
                */
               public function getWhitelistedCSRFActions()
               {
                   return array(
                       'cronVIAeBayOrders',
                       'cronUpdateVIAeBayOrderData',
                       'cronExportReviseInventoryStatus',
                       'cronSendOnlyUpdatedArticlesToeBay',
                       'cronSendOnlySubmittedArticlesToeBay',
                       'cronSendAllArticlesToeBay'
                   );
               }
        
        
        
		#############################
		### Export Articles START ###
		#############################

		/**************************
		*** Listen Events START ***
		**************************/

               
               
               /**
		 * send all articles to eBay (fired by external cronjob)
		 */
		public function cronSendAllArticlesToeBayAction()
                {
			$changetime = self::getLastArticleChangeDatetime();
                        
                        $config = Shopware()->Plugins()->Backend()->viaebay()->Config();
                    
                        $cronPassword = $this->Request()->getParam('pass');
                    
                        $offset = $this->Request()->getParam('offset', 0);
                        $limit = ($config->cronjoblimitarticles != '') ? $config->cronjoblimitarticles : 25;
                        
                        
                        if($config->cronjobpass === $cronPassword)
                        {
                            if($offset == 0)
                            {
                                self::$logFile = 'articleexport_'.date('Ymd_His').'.txt';
                            }
                            else
                            {
                                self::$logFile = $this->Request()->getParam('logFile');
                            }
                            
                            $articles = Shopware()->Db()->fetchCol('
				SELECT id FROM s_articles ORDER BY id ASC LIMIT '.$offset.', '.$limit
                            );
                            
                            if(!is_array($articles) || count($articles) == 0)
                            {
                                self::updatePluginConfigChangeDatetime($changetime);
                                
                                if(!self::$fp)
                                    self::$fp = @fopen(dirname(__FILE__).'/../../logs/'.self::$logFile, "a+");
                                
                                fwrite(self::$fp, "\n\ncronSendAllArticlesToeBay finished\n\n");
                            
                                fclose(self::$fp);
                                
                                header('HTTP/1.1 200 OK');
                                exit(0);
                                return;
                            }
                            
                            foreach($articles as $articleID)
                            {
                                $VIAeBay = new VIAeBay();
                                
                                $article = self::getArticle($articleID);

                                if($article)
                                {
                                    self::exportArticlesToVIAeBay($VIAeBay, $article);
                                }
                            }

                            $url_array = (array('sViewport' => 'viaebay', 'action' => 'cronSendAllArticlesToeBay', 'offset' => ($offset+$limit), 'logFile' => self::$logFile, 'pass' => $cronPassword));
                            $url = Shopware()->Front()->Router()->assemble($url_array);
                            header('Location: '.$url);
                            exit(0);
                        }
                        else
                        {
                            die('Permission denied');
                        }
		}
               
               
               
               
		/**
		 * send all articles to eBay (fired by cronjob or backend action drodown in article list window)
		 */
		public function sendAllArticlesToeBayAction($cron = false) {
			$changetime = self::getLastArticleChangeDatetime();

			$articles = self::getAllArticles();

			foreach($articles as $article) {
                                $VIAeBay = new VIAeBay();
                            
				if($article) {
					$result = self::exportArticlesToVIAeBay($VIAeBay, $article);

					if($result)
						self::$articleSuccess++;
					else
						self::$articleFailure++;
				}
			}

			//self::deleteDeactivatedButSubmittedArticlesInVIAeBay();

			fclose(self::$fp);

			self::updatePluginConfigChangeDatetime($changetime);

			if(!$cron)
				$this->View()->assign(array('total' => (self::$articleSuccess+self::$articleFailure), 'articlesSuccess' => self::$articleSuccess, 'articlesFailure' => self::$articleFailure, 'logFile' => self::$logFile));
		}
                
                
                
                
                
                /**
		 * send only submitted articles to eBay (fired by external cronjob)
		 */
		public function cronSendOnlySubmittedArticlesToeBayAction()
                {
			$changetime = self::getLastArticleChangeDatetime();
                        
                        $config = Shopware()->Plugins()->Backend()->viaebay()->Config();
                    
                        $cronPassword = $this->Request()->getParam('pass');
                    
                        $offset = $this->Request()->getParam('offset', 0);
                        $limit = ($config->cronjoblimitarticles != '') ? $config->cronjoblimitarticles : 25;
                        
                        
                        if($config->cronjobpass === $cronPassword)
                        {
                            if($offset == 0)
                            {
                                self::$logFile = 'articleexport_'.date('Ymd_His').'.txt';
                            }
                            else
                            {
                                self::$logFile = $this->Request()->getParam('logFile');
                            }
                            
                            $articles = Shopware()->Db()->fetchCol('
				SELECT articleID FROM swp_viaebay_articles WHERE swp_viaebay_id IS NOT NULL GROUP BY articleID ORDER BY articleID ASC LIMIT '.$offset.', '.$limit
                            );
                            
                            if(!is_array($articles) || count($articles) == 0)
                            {
                                self::updatePluginConfigChangeDatetime($changetime);
                                
                                if(!self::$fp)
                                    self::$fp = @fopen(dirname(__FILE__).'/../../logs/'.self::$logFile, "a+");
                                
                                fwrite(self::$fp, "\n\ncronSendOnlySubmittedArticlesToeBay finished\n\n");
                                
                                fclose(self::$fp);
                                
                                header('HTTP/1.1 200 OK');
                                exit(0);
                                return;
                            }
                            
                            foreach($articles as $articleID)
                            {
                                $VIAeBay = new VIAeBay();
                                    
                                $article = self::getArticle($articleID);

                                if($article)
                                {
                                    self::exportArticlesToVIAeBay($VIAeBay, $article);
                                }
                            }

                            $url_array = (array('sViewport' => 'viaebay', 'action' => 'cronSendOnlySubmittedArticlesToeBay', 'offset' => ($offset+$limit), 'logFile' => self::$logFile, 'pass' => $cronPassword));
                            $url = Shopware()->Front()->Router()->assemble($url_array);
                            header('Location: '.$url);
                            exit(0);
                        }
                        else
                        {
                            die('Permission denied');
                        }
		}
                
                

		/**
		 * send only submitted articles to eBay (fired by cronjpb or action dropdown in article list window)
		 */
		public function sendOnlySubmittedArticlesToeBayAction($cron = false) {
			$changetime = self::getLastArticleChangeDatetime();

                        $articles = Shopware()->Db()->fetchCol('SELECT articleID FROM swp_viaebay_articles WHERE swp_viaebay_id IS NOT NULL GROUP BY articleID');

                        
			foreach($articles as $articleID) {
                                $VIAeBay = new VIAeBay();
                            
				$article = self::getArticle($articleID);

				if($article) {
					$result = self::exportArticlesToVIAeBay($VIAeBay, $article);

					if($result)
						self::$articleSuccess++;
					else
						self::$articleFailure++;
				}
			}

			//self::deleteDeactivatedButSubmittedArticlesInVIAeBay();

			fclose(self::$fp);

			self::updatePluginConfigChangeDatetime($changetime);

			if(!$cron)
				$this->View()->assign(array('total' => (self::$articleSuccess+self::$articleFailure), 'articlesSuccess' => self::$articleSuccess, 'articlesFailure' => self::$articleFailure, 'logFile' => self::$logFile));
		}
                
                
                
                
                
                /**
		 * send only updated articles to eBay (by external cronjob)
		 */
		public function cronSendOnlyUpdatedArticlesToeBayAction()
                {
			$changetime = self::getLastArticleChangeDatetime();
                        
                        $config = Shopware()->Plugins()->Backend()->viaebay()->Config();
                    
                        $cronPassword = $this->Request()->getParam('pass');
                    
                        $offset = $this->Request()->getParam('offset', 0);
                        $limit = ($config->cronjoblimitarticles != '') ? $config->cronjoblimitarticles : 25;
                        
                        
                        if($config->cronjobpass === $cronPassword)
                        {
                            if($offset == 0)
                            {
                                self::$logFile = 'articleexport_'.date('Ymd_His').'.txt';
                            }
                            else
                            {
                                self::$logFile = $this->Request()->getParam('logFile');
                            }
                            
                            $articles = Shopware()->Db()->fetchCol('
				SELECT a.id
				FROM s_articles AS a
				INNER JOIN s_articles_attributes AS aa
					ON a.id = aa.articleID
                                INNER JOIN swp_viaebay_articles AS va
					ON a.id = va.articleID
				WHERE a.changetime > "' . $config->update_articles_date . '"
				AND va.swp_viaebay_id IS NOT NULL GROUP BY a.id ORDER BY a.id ASC LIMIT '.$offset.', '.$limit
                            );
                            
                            if(!is_array($articles) || count($articles) == 0)
                            {
                                self::updatePluginConfigChangeDatetime($changetime);
                                
                                if(!self::$fp)
                                    self::$fp = @fopen(dirname(__FILE__).'/../../logs/'.self::$logFile, "a+");
                                
                                fwrite(self::$fp, "\n\ncronSendOnlyUpdatedArticlesToeBay finished\n\n");
                                
                                fclose(self::$fp);
                                
                                header('HTTP/1.1 200 OK');
                                exit(0);
                                return;
                            }
                            
                            foreach($articles as $articleID)
                            {
                                $VIAeBay = new VIAeBay();
                                    
                                $article = self::getArticle($articleID);

                                if($article)
                                {
                                    self::exportArticlesToVIAeBay($VIAeBay, $article);
                                }
                            }

                            $url_array = (array('sViewport' => 'viaebay', 'action' => 'cronSendOnlyUpdatedArticlesToeBay', 'offset' => ($offset+$limit), 'logFile' => self::$logFile, 'pass' => $cronPassword));
                            $url = Shopware()->Front()->Router()->assemble($url_array);
                            header('Location: '.$url);
                            exit(0);
                        }
                        else
                        {
                            die('Permission denied');
                        }
		}
                
                

		/**
		 * send only updated articles to eBay ()
		 */
		public function sendOnlyUpdatedArticlesToeBayAction($cron = false) {
			$changetime = self::getLastArticleChangeDatetime();

			$config = Shopware()->Plugins()->Backend()->viaebay()->Config();

                        $articles = Shopware()->Db()->fetchCol('
				SELECT a.id
				FROM s_articles AS a
				INNER JOIN s_articles_attributes AS aa
					ON a.id = aa.articleID
                                INNER JOIN swp_viaebay_articles AS va
					ON a.id = va.articleID
				WHERE a.changetime > "' . $config->update_articles_date . '"
				AND va.swp_viaebay_id IS NOT NULL GROUP BY a.id
			');
                        

			foreach($articles as $articleID) {
                                $VIAeBay = new VIAeBay();
                            
				$article = self::getArticle($articleID);

				if($article) {
					$result = self::exportArticlesToVIAeBay($VIAeBay, $article);

					if($result)
						self::$articleSuccess++;
					else
						self::$articleFailure++;
				}
			}

			//self::deleteDeactivatedButSubmittedArticlesInVIAeBay();

			fclose(self::$fp);

			self::updatePluginConfigChangeDatetime($changetime);

			if(!$cron)
				$this->View()->assign(array('total' => (self::$articleSuccess+self::$articleFailure), 'articlesSuccess' => self::$articleSuccess, 'articlesFailure' => self::$articleFailure, 'logFile' => self::$logFile));
		}
                
                
                
                /**
		 * send only submitted articles ReviseInventoryStatus to eBay (fired by external cronjob)
		 */
		public function cronExportReviseInventoryStatusAction()
                {
			$changetime = self::getLastArticleChangeDatetime();
                        
                        $config = Shopware()->Plugins()->Backend()->viaebay()->Config();
                    
                        $cronPassword = $this->Request()->getParam('pass');
                    
                        $offset = $this->Request()->getParam('offset', 0);
                        $limit = ($config->cronjoblimitarticles != '') ? $config->cronjoblimitarticles : 25;
                        
                        
                        if($config->cronjobpass === $cronPassword)
                        {
                            if($offset == 0)
                            {
                                self::$logFile = 'reviseinventorystatusexport_'.date('Ymd_His').'.txt';
                            }
                            else
                            {
                                self::$logFile = $this->Request()->getParam('logFile');
                            }
                            
                            $articles = Shopware()->Db()->fetchCol('SELECT articleID FROM swp_viaebay_articles WHERE swp_viaebay_id IS NOT NULL GROUP BY articleID ORDER BY articleID ASC LIMIT '.$offset.', '.$limit);
                            
                            if(!is_array($articles) || count($articles) == 0)
                            {
                                self::updatePluginConfigChangeDatetime($changetime);
                                
                                if(!self::$fp)
                                    self::$fp = @fopen(dirname(__FILE__).'/../../logs/'.self::$logFile, "a+");
                                
                                fwrite(self::$fp, "\n\ncronExportReviseInventoryStatus finished\n\n");
                                
                                fclose(self::$fp);
                                
                                header('HTTP/1.1 200 OK');
                                exit(0);
                                return;
                            }
                            
                            foreach($articles as $articleID)
                            {
                                $VIAeBay = new VIAeBay();
                                    
                                $article = self::getArticle($articleID);

                                if($article)
                                {
                                    self::exportReviseInventoryStatusToVIAeBay($VIAeBay, $article);
                                }
                            }

                            $url_array = (array('sViewport' => 'viaebay', 'action' => 'cronExportReviseInventoryStatus', 'offset' => ($offset+$limit), 'logFile' => self::$logFile, 'pass' => $cronPassword));
                            $url = Shopware()->Front()->Router()->assemble($url_array);
                            header('Location: '.$url);
                            exit(0);
                        }
                        else
                        {
                            die('Permission denied');
                        }
		}
                
                
                
                /**
		 * send only submitted articles ReviseInventoryStatus to eBay (fired by cronjob or dropdown in article list in the backend)
		 */
		public function sendReviseInventoryStatusToeBayAction($cron = false) {
			$changetime = self::getLastArticleChangeDatetime();
                        
                        if (!$cron) {
                            
                            if (json_decode($this->Request()->productIDs)) {

                                foreach(json_decode($this->Request()->productIDs) as $articleID) {
                                        $VIAeBay = new VIAeBay();                                    
                                    
                                        $article = self::getArticle($articleID);

                                        if($article) {
                                                $result = self::exportReviseInventoryStatusToVIAeBay($VIAeBay, $article);

                                                if($result)
                                                        self::$articleSuccess++;
                                                else
                                                        self::$articleFailure++;
                                        }
                                }

                            } else {

                                $articles = Shopware()->Db()->fetchCol('SELECT articleID FROM swp_viaebay_articles WHERE swp_viaebay_id IS NOT NULL GROUP BY articleID');

                                foreach($articles as $articleID) {
                                        $VIAeBay = new VIAeBay();
                                    
                                        $article = self::getArticle($articleID);

                                        if($article) {
                                                $result = self::exportReviseInventoryStatusToVIAeBay($VIAeBay, $article);

                                                if($result)
                                                        self::$articleSuccess++;
                                                else
                                                        self::$articleFailure++;
                                        }
                                }

                            }
                            
                        } else {

                                $articles = Shopware()->Db()->fetchCol('SELECT articleID FROM swp_viaebay_articles WHERE swp_viaebay_id IS NOT NULL GROUP BY articleID');

                                foreach($articles as $articleID) {
                                    
                                        self::keepCronjobActive('VIA eBay Übertragene Artikel exportieren Preis/Menge');
                                    
                                        $VIAeBay = new VIAeBay();
                                    
                                        $article = self::getArticle($articleID);

                                        if($article) {
                                                $result = self::exportReviseInventoryStatusToVIAeBay($VIAeBay, $article);

                                                if($result)
                                                        self::$articleSuccess++;
                                                else
                                                        self::$articleFailure++;
                                        }
                                }
                                
                                self::keepCronjobActive('VIA eBay Übertragene Artikel exportieren Preis/Menge');

                            }
                        
			fclose(self::$fp);

			self::updatePluginConfigChangeDatetime($changetime);

			if(!$cron)
				$this->View()->assign(array('total' => (self::$articleSuccess+self::$articleFailure), 'articlesSuccess' => self::$articleSuccess, 'articlesFailure' => self::$articleFailure, 'logFile' => self::$logFile));
		}
                
                /**
		 * update article ReviseInventoryStatus in VIA-eBay (fired by edit article in artile list window or article detail window)
		 */
		public static function updateArticleReviseInventoryStatusInVIAeBay($articleID) {
			$VIAeBay = new VIAeBay();

			$article = self::getArticle($articleID);
                        
			if($article) {
				self::exportReviseInventoryStatusToVIAeBay($VIAeBay, $article);
                        }

			fclose(self::$fp);
		}

		/**
		 * update article in VIA-eBay (fired by edit article in artile list window or article detail window)
		 */
		public static function updateArticleInVIAeBay($articleID) {
			$VIAeBay = new VIAeBay();

			$article = self::getArticle($articleID);

			if($article) {
				self::exportArticlesToVIAeBay($VIAeBay, $article);
                        } else {
				//self::deleteDeactivatedButSubmittedArticlesInVIAeBay($articleID);
                        }

			fclose(self::$fp);
		}

		/**
		 * send multiple articles to eBay (fired by action dropdown in article list window)
		 */
		public function sendMultipleArticlesToeBayAction() {
                    
			foreach(json_decode($this->Request()->productIDs) as $articleID) {
                                $VIAeBay = new VIAeBay();
                            
				$article = self::getArticle($articleID);

				if($article) {
					$result = self::exportArticlesToVIAeBay($VIAeBay, $article);

					if($result)
						self::$articleSuccess++;
					else
						self::$articleFailure++;
				} else {
					//self::deleteDeactivatedButSubmittedArticlesInVIAeBay($articleID);
				}
			}

			fclose(self::$fp);

			$this->View()->assign(array('total' => (self::$articleSuccess+self::$articleFailure), 'articlesSuccess' => self::$articleSuccess, 'articlesFailure' => self::$articleFailure, 'logFile' => self::$logFile));
		}
                
                public function onArticleDetailSaveConfiguratorSet($articleID) {
			$VIAeBay = new VIAeBay();

			$article = self::getArticle($articleID);

			if($article)
                            $result = self::exportArticlesToVIAeBay($VIAeBay, $article);


			fclose(self::$fp);

		}

		/************************
		*** Listen Events END ***
		************************/

		/*************************************
		*** Get Article Informations START ***
		*************************************/

		protected function getLastArticleChangeDatetime() {
                        
                        return str_replace(' ', 'T', Shopware()->Db()->fetchOne('
				SELECT MAX(changetime)
				FROM s_articles AS a
				INNER JOIN s_articles_attributes AS aa
					ON a.id = aa.articleID
                                INNER JOIN swp_viaebay_articles AS va
					ON a.id = va.articleID
				WHERE va.swp_viaebay_id IS NOT NULL
			'));
		}

		protected function updatePluginConfigChangeDatetime($changetime) {
			Shopware()->Db()->exec("
				UPDATE s_core_config_values sccv
				INNER JOIN s_core_config_elements scce ON (scce.id = sccv.element_id AND scce.name = 'update_articles_date')
				INNER JOIN s_core_config_forms sccf ON (sccf.id = scce.form_id AND sccf.name = 'viaebay')
				SET sccv.value = '" . serialize($changetime) . "'
			");
		}

		/**
		 * get all Articles from Shop
		 * @return Array All Articles
		 */
		protected static function getAllArticles() {
			$builder = Shopware()->Models()->createQueryBuilder();

			$builder->select(array('article', 'details', 'attribute', 'tax', 'images', 'prices', 'options', 'propertyValues', 'detail_images'))
					->from('Shopware\Models\Article\Article', 'article')
					->leftJoin('article.details', 'details')
					->leftJoin('details.attribute', 'attribute')
					->leftJoin('article.tax', 'tax')
					->leftJoin('article.images', 'images')
					->leftJoin('details.prices', 'prices')
                                        ->leftJoin('details.images', 'detail_images')
					->leftJoin('details.configuratorOptions', 'options')
					->leftJoin('article.propertyValues', 'propertyValues')
					/* ->where('article.active = 1') // auskommentiert damit die artikel-daten auch bei viaebay abgeglichen werden wenn artikel deaktiviert ist
					//->andWhere('images.parentId IS NULL'); */
                                        ->where('images.parentId IS NULL');

			$query = $builder->getQuery();

			return $query->getResult(\Doctrine\ORM\AbstractQuery::HYDRATE_ARRAY);
		}

		/**
		 * get article data from repository
		 * @param Int $articleID Article ID
		 * @return Array Article Data
		 */
		protected static function getArticle_ORG($articleID) {
			$builder = Shopware()->Models()->createQueryBuilder();

			$builder->select(array('article', 'details', 'attribute', 'tax', 'images', 'prices', 'options', 'propertyValues', 'detail_images'))
					->from('Shopware\Models\Article\Article', 'article')
					->leftJoin('article.details', 'details')
					->leftJoin('details.attribute', 'attribute')
					->leftJoin('article.tax', 'tax')
					->leftJoin('article.images', 'images')
					->leftJoin('details.prices', 'prices')
                                        ->leftJoin('details.images', 'detail_images')
					->leftJoin('details.configuratorOptions', 'options')
					->leftJoin('article.propertyValues', 'propertyValues')
					->where('article.id = ?1')
					->andWhere('images.parentId IS NULL')
					// ->andWhere('article.active = 1') // auskommentiert damit die artikel-daten auch bei viaebay abgeglichen werden wenn artikel deaktiviert ist
					->setParameter(1, (int)$articleID);

			$query = $builder->getQuery();
                        
			return $query->getOneOrNullResult(\Doctrine\ORM\AbstractQuery::HYDRATE_ARRAY);
		}
                
                /**
		 * get article data from repository
                 * 
                 * abfrage aufgeteilt um bei grossen datenmengen nicht zu
                 * viel performance mit einem riesen join zu ziehen
                 * 
		 * @param Int $articleID Article ID
		 * @return Array Article Data
		 */
                protected static function getArticle($articleID)
                {
                        $builder = Shopware()->Models()->createQueryBuilder();
			
                        $builder->select(array('article', 'tax', 'images', 'propertyValues'))
                                              ->from('Shopware\Models\Article\Article', 'article')
                                              ->leftJoin('article.tax', 'tax')
                                              ->leftJoin('article.images', 'images')
                                              ->leftJoin('article.propertyValues', 'propertyValues')
                                              ->where('article.id = ?1')
                                              ->andWhere('images.parentId IS NULL')
                                              ->setParameter(1, (int)$articleID);
                        
                        $query = $builder->getQuery();
                        
                        $result_articles = $query->getOneOrNullResult(\Doctrine\ORM\AbstractQuery::HYDRATE_ARRAY);

                        
                        if($result_articles)
                        {
                            $builder = Shopware()->Models()->createQueryBuilder();
                            
                            $builder->select(array('details', 'prices', 'options', 'attribute', 'detail_images'))
                                                ->from('Shopware\Models\Article\Detail', 'details')
                                                ->leftJoin('details.prices', 'prices')
                                                ->leftJoin('details.configuratorOptions', 'options')
                                                ->leftJoin('details.attribute', 'attribute')
                                                ->leftJoin('details.images', 'detail_images')
                                                ->andWhere('details.articleId = ?1')
                                                ->setParameter(1, (int)$articleID);
                            
                            $query = $builder->getQuery();
                            
                            $result_articles_details = $query->getResult(\Doctrine\ORM\AbstractQuery::HYDRATE_ARRAY);
                                             
                            $result_articles['details'] = $result_articles_details;
                                             
                            return $result_articles;
                        }
                        
                        
                        return NULL;
		}
                
                /**
		 * get data from swp_viaebay_articles for given article
                 * 
                 * @param Int $articleDetailID Article Detail ID
                 * 
		 * @return Array Article Data
		 */
		public static function getDataFromVIAeBayArticleTable($articleDetailID) {
			
                    $sql = "SELECT * FROM swp_viaebay_articles WHERE articledetailsID='" . $articleDetailID . "'";
                    $data = Shopware()->Db()->fetchRow($sql);
                    
                    if(is_array($data) && count($data)>0) {
                        return $data;
                    }
                    
                    return false;
		}
                
                /**
		 * get data from swp_viaebay_articles for given article via controller action
		 */
                public static function getDataFromVIAeBayArticleTableAction() {
		
                    $config = Shopware()->Plugins()->Backend()->viaebay()->Config();
                    
                    $data = array();
                    $viaebayData = self::getDataFromVIAeBayArticleTable(Shopware()->Front()->Request()->getParam('_mainDetailId'));
                    $articleData = self::getArticle(Shopware()->Front()->Request()->getParam('_articleId'));
                    
                    
                    $taxData = $articleData['tax'];
                    $mainPrices = $articleData['details'][0]['prices'];

                    $fallbackPrice = false;
                    $customerGroupPrice = false;

                    if(is_array($mainPrices) && count($mainPrices) > 1)
                    {
                        foreach($mainPrices as $price)
                        {
                            if($price['from'] == '1')
                            {
                                if($price['customerGroupKey'] == $config->articleexportcustomergroupprice)
                                {
                                    $customerGroupPrice = $price['price'];
                                }
                                else if($price['customerGroupKey'] == 'EK')
                                {
                                    $fallbackPrice = $price['price'];
                                }
                            }
                        }
                    }
                    else
                    {
                        foreach($mainPrices as $price)
                        {
                            if($price['customerGroupKey'] == $config->articleexportcustomergroupprice)
                            {
                                $customerGroupPrice = $price['price'];
                            }
                            else if($price['customerGroupKey'] == 'EK')
                            {
                                $fallbackPrice = $price['price'];
                            }
                        }
                    }
                    reset($mainPrices);
                        
                        
                    if(is_array($viaebayData))
                    {
                        $best_offer_auto_accept_price = $viaebayData['best_offer_auto_accept_price'];
                        $best_offer_auto_accept_price = $best_offer_auto_accept_price / 100 * (100 + $taxData['tax']);
                        $best_offer_auto_accept_price = round($best_offer_auto_accept_price, 2);

                        $best_offer_minimum_price = $viaebayData['best_offer_minimum_price'];
                        $best_offer_minimum_price = $best_offer_minimum_price / 100 * (100 + $taxData['tax']);
                        $best_offer_minimum_price = round($best_offer_minimum_price, 2);
                    }
                    else
                    {
                        $best_offer_auto_accept_price = round(0, 2);

                        $best_offer_minimum_price = round(0, 2);
                    }
                    
                    $data['viaeabyprice'] = round(($customerGroupPrice) ? $customerGroupPrice : $fallbackPrice, 2);
                    $data['best_offer_auto_accept_price'] = $best_offer_auto_accept_price;
                    $data['best_offer_minimum_price'] = $best_offer_minimum_price;
                    
                    header('Content-Type: text/html; charset=utf-8');
                    echo json_encode(array('responseText' => $data));
                    die;
		}
                
                
                /**
		 * set data from swp_viaebay_articles for given article
                 * 
		 * @param Int $articleDetailID ArticleDetailsID
		 * @param Double $best_offer_auto_accept_price VIA eBay BestOfferAutoAcceptPrice
                 * @param Double $best_offer_minimum_price VIA eBay BestOfferMinimumPrice
		 */
		public static function setDataFromVIAeBayArticleTable($articleDetailID, $best_offer_auto_accept_price, $best_offer_minimum_price) {
                    
                        $check = Shopware()->Db()->fetchOne('SELECT articledetailsID FROM swp_viaebay_articles WHERE articledetailsID='.$articleDetailID);
                                                
                        if($check) {
                            
                            Shopware()->Db()->exec('UPDATE swp_viaebay_articles SET best_offer_auto_accept_price="' . $best_offer_auto_accept_price . '", best_offer_minimum_price="' . $best_offer_minimum_price . '" WHERE articledetailsID='.$articleDetailID);
                        } else {
                            
                            Shopware()->Db()->Exec('INSERT INTO swp_viaebay_articles (articledetailsID, best_offer_auto_accept_price, best_offer_minimum_price) VALUES (' . $articleDetailID . ', "' . $best_offer_auto_accept_price . '", "' . $best_offer_minimum_price . '")');
                        }
		}
                
                /**
		 * set data from swp_viaebay_articles for given article via controller action
		 */
		public static function setDataFromVIAeBayArticleTableAction() {
                
                    $config = Shopware()->Plugins()->Backend()->viaebay()->Config();
                    
                    $viaeabymessage = "-";
                    $viaebayerror = false;
                    $responseText = array();
                    
                    if($config->usebestoffer)
                    {
                        $articleData = self::getArticle(Shopware()->Front()->Request()->getParam('_articleId'));
                        $articleDetailID = Shopware()->Front()->Request()->getParam('_mainDetailId');
                        $taxData = $articleData['tax'];

                        
                        //$articlePrice = Shopware()->Front()->Request()->getParam('_viaeabyprice');
                        //if(!isset($articlePrice) || $articlePrice <=0)
                        // hole immer den aktuellen artikel preis aus der db
                        {
                            $mainPrices = $articleData['details'][0]['prices'];

                            $fallbackPrice = false;
                            $customerGroupPrice = false;

                            if(is_array($mainPrices) && count($mainPrices) > 1)
                            {
                                foreach($mainPrices as $price)
                                {
                                    if($price['from'] == '1')
                                    {
                                        if($price['customerGroupKey'] == $config->articleexportcustomergroupprice)
                                        {
                                            $customerGroupPrice = $price['price'];
                                        }
                                        else if($price['customerGroupKey'] == 'EK')
                                        {
                                            $fallbackPrice = $price['price'];
                                        }
                                    }
                                }
                            }
                            else
                            {
                                foreach($mainPrices as $price)
                                {
                                    if($price['customerGroupKey'] == $config->articleexportcustomergroupprice)
                                    {
                                        $customerGroupPrice = $price['price'];
                                    }
                                    else if($price['customerGroupKey'] == 'EK')
                                    {
                                        $fallbackPrice = $price['price'];
                                    }
                                }
                            }
                            reset($mainPrices);
                            
                            $articlePrice = round(($customerGroupPrice) ? $customerGroupPrice : $fallbackPrice, 2);
                        }
                        

                        $best_offer_auto_accept_price = str_replace(',', '.', (Shopware()->Front()->Request()->getParam('_best_offer_auto_accept_price')) ? Shopware()->Front()->Request()->getParam('_best_offer_auto_accept_price') : 0);
                        $best_offer_minimum_price = str_replace(',', '.', (Shopware()->Front()->Request()->getParam('_best_offer_minimum_price')) ? Shopware()->Front()->Request()->getParam('_best_offer_minimum_price') : 0);


                        if($best_offer_auto_accept_price >= $articlePrice)
                        {

                            $viaebayerror = true;
                            //$viaeabymessage = "BestOfferAutoAcceptPrice muss kleiner dem Verkaufspreis sein!!";
                            $viaeabymessage = "'Automatisch Akzeptieren Ab' muss kleiner dem Verkaufspreis sein!!";
                        }
                        else if($best_offer_minimum_price >= $best_offer_auto_accept_price && $best_offer_minimum_price != 0)
                        {

                            $viaebayerror = true;
                            //$viaeabymessage = "BestOfferMinimumPrice muss kleiner dem BestOfferAutoAcceptPrice sein!!";
                            $viaeabymessage = "'Automatisch Ablehnen Unter' muss kleiner dem 'Automatisch Akzeptieren Ab'-Preis sein!!";
                        }

                        
                        if($viaebayerror == false)
                        {
                            $best_offer_auto_accept_price = $best_offer_auto_accept_price / (100 + $taxData['tax']) * 100;
                            $best_offer_minimum_price = $best_offer_minimum_price / (100 + $taxData['tax']) * 100;

                            self::setDataFromVIAeBayArticleTable($articleDetailID, $best_offer_auto_accept_price, $best_offer_minimum_price);
                        }
                    }
                    
                    //$responseText['viaeabymessage'] = $viaeabymessage;
                    
                    header('Content-Type: text/html; charset=utf-8');
                    //echo json_encode(array('responseText' => $responseText));
                    echo json_encode(array('responseText' => $viaeabymessage));
                    die;
		}

		/***********************************
		*** Get Article Informations END ***
		***********************************/

		/**
		 * prepare article data and call the VIA eBay REST Client
		 * @param Class $VIAeBay VIA eBay RESTClient
		 * @param Array $article Article Data
		 */
		protected static function exportArticlesToVIAeBay($VIAeBay, $article) {
			$result = true;

			if(!self::$logFile)
				self::$logFile = 'articleexport_'.date('Ymd_His').'.txt';

			if(!self::$fp)
				self::$fp = @fopen(dirname(__FILE__).'/../../logs/'.self::$logFile, "a+");

			$images = self::getImages($article['images']);

			$article['details'] = self::sortArticleDetails($article['details'], $article['mainDetailId']);

			foreach($article['details'] as $articleDetail) {
				self::resetApiError($VIAeBay);

				$articleData = self::getArticleData($article, $articleDetail);

                                if (is_array($articleDetail['images']) && count($articleDetail['images']) > 0) {
                                    $detail_images = self::getDetailImages($articleDetail['images'], $article['images']);
                                }
                                
                                $VIAeBayID = Shopware()->Db()->fetchOne('SELECT swp_viaebay_id FROM swp_viaebay_articles WHERE articledetailsID='.$articleDetail['id']);

                                
				if(self::isBlogArticle($article['id']) && !$VIAeBayID) {
					fwrite(self::$fp, 'Artikelnummer: '.$articleData['ForeignId'].' ('.$articleData['Title'].')'."\n");
					fwrite(self::$fp, "* Artikel ist ausschließlich in einer Blog-Kategorie und wurde daher nicht übertragen\n");
					fwrite(self::$fp, "\n\n--------------------------------------------------------------------\n\n");

					return false;
				} elseif(self::isBlogArticle($article['id']) && $VIAeBayID) {
					self::deleteMultipleArticlesIneBayAction(array($article['id']));

					fwrite(self::$fp, 'Artikelnummer: '.$articleData['ForeignId'].' ('.$articleData['Title'].')'."\n");
					fwrite(self::$fp, "* Artikel ist mittlerweile ausschließlich in einer Blog-Kategorie und wurde daher in VIA-Connect gelöscht\n");
					fwrite(self::$fp, "\n\n--------------------------------------------------------------------\n\n");

					return false;
				}

				//if($VIAeBayID)
				//	$VIAeBayID = self::checkIfArticleIsNormalOrConfiguratorChanged($VIAeBay, $VIAeBayID, $article);
                                
                                //if(!isset($VIAeBayID) || $VIAeBayID !== 'PRODUCTTYPECHANGED') {

                                    if($articleDetail['id'] == $article['mainDetailId']) {
                                    //if($articleDetail['id'] == $article['mainDetailId'] && $VIAeBayID !== 'PRODUCTTYPECHANGED') {
                                            if(count($article['details']) == 1 && (!is_array($articleDetail['configuratorOptions']) || count($articleDetail['configuratorOptions']) == 0)) {
                                                    // Normaler Artikel
                                                    if($VIAeBayID) {
                                                            $VIAeBay->updateProducts($articleData, '0', $VIAeBayID);
                                                            $VIAeBay->deleteProductSpecifics($VIAeBayID);
                                                            self::setAttributes($VIAeBay, $VIAeBayID, $article);
                                                            self::setBrandAndMpn($VIAeBay, $VIAeBayID, $article);
                                                            self::setOptionalAttributes($VIAeBay, $VIAeBayID, $articleDetail['attribute']);
                                                            $VIAeBay->deleteProductImages($VIAeBayID);
                                                            $VIAeBay->setProductImages($images, $VIAeBayID);
                                                            $VIAeBay->deleteProductCatalogs($VIAeBayID);
                                                            self::assignProductToCatalogs($VIAeBay, $article['id'], $VIAeBayID);
                                                            self::setPropertyAttributes($VIAeBay, $article, $VIAeBayID);
                                                    } else {
                                                            $articleResponseId = $VIAeBay->setProducts($articleData, '0');
                                                            self::setVIAeBayIDinDB($articleDetail['id'], $articleResponseId, $article['id']);
                                                            $VIAeBay->deleteProductSpecifics($articleResponseId);
                                                            self::setAttributes($VIAeBay, $articleResponseId, $article);
                                                            self::setBrandAndMpn($VIAeBay, $articleResponseId, $article);
                                                            self::setOptionalAttributes($VIAeBay, $articleResponseId, $articleDetail['attribute']);
                                                            $VIAeBay->setProductImages($images, $articleResponseId);
                                                            self::assignProductToCatalogs($VIAeBay, $article['id'], $articleResponseId);
                                                            self::setPropertyAttributes($VIAeBay, $article, $articleResponseId);
                                                    }
                                            } elseif(count($article['details']) > 1 || (count($article['details']) == 1 && (is_array($articleDetail['configuratorOptions']) && count($articleDetail['configuratorOptions']) > 0))) {

                                                    $VIAeBayContainerID = Shopware()->Db()->fetchOne('SELECT swp_viaebay_container_id FROM swp_viaebay_articles WHERE articledetailsID='.$articleDetail['id']);

                                                    // Fallback, da es vorkommen, dass die Vorauswahl in Shopware geaendert wird
                                                    // dadurch hat die neue MainDetail der Variante nicht die Container-ID hinterlegt
                                                    // was den Artikel dann neu bei VIAeBay angelegt hat
                                                    if(!$VIAeBayContainerID) {
                                                        $VIAeBayContainerID_fallback = Shopware()->Db()->fetchALL('SELECT swp_viaebay_container_id, articledetailsID FROM swp_viaebay_articles WHERE swp_viaebay_container_id IS NOT NULL AND articleID='.$article['id']);
                                                        
                                                        if(is_array($VIAeBayContainerID_fallback) && count($VIAeBayContainerID_fallback) == 1) {
                                                            self::setVIAeBayContainerIDinDB($VIAeBayContainerID_fallback[0]['articledetailsID'], 0, $article['id']);
                                                            self::setVIAeBayContainerIDinDB($articleDetail['id'], $VIAeBayContainerID_fallback[0]['swp_viaebay_container_id'], $article['id']);
                                                            $VIAeBayContainerID = $VIAeBayContainerID_fallback[0]['swp_viaebay_container_id'];
                                                        }
                                                    }

                                                    // Container Artikel
                                                    if($VIAeBayContainerID) {
                                                            $VIAeBay->updateProducts($articleData, '1', $VIAeBayContainerID);
                                                            $articleContainerResponseId = $VIAeBayContainerID;
                                                            $VIAeBay->deleteProductSpecifics($VIAeBayContainerID);
                                                            self::setAttributes($VIAeBay, $VIAeBayContainerID, $article);
                                                            self::setBrandAndMpn($VIAeBay, $VIAeBayContainerID, $article);
                                                            self::setOptionalAttributes($VIAeBay, $VIAeBayContainerID, $articleDetail['attribute']);
                                                            $VIAeBay->deleteProductImages($VIAeBayContainerID);
                                                            $VIAeBay->setProductImages($images, $VIAeBayContainerID);
                                                            $VIAeBay->deleteProductCatalogs($VIAeBayContainerID);
                                                            self::assignProductToCatalogs($VIAeBay, $article['id'], $VIAeBayContainerID);
                                                            self::setPropertyAttributes($VIAeBay, $article, $VIAeBayContainerID);
                                                    } else {
                                                            $articleContainerResponseId = $VIAeBay->setProducts($articleData, '1');
                                                            self::setVIAeBayContainerIDinDB($articleDetail['id'], $articleContainerResponseId, $article['id']);
                                                            $VIAeBay->deleteProductSpecifics($articleContainerResponseId);
                                                            self::setAttributes($VIAeBay, $articleContainerResponseId, $article);
                                                            self::setBrandAndMpn($VIAeBay, $articleContainerResponseId, $article);
                                                            self::setOptionalAttributes($VIAeBay, $articleContainerResponseId, $articleDetail['attribute']);
                                                            $VIAeBay->setProductImages($images, $articleContainerResponseId);
                                                            self::assignProductToCatalogs($VIAeBay, $article['id'], $articleContainerResponseId);
                                                            self::setPropertyAttributes($VIAeBay, $article, $articleContainerResponseId);
                                                    }

                                                    // 1. Zuordnungsartikel
                                                    $articleVariationsData = self::getArticleVariationsData($articleContainerResponseId, $article, $articleDetail);

                                                    if($VIAeBayID) {
                                                            $VIAeBay->updateProductVariations($VIAeBayID, $articleVariationsData);
                                                            
                                                            self::setBrandAndMpnVariation($VIAeBay, $VIAeBayID, $article, $articleVariationsData);
                                                            
                                                            $VIAeBay->deleteProductVariationImages($VIAeBayID);
                                                            if (is_array($detail_images) && count($detail_images) > 0) {
                                                                $VIAeBay->setProductVariationImages($VIAeBayID, $detail_images);
                                                            }
                                                            
                                                    } else {
                                                            $attributes = self::getArticleAttributes($articleDetail['configuratorOptions']);

                                                            $articleResponseId = $VIAeBay->setProductVariations($articleVariationsData);
                                                            self::setVIAeBayIDinDB($articleDetail['id'], $articleResponseId, $article['id']);
                                                            $VIAeBay->setProductVariationSpecifics($articleResponseId, $attributes);
                                                            self::setBrandAndMpnVariation($VIAeBay, $articleResponseId, $article, $articleVariationsData);
                                                            
                                                            if (is_array($detail_images) && count($detail_images) > 0) {
                                                                $VIAeBay->setProductVariationImages($articleResponseId, $detail_images);
                                                            }
                                                    }
                                            }
                                    } else {
                                            // 2. - n. Zuordnungsartikel
                                            $articleVariationsData = self::getArticleVariationsData($articleContainerResponseId, $article, $articleDetail);

                                            if($VIAeBayID) {
                                                    $VIAeBay->updateProductVariations($VIAeBayID, $articleVariationsData, $articleVariationsData);
                                                    
                                                    self::setBrandAndMpnVariation($VIAeBay, $VIAeBayID, $article, $articleVariationsData);
                                                    
                                                    $VIAeBay->deleteProductVariationImages($VIAeBayID);
                                                    if (is_array($detail_images) && count($detail_images) > 0) {
                                                        $VIAeBay->setProductVariationImages($VIAeBayID, $detail_images);
                                                    }
                                                    
                                            } else {
                                                    $attributes = self::getArticleAttributes($articleDetail['configuratorOptions']);

                                                    $articleResponseId = $VIAeBay->setProductVariations($articleVariationsData);
                                                    self::setVIAeBayIDinDB($articleDetail['id'], $articleResponseId, $article['id']);
                                                    $VIAeBay->setProductVariationSpecifics($articleResponseId, $attributes);
                                                    self::setBrandAndMpnVariation($VIAeBay, $articleResponseId, $article, $articleVariationsData);
                                                    
                                                    if (is_array($detail_images) && count($detail_images) > 0) {
                                                        $VIAeBay->setProductVariationImages($articleResponseId, $detail_images);
                                                    }
                                            }
                                    }
                                
                                // }
                                

				$errors = self::checkApiError($VIAeBay);

				if($errors['error']) {
					$articleNumber = ($articleVariationsData['Sku']) ? $articleVariationsData['Sku'] : $articleData['ForeignId'];

					fwrite(self::$fp, 'Artikelnummer: '.$articleNumber.' ('.$articleData['Title'].')'."\n");

					foreach($errors['list'] as $errorText)
						fwrite(self::$fp, '* '.$errorText."\n");

					fwrite(self::$fp, "\n\n--------------------------------------------------------------------\n\n");

					$result = false;
				}
			}

                        
			return $result;
		}
                
                /**
		 * prepare article data and call the VIA eBay REST Client
		 * @param Class $VIAeBay VIA eBay RESTClient
		 * @param Array $article Article Data
		 */
		protected static function exportReviseInventoryStatusToVIAeBay($VIAeBay, $article) {
			$result = true;

			if(!self::$logFile)
				self::$logFile = 'reviseinventorystatusexport_'.date('Ymd_His').'.txt';

			if(!self::$fp)
				self::$fp = @fopen(dirname(__FILE__).'/../../logs/'.self::$logFile, "a+");

			$article['details'] = self::sortArticleDetails($article['details'], $article['mainDetailId']);

			foreach ($article['details'] as $articleDetail) {
                            self::resetApiError($VIAeBay);

                            $articleData = self::getArticleData($article, $articleDetail);

                            $VIAeBayID = Shopware()->Db()->fetchOne('SELECT swp_viaebay_id FROM swp_viaebay_articles WHERE articledetailsID=' . $articleDetail['id']);


                            if ($articleDetail['id'] == $article['mainDetailId']) {
                                if(count($article['details']) == 1 && (!is_array($articleDetail['configuratorOptions']) || count($articleDetail['configuratorOptions']) == 0)) {
                                    // Normaler Artikel
                                    if ($VIAeBayID) {
                                        $VIAeBay->reviseInventoryStatus($VIAeBayID, false, $articleData['StockAmount'], $articleData['Price'], $articleData['PsuedoPrice']);
                                    }
                                } elseif(count($article['details']) > 1 || (count($article['details']) == 1 && (is_array($articleDetail['configuratorOptions']) && count($articleDetail['configuratorOptions']) > 0))) {
                                     
                                    $VIAeBayContainerID = Shopware()->Db()->fetchOne('SELECT swp_viaebay_container_id FROM swp_viaebay_articles WHERE articledetailsID=' . $articleDetail['id']);


                                    // Container Artikel
                                    if ($VIAeBayContainerID) {
                                       $articleContainerResponseId = $VIAeBayContainerID;
                                    }

                                    // 1. Zuordnungsartikel
                                    $articleVariationsData = self::getArticleVariationsData($articleContainerResponseId, $article, $articleDetail);

                                    if ($VIAeBayID) {
                                        $VIAeBay->reviseInventoryStatus($VIAeBayContainerID, $VIAeBayID, $articleVariationsData['StockAmount'], $articleVariationsData['Price'], $articleVariationsData['PsuedoPrice']);
                                    }
                                    
                                    // momentan deaktiviert da es sonst fehler macht bei viaebay
                                    // Container Artikel
                                    //if ($VIAeBayContainerID) {
                                    //    $VIAeBay->reviseInventoryStatus($VIAeBayContainerID, false, $articleData['StockAmount'], $articleData['Price']);
                                    //}
                                }
                            } else {
                                // 2. - n. Zuordnungsartikel
                                $articleVariationsData = self::getArticleVariationsData($articleContainerResponseId, $article, $articleDetail);

                                if ($VIAeBayID) {
                                    $VIAeBay->reviseInventoryStatus($VIAeBayContainerID, $VIAeBayID, $articleVariationsData['StockAmount'], $articleVariationsData['Price'], $articleVariationsData['PsuedoPrice']);
                                }
                            }


                            $errors = self::checkApiError($VIAeBay);

                            if ($errors['error']) {
                                $articleNumber = ($articleVariationsData['Sku']) ? $articleVariationsData['Sku'] : $articleData['ForeignId'];

                                fwrite(self::$fp, 'Artikelnummer: ' . $articleNumber . ' (' . $articleData['Title'] . ')' . "\n");

                                foreach ($errors['list'] as $errorText)
                                    fwrite(self::$fp, '* ' . $errorText . "\n");

                                fwrite(self::$fp, "\n\n--------------------------------------------------------------------\n\n");

                                $result = false;
                            }
                        }

                        
			return $result;
		}

		protected function checkIfArticleIsNormalOrConfiguratorChanged($VIAeBay, $VIAeBayID, $article) {
                    //TODO Funktionalität wurde vorerst wieder deaktiviert
                    return;


                    __d('checkIfArticleIsNormalOrConfiguratorChanged');


			$articleChanged = false;

			$productTypes = $VIAeBay->getProductType(self::getArticleRessourceID($article['id']));
                        

			if(isset($article['configuratorSetId']) && $article['configuratorSetId'] != '') {
                            
                            if($productType != '1') {
                                $articleChanged = true;
                            }
                                
			} else if(!isset($article['configuratorSetId']) || $article['configuratorSetId'] == '') {
                            
                            if($productType != '0') {
                                
                                $articleChanged = true;
                            }
                            
			} else {
                            
                           // if($productType != '0') {
                           //     $articleChanged = true;
                           //  }
                            
			}
                        

			if($articleChanged === true) {
                            
                               // __d('PRODUCTTYPECHANGED - articleid - '.$article['id']);
                               // __d($article, '$article');
                               // __d($productType, '$productType');                                
                            
                            
				//self::deleteMultipleArticlesIneBayAction(array($article['id']), true);
                                
                                //	return false;
                                return 'PRODUCTTYPECHANGED';
			} else
				return $VIAeBayID;
		}
		

		/**
		 * check if the article only in blog categories
		 */
		protected function isBlogArticle($articleID) {
			$categories = Shopware()->Db()->fetchAll('
				SELECT ac.categoryID, c.blog
				FROM s_articles_categories AS ac
				LEFT JOIN s_categories_attributes AS ca
					ON ac.categoryID = ca.categoryID
				INNER JOIN s_categories AS c
					ON ac.categoryID = c.id
				WHERE ac.articleID='.$articleID.' AND c.active=1
			');


			if(count($categories) == 0) return false;

			$onlyBlogCategories = true;

			foreach($categories as $category)
				if(!$category['blog'])
					$onlyBlogCategories = false;

			return $onlyBlogCategories;
		}


		/**
		 * get Array of Image URLs
		 * 
		 * Plan.io Ticket #1846 - Methode enthaelt Anpassungen fuer die Umsetzung des Tickets
		 *
		 * @param Array $images Shopware Images Array
		 * @return Array Image URLs
		 */
		protected static function getImages($images)
                {
                    $imagesArray = array();
                    $index = 1;

                    $config = Shopware()->Plugins()->Backend()->viaebay()->Config();
                        
                    $PathArticleImg = rtrim($config->shop_domain, '/') . '/media/image/';
                    //$PathArticleImg = rtrim('https://www.it-einkaufspartner.de/', '/') . '/media/image/';

                    foreach($images as $image) 
                    {
                        $media = Shopware()->Models()->find('\Shopware\Models\Media\Media', $image['mediaId']);
                        $path = $media->getPath();

                        
			if($image['main'] == 1) 
			{				
                            if(preg_match('/^(img\.php\?url=)/', $path) === 1)
                            {
                                $imagesArray[0] = $PathArticleImg . 'thumbnail/' . $path;
                            }
                            else if(preg_match('/^(http)/', $path) === 1)
                            {
                                $imagesArray[0] = $path;
                            }
                            else if(version_compare(Shopware::VERSION, '5.1.0', '>=')) // MediaService-Logik seit Shopware 5.1.0 mit virtuellem Pfad fuer Bilder
                            {
                                $mediaService = Shopware()->Container()->get('shopware_media.media_service');
                                $path = $mediaService->getUrl($path);
                                $imagesArray[0] = $path;
                            }
                            else
                            {
                                // $imagesArray[0] = Shopware()->Modules()->System()->sSYSTEM->sPathArticleImg . $image['path'] . '.' . $image['extension'];
                                $imagesArray[0] = $PathArticleImg . $image['path'] . '.' . $image['extension'];
                            }
                        } 
                        else 
                        {
                            if(preg_match('/^(img\.php\?url=)/', $path) === 1)
                            {
                                $imagesArray[$index] = $PathArticleImg . 'thumbnail/' . $path;
                            }
                            else if(preg_match('/^(http)/', $path) === 1)
                            {
                                $imagesArray[$index] = $path;
                            }
                            else if(version_compare(Shopware::VERSION, '5.1.0', '>=')) // MediaService-Logik seit Shopware 5.1.0 mit virtuellem Pfad fuer Bilder
                            {
                                $mediaService = Shopware()->Container()->get('shopware_media.media_service');
                                $path = $mediaService->getUrl($path);
                                $imagesArray[$index] = $path;
                            }
                            else
                            {
                                // $imagesArray[$index] = Shopware()->Modules()->System()->sSYSTEM->sPathArticleImg . $image['path'] . '.' . $image['extension'];
                                $imagesArray[$index] = $PathArticleImg . $image['path'] . '.' . $image['extension'];
                            }
                        }

                        
			$index++;
                    }

                    
                    ksort($imagesArray);
                        
                    return $imagesArray;
		}

                
                /**
		 * get Array of Image URLs
		 * @param Array $detail_images Shopware Images Array - imageas of the article detail
                 * @param Array $main_images Shopware Images Array - all images for an article
		 * @return Array Image URLs
		 */
		protected static function getDetailImages($detail_images, $main_images)
                {
                    $imagesArray = array();

                    
                    foreach($detail_images as $image)
                    {
                        $path = self::getDetailImagesPath($image['parentId'], $main_images);
            
                        if($path !== false)
                        {
                            $imagesArray[] = $path;
                        }
                    }

                    
                    ksort($imagesArray);

                    return $imagesArray;
		}

         
                /**
                 * get Image URLs
                 * 
		 * Plan.io Ticket #1846 - Methode enthaelt Anpassungen fuer die Umsetzung des Tickets
		 *
		 * @param Array $detail_images Shopware Images Array - imageas of the article detail
                 * @param Array $main_images Shopware Images Array - all images for an article
		 * @return Array Image URLs
                 */       
                protected static function getDetailImagesPath($parentId, $main_images)
                {
                    $config = Shopware()->Plugins()->Backend()->viaebay()->Config();
                
                    $PathArticleImg = rtrim($config->shop_domain, '/') . '/media/image/';
                    //$PathArticleImg = rtrim('https://www.it-einkaufspartner.de/', '/') . '/media/image/';
            
                    
                    foreach($main_images as $image)
                    {
                        $media = Shopware()->Models()->find('\Shopware\Models\Media\Media', $image['mediaId']);
			$path = $media->getPath();

                        if($image['id'] == $parentId)
                        {
                            if(preg_match('/^(img\.php\?url=)/', $path) === 1)
                            {
                                return $PathArticleImg . 'thumbnail/' . $path;
                            }
                            else if(preg_match('/^(http)/', $path) === 1)
                            {
                                return $path;
                            }
                            else if(version_compare(Shopware::VERSION, '5.1.0', '>=')) // MediaService-Logik seit Shopware 5.1.0 mit virtuellem Pfad fuer Bilder
                            {
                                $mediaService = Shopware()->Container()->get('shopware_media.media_service');
                                $path = $mediaService->getUrl($path);
                                return $path;
                            }
                            else
                            {
                                // return Shopware()->Modules()->System()->sSYSTEM->sPathArticleImg . $image['path'] . '.' . $image['extension'];
                                return $PathArticleImg . $image['path'] . '.' . $image['extension'];
                            }
                        }
                    }
            
                    return false;
                }

                
                /**
		 * sort the article details, so the main article is the first in the array
		 * @param Array $articleDetails unsorted Article Details
		 * @return Array Sorted Article Details
		 */
		protected static function sortArticleDetails($articleDetails, $mainDetailID) {
			$newArticleDetails = array();
			$index = 1;

			foreach($articleDetails as $articleDetail) {
				if($articleDetail['id'] == $mainDetailID)
					$newArticleDetails[0] = $articleDetail;
				else {
					$newArticleDetails[$index] = $articleDetail;
					$index++;
				}
			}

			ksort($newArticleDetails);

			return $newArticleDetails;
		}

		/**
		 * get base article data for VIA eBay
		 * @param Array $article Main Article Data
		 * @param Array $articleDetail Detail Data of Article or Variants
		 * @return Array Base Article Data for VIA eBay
		 */
		protected static function getArticleData($article, $articleDetail) {
			$config = Shopware()->Plugins()->Backend()->viaebay()->Config();

                        
                        // falls mal kein lagerbestand da ist bzw. der datensatzt keinen gueltigen
                        // wert enthaelt, dann setze wenigtens 0 als Lagerbestand zum Uebertragen
                        if(!isset($articleDetail['inStock']) || $articleDetail['inStock'] == '')
                        {
                            $articleDetail['inStock'] = 0;
                        }
                        
                        
                        if($config->sale_actice == true && (int)$article['lastStock'] == (int)0) {
                            
                            if((int)$articleDetail['inStock'] <= (int)0) {
                                $articleDetail['inStock'] = (int)$config->default_stock_amount;
                            }
                            
                        } else {
                            
                            if((int)$articleDetail['inStock'] < (int)0) {
                                $articleDetail['inStock'] = 0;
                            }
                            
                        }

                        
			$fallbackPrice = false;
			$customerGroupPrice = false;
			$fallbackPseudoPrice = false;
			$customerGroupPseudoPrice = false;

                        //__d($articleDetail['prices']);
                        
                        if (is_array($articleDetail['prices']) && count($articleDetail['prices']) > 1) {
                            
                            foreach($articleDetail['prices'] as $price) {
                                
                                if ($price['from'] == '1') {
                                
                                    if($price['customerGroupKey'] == $config->articleexportcustomergroupprice) {
                                            $customerGroupPrice = $price['price'];
                                            $customerGroupPseudoPrice = $price['pseudoPrice'];
                                    } elseif($price['customerGroupKey'] == 'EK') {
                                            $fallbackPrice = $price['price'];
                                            $fallbackPseudoPrice = $price['pseudoPrice'];
                                    }
                                }
                            }
                            
                        } else {
                            
                            foreach($articleDetail['prices'] as $price) {
                                    if($price['customerGroupKey'] == $config->articleexportcustomergroupprice) {
                                            $customerGroupPrice = $price['price'];
                                            $customerGroupPseudoPrice = $price['pseudoPrice'];
                                    } elseif($price['customerGroupKey'] == 'EK') {
                                            $fallbackPrice = $price['price'];
                                            $fallbackPseudoPrice = $price['pseudoPrice'];
                                    }
                            }
                        }

			$articlePrice = ($customerGroupPrice) ? $customerGroupPrice : $fallbackPrice;
			//$pseudoPrice = ($customerGroupPseudoPrice) ? $customerGroupPseudoPrice : $fallbackPseudoPrice;
                        $pseudoPrice = $customerGroupPseudoPrice;
			$articlePrice = round($articlePrice / 100 * (100 + $article['tax']['tax']), 2);
			$pseudoPrice = round($pseudoPrice / 100 * (100 + $article['tax']['tax']), 2);

			if($pseudoPrice) {
				if($pseudoPrice < $articlePrice)
					$pseudoPrice = false;
				else
					list($articlePrice, $pseudoPrice) = array($pseudoPrice, $articlePrice);
			}

                        // damit Word-Anfuehrungszeichen uebertragen werden koennen, werden diese in normale umgewandelt
                        $title = $article['name'];
                        $title = str_replace('“', '"', $title);
                        $title = str_replace('„', '"', $title);
                        //$title = substr($title, 0, 75);

                        
                        if($config->zeroqty && ((int)$articleDetail['active'] == (int)0 || (int)$article['active'] == (int)0))
                        {
                            $articleDetail['inStock'] = 0;
                        }
                        
                        
			$articleData = array(
				'ForeignId' => $articleDetail['number'],
				'Title' => $title,
				'Description' => $article['descriptionLong'],
				'Price' => $articlePrice,
				'PsuedoPrice' => $pseudoPrice,
				'StockAmount' => $articleDetail['inStock'],
				'Ean' => $articleDetail['ean'],
				'VatPercent' => $article['tax']['tax'],
				'ShortDescription' => $article['description']
			);

			if(isset($articleDetail['unitId']) && isset($articleDetail['purchaseUnit']) && $articleDetail['purchaseUnit'] > 0 && isset($articleDetail['referenceUnit']) && $articleDetail['referenceUnit'] > 0) {
				$articleData['UnitQuantity'] = $articleDetail['purchaseUnit']/$articleDetail['referenceUnit'];
				$articleData['UnitType'] = (int)$articleDetail['referenceUnit'].Shopware()->Db()->fetchOne('SELECT unit FROM s_core_units WHERE id='.$articleDetail['unitId']);
			}
                        
                        
                        
                        // prepare Preisvorschlag - Anfang
                        
                        //__d($article);
                        //__d($articleDetail);
                        
                        // Preisvorschlag geht aktuell nur bei normalen artikeln
                        
                        if (count($article['details']) == 1 && $config->usebestoffer) {
                        
                                if($preisvorschlagData = self::getDataFromVIAeBayArticleTable($article['mainDetailId'])) {

                                    $best_offer_auto_accept_price = $preisvorschlagData['best_offer_auto_accept_price'];
                                    $best_offer_auto_accept_price = round($best_offer_auto_accept_price / 100 * (100 + $article['tax']['tax']), 2);

                                    $best_offer_minimum_price = $preisvorschlagData['best_offer_minimum_price'];
                                    $best_offer_minimum_price = round($best_offer_minimum_price / 100 * (100 + $article['tax']['tax']), 2);


                                    // $best_offer_auto_accept_price muss kleiner dem $articlePrice sein
                                    // $best_offer_minimum_price muss kleiner dem $best_offer_auto_accept_price sein
                                    if($best_offer_auto_accept_price < $articlePrice && $best_offer_minimum_price < $best_offer_auto_accept_price) {

                                        $articleData['BestOfferAutoAcceptPrice'] = $best_offer_auto_accept_price;
                                        $articleData['BestOfferMinimumPrice'] = $best_offer_minimum_price;

                                    } else {

                                        $best_offer_auto_accept_price = false;
                                        $best_offer_minimum_price = false;

                                    }


                                } else {

                                    $best_offer_auto_accept_price = false;
                                    $best_offer_minimum_price = false;

                                }
                        
                        } else {
                            
                            $articleData['BestOfferNOTSUPPORTED'] = 'NOTSUPPORTED';
                            
                        }
                        
                        // prepare Preisvorschlag - Ende
                        
                        
                        //__d($articleData);

			return $articleData;
		}

		/**
		 * set VIAeBayID in DB to the Article
		 * @param Int $articleDetailsID ArticleDetailsID
		 * @param Int $VIAeBayID VIA eBay Article Response ID
                 * @param Int $articleID articleID
		 */
		protected static function setVIAeBayIDinDB($articleDetailsID, $VIAeBayID, $articleID = false) {
                    
                        $check = Shopware()->Db()->fetchOne('SELECT articledetailsID FROM swp_viaebay_articles WHERE articledetailsID="'.$articleDetailsID.'"');
                                     
                        if($check) {
                            Shopware()->Db()->exec('UPDATE swp_viaebay_articles SET swp_viaebay_id="'.$VIAeBayID.'" WHERE articledetailsID="'.$articleDetailsID.'"');
                        } else {
                            Shopware()->Db()->Exec('INSERT INTO swp_viaebay_articles (articledetailsID, swp_viaebay_id) VALUES ("' . $articleDetailsID . '", "' . $VIAeBayID . '")');
                        }
                        
                        
                        if ($articleID !== false) {
                            Shopware()->Db()->exec('UPDATE swp_viaebay_articles SET articleID="'.$articleID.'" WHERE articledetailsID="'.$articleDetailsID.'"');
                        }
		}

		/**
		 * set VIAeBayContainerID in DB to the Article
		 * @param Int $articleDetailsID ArticleDetailsID
		 * @param Int $VIAeBayContainerID VIA eBay Container Article Response ID
                 * @param Int $articleID articleID
		 */
		protected static function setVIAeBayContainerIDinDB($articleDetailsID, $VIAeBayContainerID, $articleID = false) {
                    
                        $check = Shopware()->Db()->fetchOne('SELECT articledetailsID FROM swp_viaebay_articles WHERE articledetailsID="'.$articleDetailsID.'"');
                                                
                        if($check) {
                            Shopware()->Db()->exec('UPDATE swp_viaebay_articles SET swp_viaebay_container_id="'.$VIAeBayContainerID.'" WHERE articledetailsID="'.$articleDetailsID.'"');
                        } else {
                            Shopware()->Db()->Exec('INSERT INTO swp_viaebay_articles (articledetailsID, swp_viaebay_container_id) VALUES ("' . $articleDetailsID . '", "' . $VIAeBayContainerID . '")');
                        }
                        
                        
                        if ($articleID !== false) {
                            Shopware()->Db()->exec('UPDATE swp_viaebay_articles SET articleID="'.$articleID.'" WHERE articledetailsID="'.$articleDetailsID.'"');
                        }
		}

		/**
		 * set the Manufacturer to the VIA eBay Products Ressource
		 * @param Class $VIAeBay VIA eBay REST Client
		 * @param Int $ressourceID VIA eBay Products Resspirce ID
		 * @param Int $supplierID Supplier ID
		 */
		protected static function setAttributes($VIAeBay, $ressourceID, $article) {
			$attributes['Marke'] = Shopware()->Db()->fetchOne('SELECT name FROM s_articles_supplier WHERE id='.$article['supplierId']);

			if($article['details'][0]['supplierNumber'])
				$attributes['Herstellernummer'] = $article['details'][0]['supplierNumber'];

			$VIAeBay->setProductSpecifics($ressourceID, $attributes);
                        
                        
                        // Herrsteller-Beschreibung uebermitteln
                        $supplierDesc = Shopware()->Db()->fetchOne('SELECT description FROM s_articles_supplier WHERE id='.$article['supplierId']);
                        $VIAeBay->setProductOptionalAttributes($ressourceID, array('Hersteller-Beschreibung' => $supplierDesc));
		}

		protected static function setOptionalAttributes($VIAeBay, $ressourceID, $attributes) {
			$optionalAttributes = array();

			foreach($attributes as $key => $value)
				if($group = Shopware()->Db()->fetchOne('SELECT label FROM s_core_engine_elements WHERE name="'.$key.'"'))
					$optionalAttributes[$group] = $value;

			if(is_array($optionalAttributes) && count($optionalAttributes) > 0)
				$VIAeBay->setProductOptionalAttributes($ressourceID, $optionalAttributes);
		}
                
                protected static function setBrandAndMpn($VIAeBay, $ressourceID, $article) {
			$brand = Shopware()->Db()->fetchOne('SELECT name FROM s_articles_supplier WHERE id='.$article['supplierId']);

                        $mpn = '';
			if($article['details'][0]['supplierNumber'])
				$mpn = $article['details'][0]['supplierNumber'];
			
			$VIAeBay->setBrandAndMpn($ressourceID, $brand, $mpn);
		}
                
                
                protected static function setBrandAndMpnVariation($VIAeBay, $ressourceID, $article, $articleVariation) {
			$brand = Shopware()->Db()->fetchOne('SELECT name FROM s_articles_supplier WHERE id='.$article['supplierId']);
                        
                        $ean = '';
			if(Shopware()->Db()->fetchOne('SELECT ean FROM s_articles_details WHERE ordernumber="'.$articleVariation['Sku'].'"') != '') {
				$ean = Shopware()->Db()->fetchOne('SELECT ean FROM s_articles_details WHERE ordernumber="'.$articleVariation['Sku'].'"');
                        } else if($article['details'][0]['ean']) {
                                $ean = $article['details'][0]['ean'];
                        }
                        
                        $mpn = '';
			if(Shopware()->Db()->fetchOne('SELECT suppliernumber FROM s_articles_details WHERE ordernumber="'.$articleVariation['Sku'].'"') != '') {
				$mpn = Shopware()->Db()->fetchOne('SELECT suppliernumber FROM s_articles_details WHERE ordernumber="'.$articleVariation['Sku'].'"');
                        } else if($article['details'][0]['supplierNumber']) {
                                $mpn = $article['details'][0]['supplierNumber'];
                        }
                        
			$VIAeBay->setBrandAndMpnVariation($ressourceID, $brand, $mpn, $ean);
		}

                
		/**
		 * assign the catalogs ressource id to the products ressource id
		 * @param Class $VIAeBay VIA eBay REST Client
		 * @param Int $articleID Article ID
		 * @param Int $VIAeBayArticleID VIA eBay Ressource ID
		 */
		protected static function assignProductToCatalogs($VIAeBay, $articleID, $VIAeBayArticleID) {
                        
                        $categories = Shopware()->Db()->fetchAll('
				SELECT ac.categoryID, vc.swp_viaebay_id
				FROM s_articles_categories AS ac
				LEFT JOIN s_categories_attributes AS ca
					ON ac.categoryID = ca.categoryID
				INNER JOIN s_categories AS c
					ON ac.categoryID = c.id
                                LEFT JOIN swp_viaebay_categories AS vc
                                        ON vc.categoryID = c.id
				WHERE ac.articleID='.$articleID.' AND c.active=1 and c.blog=0
			');
                        
                        
			foreach($categories as $category) {
				if(!$category['swp_viaebay_id'])
					$category['swp_viaebay_id'] = self::createAndAssignCatalogs($VIAeBay, $category);

				$VIAeBay->setProductCatalogs($VIAeBayArticleID, $category['swp_viaebay_id']);
			}
		}

		/**
		 * create and assign the categories ressource for the product ressource in VIAeBay System
		 * @param Class $VIAeBay
		 * @param Array $category
		 * @return Int VIA eBay Ressource ID
		 */
		protected static function createAndAssignCatalogs($VIAeBay, $category) {
			$catPath[] = array('parent' => $category['categoryID']);

			$catPath = self::getCategoryPath($catPath);

			foreach($catPath as &$cat) {
				if(!$cat['swp_viaebay_id']) {
					$categoryData = array('ForeignId' => $cat['categoryID'], 'Name' => $cat['description'], 'IsRootLevel' => ($cat['categoryID']  == '1') ? 'true' : 'false');

					$cat['swp_viaebay_id'] = (int)$VIAeBay->setCatalogs($categoryData);

                                        $check = Shopware()->Db()->fetchOne('SELECT categoryID FROM swp_viaebay_categories WHERE categoryID='.$cat['categoryID']);
                                                
                                        if($check) {
                                            Shopware()->Db()->exec('UPDATE swp_viaebay_categories SET swp_viaebay_id="'.$cat['swp_viaebay_id'].'" WHERE categoryID='.$cat['categoryID']);
                                        } else {
                                            Shopware()->Db()->Exec('INSERT INTO swp_viaebay_categories (categoryID, swp_viaebay_id) VALUES (' . $cat['categoryID'] . ', ' . $cat['swp_viaebay_id'] . ')');
                                        }
				}
			}

			$catPath = array_reverse($catPath);

			$parentCatRessourceID = 0;

			foreach($catPath as $cat) {
				if($parentCatRessourceID != 0)
					$VIAeBay->setCatalogsRelations($parentCatRessourceID, $cat['swp_viaebay_id']);

				$parentCatRessourceID = $cat['swp_viaebay_id'];
			}

			return $catPath[count($catPath) - 1]['swp_viaebay_id'];
		}

		/**
		 * get category path (recursive)
		 * @param Array $categoryPath Category Path
		 * @param Boolean $first true for reset the array in first iteration
		 * @return Array Category Path
		 */
		protected static function getCategoryPath(&$categoryPath, $first = true) {
			
                        $category = Shopware()->Db()->fetchAll('SELECT c.id as categoryID, c.parent, c.description, vc.swp_viaebay_id FROM s_categories AS c LEFT JOIN s_categories_attributes AS ca ON c.id = ca.categoryID LEFT JOIN swp_viaebay_categories AS vc ON vc.categoryID = c.id WHERE c.id='.$categoryPath[(count($categoryPath) - 1)]['parent']);

			if($first == true)
				unset($categoryPath);

			if(count($category) == 0) {
                                $check = Shopware()->Db()->fetchOne('SELECT categoryID FROM swp_viaebay_categories WHERE categoryID=1');
                                                
                                if($check) {
                                    Shopware()->Db()->exec('UPDATE swp_viaebay_categories SET swp_viaebay_id=NULL WHERE categoryID=1');
                                } else {
                                    Shopware()->Db()->Exec('INSERT INTO swp_viaebay_categories (categoryID, swp_viaebay_id) VALUES (1, NULL)');
                                }
                                
				$categoryPath[] = array('parent' => null, 'swp_viaebay_id' => null, 'description' => 'Root', 'categoryID' => '1');
			} else
				$categoryPath[] = array('categoryID' => $category[0]['categoryID'], 'parent' => $category[0]['parent'], 'swp_viaebay_id' => $category[0]['swp_viaebay_id'], 'description' => $category[0]['description']);

			if($categoryPath[(count($categoryPath) - 1)]['parent'] != null && $categoryPath[(count($categoryPath) - 1)]['swp_viaebay_id'] == null)
				self::getCategoryPath($categoryPath, false);
                        

			return $categoryPath;
		}

		/**
		 * update the category in VIA-eBay
		 */
		public function updateCategoryInVIAeBay($categoryID) {
                        
                        $VIAeBayID = Shopware()->Db()->fetchOne('SELECT swp_viaebay_id FROM swp_viaebay_categories WHERE categoryID='.$categoryID);
                    
                        
			if(!$VIAeBayID) return false;

			$VIAeBay = new VIAeBay();

			if((int)Shopware()->Db()->fetchOne('SELECT active FROM s_categories WHERE id='.$categoryID) == (int)0)
				self::deleteCategoriesStructureInVIAeBay($categoryID);
			else {
				$catalogData = array(
					'Name' => Shopware()->Db()->fetchOne('SELECT description FROM s_categories WHERE id='.$categoryID)
				);

				$VIAeBay->updateCatalogs($VIAeBayID, $catalogData);
			}
		}

		/**
		 * update the category structure, when the admin drag&drop this in the category backend
		 */
		public function submitNewCategoryStructureByMovingCategory($cateoryID, $categoryParentID) {
                        
                        $categoryVIAeBayID = Shopware()->Db()->fetchOne('SELECT swp_viaebay_id FROM swp_viaebay_categories WHERE categoryID='.$cateoryID);
                        
                    
			if(!$categoryVIAeBayID) return false;

			$VIAeBay = new VIAeBay();

                        $categoryParentVIAeBayID = Shopware()->Db()->fetchOne('SELECT swp_viaebay_id FROM swp_viaebay_categories WHERE categoryID='.$categoryParentID);
                        
                        
			if($categoryParentVIAeBayID)
				$VIAeBay->updateCatalogsRelations($categoryParentVIAeBayID, $categoryVIAeBayID);
			else {
				$categoryParentVIAeBayID = self::createAndAssignCatalogs($VIAeBay, array('categoryID' => $categoryParentID));
				$VIAeBay->updateCatalogsRelations($categoryParentVIAeBayID, $categoryVIAeBayID);
			}
		}

		/**
		 * set the shopware property attributes to VIA eBay
		 * @param Class $VIAeBay VIA eBay Class
		 * @param Array $article Article Data
		 * @param Int $articleResponseId VIA eBay Product Ressource ID
		 */
		protected static function setPropertyAttributes_ORG($VIAeBay, $article, $articleResponseId) {
			if(is_array($article['propertyValues']) && count($article['propertyValues']) > 0) {
				$attributes = array();

				foreach($article['propertyValues'] as $propertyValue) {
					$group = Shopware()->Db()->fetchOne('SELECT name FROM s_filter_options WHERE id='.$propertyValue['optionId']);

					if(array_key_exists($group, $attributes))
						$attributes[$group] .= ', ' . $propertyValue['value'];
					else
						$attributes[$group] = $propertyValue['value'];
				}

				$VIAeBay->setProductSpecifics($articleResponseId, $attributes);
			}
		}
                
                /**
		 * set the shopware property attributes to VIA eBay
                 * 
                 * - Mit Erweiterung dass nur eine bestimmt Anzahl an Merkmalen
                 * uebertragen werden und dabei auf die Reihenfolge von der Frontend-Ausgabe geachtet wird
                 * 
		 * @param Class $VIAeBay VIA eBay Class
		 * @param Array $article Article Data
		 * @param Int $articleResponseId VIA eBay Product Ressource ID
		 */
		protected static function setPropertyAttributes($VIAeBay, $article, $articleResponseId)
                {
                    $config = Shopware()->Plugins()->Backend()->viaebay()->Config();
                    $countpropertyvalues = ((int)$config->countpropertyvalues <= 22) ? (int)$config->countpropertyvalues : 22;
                   
                    try
                    {
                        $repository = Shopware()->Models()->getRepository('Shopware\Models\Shop\Shop');
                        $shop = $repository->getActiveById(1);
                        $shop->registerResources(Shopware()->Bootstrap());
                    
                        $articless = Shopware()->Modules()->Articles()->sGetArticleById(
                            $article['id']
                        );
                        
                        //__d($articless, 'ddd');
            
                    }
                    catch(Exception $e)
                    {
                        $articless = null;
                    }
                    
                    
                    
                    if(is_array($articless) && (is_array($articless['sProperties']) && count($articless['sProperties']) > 0))
                    {
                        $attributes = array();
                        
                        foreach($articless['sProperties'] as $propertyValue)
                        {
                            $group = $propertyValue['name'];

                            if(array_key_exists($group, $attributes))
                            {
                                $attributes[$group] .= ', ' . $propertyValue['value'];
                            }
                            else
                            {
                                $attributes[$group] = $propertyValue['value'];
                            }
                            
                            // Anzahl der zu uebertragenden Merkmale erreicht
                            if(count($attributes) >= $countpropertyvalues)
                            {
                                break;
                            }
			}
                        
                        //__d($attributes, 'new way attributes');

			$VIAeBay->setProductSpecifics($articleResponseId, $attributes);
                    }
                    else if(is_array($article['propertyValues']) && count($article['propertyValues']) > 0)
                    {
                        $attributes = array();

			foreach($article['propertyValues'] as $propertyValue)
                        {
                            $group = Shopware()->Db()->fetchOne('SELECT name FROM s_filter_options WHERE id='.$propertyValue['optionId']);

                            if(array_key_exists($group, $attributes))
                            {
                                $attributes[$group] .= ', ' . $propertyValue['value'];
                            }
                            else
                            {
                                $attributes[$group] = $propertyValue['value'];
                            }
                            
                            // Anzahl der zu uebertragenden Merkmale erreicht
                            if(count($attributes) >= $config->countpropertyvalues)
                            {
                                break;
                            }
			}
                        
                        $VIAeBay->setProductSpecifics($articleResponseId, $attributes);
                    }
		}

		/**
		 * get variations article data for VIA eBay
		 * @param Int $articleContainerResponseId Main Article Ressource ID from VIA eBay
		 * @param Array $article Main Article Data
		 * @param Array $articleDetail Detail Data of Article or Variants
		 * @return Array variations Article Data for VIA eBay
		 */
		protected static function getArticleVariationsData($articleContainerResponseId, $article, $articleDetail) {
                        $config = Shopware()->Plugins()->Backend()->viaebay()->Config();
                    
                        
                        // falls mal kein lagerbestand da ist bzw. der datensatzt keinen gueltigen
                        // wert enthaelt, dann setze wenigtens 0 als Lagerbestand zum Uebertragen
                        if(!isset($articleDetail['inStock']) || $articleDetail['inStock'] == '')
                        {
                            $articleDetail['inStock'] = 0;
                        }
                        
                        

                        // alter weg - neuer weg - damit die variante auf VIA eBay aktiv bleibt auch wenn sie im shop deaktiviert wurde
			// if((int)$articleDetail['inStock'] < (int)0)
			//	$articleDetail['inStock'] = 0;
                        
                        // neuer weg - damit die variante auf VIA eBay aktiv bleibt auch wenn sie im shop deaktiviert wurde
                        if($config->sale_actice == true && (int)$article['lastStock'] == (int)0) {
                            
                            if((int)$articleDetail['inStock'] <= (int)0) {
                                $articleDetail['inStock'] = (int)$config->default_stock_amount;
                            }
                            
                        } else {
                            
                            if((int)$articleDetail['inStock'] < (int)0) {
                                $articleDetail['inStock'] = 0;
                            }
                            
                        }
                    
                        
                        if (is_array($articleDetail['prices']) && count($articleDetail['prices']) > 1) {
                            
                            foreach($articleDetail['prices'] as $price) {
                                
                                if ($price['from'] == '1') {
                                
                                    if($price['customerGroupKey'] == $config->articleexportcustomergroupprice) {
                                            $customerGroupPrice = $price['price'];
                                    } elseif($price['customerGroupKey'] == 'EK') {
                                            $fallbackPrice = $price['price'];
                                            $fallbackPseudoPrice = $price['pseudoPrice'];
                                    }
                                }
                            }
                            
                        } else {
                            
                            foreach($articleDetail['prices'] as $price) {
                                    if($price['customerGroupKey'] == $config->articleexportcustomergroupprice) {
                                            $customerGroupPrice = $price['price'];
                                    } elseif($price['customerGroupKey'] == 'EK') {
                                            $fallbackPrice = $price['price'];
                                    }
                            }
                        }

			$articlePrice = ($customerGroupPrice) ? $customerGroupPrice : $fallbackPrice;
                        
                        
                        // deaktivierte artikel mit lagerbestand "0" uebertragen
                        if($config->zeroqty && ((int)$articleDetail['active'] == (int)0 || (int)$article['active'] == (int)0))
                        {
                            $articleDetail['inStock'] = 0;
                        }
                        
                        
			return $articleData = array(
				'ProductId' => $articleContainerResponseId,
				'Price' => round($articlePrice / 100 * (100 + $article['tax']['tax']), 2),
				'StockAmount' => $articleDetail['inStock'],
				'Sku' => $articleDetail['number'],
			);
		}

		/**
		 * get article attributes for VIA eBay
		 * @param Array $configuratorOptions Configurator Options Array
		 * @return Array attributes array for VIA eBay
		 */
		protected static function getArticleAttributes($configuratorOptions) {
			$attributes = array();

			foreach($configuratorOptions as $configuratorOption)
				$attributes[Shopware()->Db()->fetchOne('SELECT name FROM s_article_configurator_groups WHERE id='.$configuratorOption['groupId'])] = $configuratorOption['name'];

			return $attributes;
		}

		###########################
		### Export Articles END ###
		###########################

		#############################
		### Delete Articles START ###
		#############################

		/**
		 * delete multiple article in VIA-eBay
		 */
		public function deleteMultipleArticlesIneBayAction($articleIDs = false, $notVIAeBayDropdownAction = false, $articleisdeletedinshopware = false) {
			$VIAeBay = new VIAeBay();

			if(!$articleIDs)
				$articleIDs = json_decode($this->Request()->productIDs);

			if(!self::$logFile)
				self::$logFile = 'deletearticles_'.date('Ymd_His').'.txt';

			if(!self::$fp)
				self::$fp = @fopen(dirname(__FILE__).'/../../logs/'.self::$logFile, "a+");

			foreach($articleIDs as $articleID) {
				$articleRessourceID = self::getArticleRessourceID($articleID);

				if($articleRessourceID)
					$result = $VIAeBay->deleteProduct($articleRessourceID);

                                
                                if($articleisdeletedinshopware)
                                {
                                    Shopware()->Db()->Exec('DELETE FROM swp_viaebay_articles WHERE articleID='.$articleID);
                                }
                                else
                                {
                                    Shopware()->Db()->Exec('UPDATE swp_viaebay_articles SET swp_viaebay_container_id = NULL, swp_viaebay_id = NULL WHERE articleID='.$articleID);
                                }
                                
                                
                                // ST: damit auch bei den varianten die viaebay_id geloescht wird. gab sonst das problem, dass der artikel nicht mehr angelegt werden konnte
                                $articles_variations = Shopware()->Db()->fetchAll('SELECT id FROM s_articles_details WHERE articleID='.$articleID);    
                                        
                                if (is_array($articles_variations) && count($articles_variations) > 0) {
                                            
                                    foreach ($articles_variations as $avK => $avVal) {
                                        
                                        
                                        if($articleisdeletedinshopware)
                                        {
                                            Shopware()->Db()->Exec('DELETE FROM swp_viaebay_articles WHERE articledetailsID='.$avVal['id']);
                                        }
                                        else
                                        {
                                            Shopware()->Db()->Exec('UPDATE swp_viaebay_articles SET swp_viaebay_container_id = NULL, swp_viaebay_id = NULL WHERE articledetailsID='.$avVal['id']);
                                        }
                                    }
                                }
                                        

				if($result)
					self::$deleteSuccess++;
				else
					self::$deleteFailure++;

				$errors = self::checkApiError($VIAeBay);

				if($errors['error']) {
					$articleData = Shopware()->Db()->fetchRow('SELECT a.name, ad.ordernumber FROM s_articles AS a INNER JOIN s_articles_details AS ad ON a.id=ad.articleID WHERE a.id='.$articleID);

					fwrite(self::$fp, 'Artikelnummer: '.$articleData['ordernumber'].' [VIA-Connect ProductsID: '.$articleRessourceID.'] ('.$articleData['name'].')'."\n");

					foreach($errors['list'] as $errorText)
						fwrite(self::$fp, '* '.$errorText."\n");

					fwrite(self::$fp, "\n\n--------------------------------------------------------------------\n\n");
				}
			}

			fclose(self::$fp);

			if(!$notVIAeBayDropdownAction)
				$this->View()->assign(array('total' => (self::$deleteSuccess+self::$deleteFailure), 'deleteSuccess' => self::$deleteSuccess, 'deleteFailure' => self::$deleteFailure, 'logFile' => self::$logFile));
		}

		/**
		 * delete all articles in VIA-eBay
		 */
		public function deleteAllArticlesIneBayAction() {
			$VIAeBay = new VIAeBay();

                        
                        $articles = Shopware()->Db()->fetchCol('SELECT articleID FROM swp_viaebay_articles WHERE swp_viaebay_container_id IS NOT NULL OR swp_viaebay_id IS NOT NULL GROUP BY articleID');
                        
                        
			if(!self::$logFile)
				self::$logFile = 'deletearticles_'.date('Ymd_His').'.txt';

			if(!self::$fp)
				self::$fp = @fopen(dirname(__FILE__).'/../../logs/'.self::$logFile, "a+");

			foreach($articles as $articleID) {
				$articleRessourceID = self::getArticleRessourceID($articleID);

				if($articleRessourceID) {
					$result = $VIAeBay->deleteProduct($articleRessourceID);

                                        
                                        Shopware()->Db()->Exec('UPDATE swp_viaebay_articles SET swp_viaebay_container_id = NULL, swp_viaebay_id = NULL WHERE articleID='.$articleID);
                                        
                                        
                                        // ST: damit auch bei den varianten die viaebay_id geloescht wird. gab sonst das problem, dass der artikel nicht mehr angelegt werden konnte
                                        $articles_variations = Shopware()->Db()->fetchAll('SELECT id FROM s_articles_details WHERE articleID='.$articleID);    
                                        
                                        if (is_array($articles_variations) && count($articles_variations) > 0) {
                                            
                                            foreach ($articles_variations as $avK => $avVal) {
                                                
                                                
                                                Shopware()->Db()->Exec('UPDATE swp_viaebay_articles SET swp_viaebay_container_id = NULL, swp_viaebay_id = NULL WHERE articledetailsID='.$avVal['id']);
                                            }
                                        }
                                        
                                        
					if($result)
						self::$deleteSuccess++;
					else
						self::$deleteFailure++;

					$errors = self::checkApiError($VIAeBay);

					if($errors['error']) {
						$articleData = Shopware()->Db()->fetchRow('SELECT a.name, ad.ordernumber FROM s_articles AS a INNER JOIN s_articles_details AS ad ON a.id=ad.articleID WHERE a.id='.$articleID);

						fwrite(self::$fp, 'Artikelnummer: '.$articleData['ordernumber'].' [VIA-Connect ProductsID: '.$articleRessourceID.'] ('.$articleData['name'].')'."\n");

						foreach($errors['list'] as $errorText)
							fwrite(self::$fp, '* '.$errorText."\n");

						fwrite(self::$fp, "\n\n--------------------------------------------------------------------\n\n");
					}
				}
			}

			fclose(self::$fp);

			$this->View()->assign(array('total' => (self::$deleteSuccess+self::$deleteFailure), 'deleteSuccess' => self::$deleteSuccess, 'deleteFailure' => self::$deleteFailure, 'logFile' => self::$logFile));
		}

		/**
		 * get the VIA-eBay article ressource ID
		 * @param Int $articleID article ID
		 */
		protected function getArticleRessourceID($articleID) {
			$VIAeBayRessourceID = false;

                        
                        if($VIAeBayRessourceID = Shopware()->Db()->fetchOne('SELECT swp_viaebay_container_id FROM swp_viaebay_articles WHERE articleID="'.$articleID.'" AND swp_viaebay_container_id IS NOT NULL'))
				return $VIAeBayRessourceID;
			elseif($VIAeBayRessourceID = Shopware()->Db()->fetchOne('SELECT swp_viaebay_id FROM swp_viaebay_articles WHERE articleID="'.$articleID.'" AND swp_viaebay_id IS NOT NULL'))
				return $VIAeBayRessourceID;
			else
				return false;
		}

		/**
		 * delete submitted articles when they now deactivated
		 */
		protected function deleteDeactivatedButSubmittedArticlesInVIAeBay($articleID = false) {
//TODO Funktionalität wurde vorerst wieder deaktiviert
return;


__d('deleteDeactivatedButSubmittedArticlesInVIAeBay');


                        
                        if($articleID)
				$articleIDs = array($articleID);
			else
				$articleIDs = Shopware()->Db()->fetchCol('
					SELECT articles.id AS articleID
					FROM s_articles AS articles JOIN swp_viaebay_articles AS va ON articles.id=va.articleID
					WHERE articles.active=0 AND (va.swp_viaebay_container_id IS NOT NULL OR va.swp_viaebay_id IS NOT NULL)
					GROUP BY articles.id
				');
                        

			if($articleIDs)
				self::deleteMultipleArticlesIneBayAction($articleIDs, true);
		}

		/**
		 * delete article variants
		 */
		public function deleteVariantsInVIAeBay($details) {
			$VIAeBay = new VIAeBay();

			if(!self::$logFile)
				self::$logFile = 'deletearticles_'.date('Ymd_His').'.txt';

			if(!self::$fp)
				self::$fp = @fopen(dirname(__FILE__).'/../../logs/'.self::$logFile, "a+");

			foreach($details as $detail) {
                                
                                $VIAeBayID = Shopware()->Db()->fetchOne('SELECT swp_viaebay_id FROM swp_viaebay_articles WHERE articledetailsID="'.$detail['id'].'"');

                                
				if(!$VIAeBayID) continue;

				$VIAeBay->deleteProductVariations($VIAeBayID);

				$errors = self::checkApiError($VIAeBay);

				if($errors['error']) {
					$articleData = Shopware()->Db()->fetchRow('SELECT a.name, ad.ordernumber FROM s_articles AS a INNER JOIN s_articles_details AS ad ON a.id=ad.articleID WHERE ad.id='.$detail['id']);

					fwrite(self::$fp, 'Artikelnummer: '.$articleData['ordernumber'].' [VIA-Connect ProductsID: '.$VIAeBayID.'] ('.$articleData['name'].')'."\n");

					foreach($errors['list'] as $errorText)
						fwrite(self::$fp, '* '.$errorText."\n");

					fwrite(self::$fp, "\n\n--------------------------------------------------------------------\n\n");
				}
			}

			fclose(self::$fp);
		}

		###########################
		### Delete Articles END ###
		###########################

		###########################
		### Import Orders START ###
		###########################

                public function cronVIAeBayOrdersAction()
                {
                    $config = Shopware()->Plugins()->Backend()->viaebay()->Config();
                    
                    $cronPassword = $this->Request()->getParam('pass');
                    
                    $offset = $this->Request()->getParam('offset', 0);
                    $limit = ($config->cronjoblimitorders != '') ? $config->cronjoblimitorders : 50; 
                    
                    $filename = dirname(__FILE__).'/../../logs/orders.txt';
                    
                    $the_end = false;
                    
                    
                    if($config->cronjobpass === $cronPassword)
                    {
                        $VIAeBay = new VIAeBay();
                        
                        
                        if($offset == 0)
                        {
                            self::$logFile = 'orderimport_'.date('Ymd_His').'.txt';
                            
                            $orders = $VIAeBay->getSalesOrders();
                            
                            $fp_orders = @fopen($filename, "w");
                            fwrite($fp_orders, print_r(serialize($orders->d), true));
                            fclose($fp_orders);
                        }
                        else
                        {
                            self::$logFile = $this->Request()->getParam('logFile');
                            
                            $orders->d = unserialize(file_get_contents($filename));
                        }
                        
                        
                        // keine bestellung von viaebay geholt
                        if(!is_array($orders->d) || count($orders->d) < 1)
                        {
                            $the_end = true;
                        }
                        
                        $proc_orders = array_slice($orders->d, $offset, $limit);
                        
                        // keine bestellungen mehr zu verarbeiten
                        if(!is_array($proc_orders) || count($proc_orders) < 1)
                        {
                            $the_end = true;
                        }
                        
                        
                        if($the_end)
                        {
                            unlink($filename);
                            
                            if(!self::$fp)
				self::$fp = @fopen(dirname(__FILE__).'/../../logs/'.self::$logFile, "a+");
                            
                            fwrite(self::$fp, "\n\ncronVIAeBayOrders finished\n\n");
                            
                            fclose(self::$fp);
                            
                            
                            // Bestelldaten bei VIAeBay aktualisieren
                            $url_array = (array('sViewport' => 'viaebay', 'action' => 'cronUpdateVIAeBayOrderData', 'pass' => $cronPassword));
                            $url = Shopware()->Front()->Router()->assemble($url_array);
                            header('Location: '.$url);
                            exit(0);
                        }
                        else
                        {
                            $this->importOrders($proc_orders, $VIAeBay, true);
                            
                            $url_array = (array('sViewport' => 'viaebay', 'action' => 'cronVIAeBayOrders', 'offset' => ($offset+$limit), 'logFile' => self::$logFile, 'pass' => $cronPassword));
                            $url = Shopware()->Front()->Router()->assemble($url_array);
                            header('Location: '.$url);
                            exit(0);
                        }
                        
                        
                    }
                    else
                    {
                        die('Permission denied');
                    }                   
                }
                
                
		/**
		 * get the Orders from VIA eBay and import or Update in Shopware
		 */
		public function getVIAeBayOrdersAction($cron = false)
                {
                    $VIAeBay = new VIAeBay();
                    $orders = $VIAeBay->getSalesOrders();
                        
                    if(is_array($orders->d) && count($orders->d) > 0)
                    {
                        $this->importOrders($orders->d, $VIAeBay, $cron);
                    }

                    // Bestelldaten bei VIAeBay aktualisieren
                    self::updateVIAeBayOrderData();
                        
                    if(!$cron)
                    {
                        $this->View()->assign(array('total' => (self::$orderSuccess+self::$orderFailure), 'ordersSuccess' => self::$orderSuccess, 'ordersFailure' => self::$orderFailure, 'logFile' => self::$logFile));
                    }
		}
                
                
                /**
		 * process the Orders from VIA eBay and import or Update in Shopware
		 */
                protected function importOrders($proc_orders, $VIAeBay, $cron = false)
                {
                    $config = Shopware()->Plugins()->Backend()->viaebay()->Config();
                    
                    if(!self::$logFile)
                    {
                        self::$logFile = 'orderimport_'.date('Ymd_His').'.txt';
                    }

                    if(!self::$fp)
                    {
                        self::$fp = @fopen(dirname(__FILE__).'/../../logs/'.self::$logFile, "a+");
                    }
                    
                    
                    foreach($proc_orders as $order)
                    {
                        try
                        {
                            $checkOrder = Shopware()->Db()->fetchOne('SELECT orderID FROM s_order_attributes WHERE swp_viaebay_id='.$order->Id);

                            if(!$checkOrder)
                            {
                                $userID = self::importCustomerAsGuest($order);
                                $orderID = self::createOrderMainData($VIAeBay, $order, $userID);
                                self::createOrderBillingAddressData($orderID, $userID, ($order->Address) ?: $order->ShippingAddress);
                                self::createOrderShippingAddressData($orderID, $userID, ($order->ShippingAddress) ?: $order->Address);

                                $shippingCountry = ($order->ShippingAddress->Country) ? $order->ShippingAddress->Country : $order->Address->Country;
                                $shippingCountryData = self::getCounzryData($shippingCountry);

                                if(!is_array($shippingCountryData) || count($shippingCountryData) <= 0)
                                {
                                    $shippingCountryData = array();
                                }                                                

                                self::createOrderDetailsData($VIAeBay, $orderID, $order->SalesOrderItems, $shippingCountryData);
                            }
                            else
                            {
                                $paymentcompletestatus_config = self::getPaymentOptionPaymentCompleteConfig($order->PaymentOption);
                                self::updateOrderStatus($order, $config->shippingcompletestatus, $config->$paymentcompletestatus_config);
                            }

                            self::$orderSuccess++;
                        } 
                        catch(Exception $e)
                        {
                            fwrite(self::$fp, 'VIA-Connect Bestellnummer (SalesOrderId): '.$order->Id."\n");
                            fwrite(self::$fp, $e->getTraceAsString()."\n");
                            fwrite(self::$fp, "\n\n--------------------------------------------------------------------\n\n");

                            self::$orderFailure++;

                            continue;
                        }    
                    }
                    
                    if(!$cron)
                    {
                        fclose(self::$fp);
                    }
                }



                /**
		 * import the VIA eBay customer as guest in Shopware
		 * @param Object $order Order from VIA eBay
		 * @return Int new userID from Shopware
		 */
		protected static function importCustomerAsGuest($order) {
			self::splitStreetAndHouseNo($billingStreet, $order->Address->Street);
			self::splitStreetAndHouseNo($shippingStreet, $order->ShippingAddress->Street);
			$billingCountryID = self::getCounzryID($order->Address->Country);
			$shippingCountryID = self::getCounzryID($order->ShippingAddress->Country);

			if($billingCountryID) {
				$billingStateID = self::getStateID($billingCountryID, $order->Address->State);
                        } else {
				$billingCountryID = 0;
				$billingStateID = 0;
			}

			if($shippingCountryID) {
				$shippingStateID = self::getStateID($shippingCountryID, $order->ShippingAddress->State);
                        } else {
				$shippingCountryID = 0;
				$shippingStateID = 0;
			}
                        
                        $config = Shopware()->Plugins()->Backend()->viaebay()->Config();

			$data = array(
				'email' => $order->Address->Email,
				'accountMode' => '1',
                                'groupKey' => $config->articleexportcustomergroupprice,
				'internalComment' => 'VIA eBay Import',
                                'firstname' => ($order->Address->Name) ?: '', // zusaetzlich benoetigt seit sw 5.2.2
                                'lastname' => ($order->Address->Surname) ?: '', // zusaetzlich benoetigt seit sw 5.2.2
                                'salutation' => self::getSalutation($order->Address->Salutation), // zusaetzlich benoetigt seit sw 5.2.2
				'billing' => array(
					'company' => ($order->Address->Company && $order->Address->Company != '-') ?: '',
					'salutation' => self::getSalutation($order->Address->Salutation),
					'firstName' => ($order->Address->Name) ?: '',
                                        'firstname' => ($order->Address->Name) ?: '', // zusaetzlich benoetigt seit sw 5.2.2
					'lastName' => ($order->Address->Surname) ?: '',
                                        'lastname' => ($order->Address->Surname) ?: '', // zusaetzlich benoetigt seit sw 5.2.2
					'street' => ($billingStreet->Street) ?: '',
					'streetNumber' => ($billingStreet->HouseNo) ?: '',
                                        'streetnumber' => ($billingStreet->HouseNo) ?: '', // zusaetzlich benoetigt seit sw 5.2.2
					'zipCode' => ($order->Address->PostalCode) ?: '',
                                        'zipcode' => ($order->Address->PostalCode) ?: '', // zusaetzlich benoetigt seit sw 5.2.2
					'city' => ($order->Address->Town) ?: '',
					'countryId' => ($billingCountryID) ?: '',
                                        'country' => ($billingCountryID) ?: 0, // zusaetzlich benoetigt seit sw 5.2.2
					'stateId' => ($billingStateID) ?: '',
                                        'state' => ($billingStateID) ?: 0, // zusaetzlich benoetigt seit sw 5.2.2
					'phone' => ($order->Address->Phone) ?: '-' // muss so seit der 5.2 wenn telefon als pflichtfeld eingestellt
				),
				'shipping' => array(
					'company' => ($order->ShippingAddress->Company && $order->ShippingAddress->Company != '-') ?: '',
					'salutation' => self::getSalutation($order->ShippingAddress->Salutation),
					'firstName' => ($order->ShippingAddress->Name) ?: '',
                                        'firstname' => ($order->ShippingAddress->Name) ?: '', // zusaetzlich benoetigt seit sw 5.2.2
					'lastName' => ($order->ShippingAddress->Surname) ?: '',
                                        'lastname' => ($order->ShippingAddress->Surname) ?: '', // zusaetzlich benoetigt seit sw 5.2.2
					'street' => ($shippingStreet->Street) ?: '',
					'streetNumber' => ($shippingStreet->HouseNo) ?: '',
                                        'streetnumber' => ($shippingStreet->HouseNo) ?: '', // zusaetzlich benoetigt seit sw 5.2.2
					'zipCode' => ($order->ShippingAddress->PostalCode) ?: '',
                                        'zipcode' => ($order->ShippingAddress->PostalCode) ?: '', // zusaetzlich benoetigt seit sw 5.2.2    
					'city' => ($order->ShippingAddress->Town) ?: '',
					'countryId' => ($shippingCountryID) ?: '',
                                        'country' => ($shippingCountryID) ?: 0, // zusaetzlich benoetigt seit sw 5.2.2
					'stateId' => ($shippingStateID) ?: '',
                                        'state' => ($shippingStateID) ?: 0, // zusaetzlich benoetigt seit sw 5.2.2
                                        'phone' => ($order->ShippingAddress->Phone) ?: '-' // muss so seit der 5.2 wenn telefon als pflichtfeld eingestellt
				)
			);
                        
                        $paymentID = self::getShopPaymentID($order->PaymentOption);

			if($paymentID) {
                            $data['paymentID'] = $paymentID;
                        } else {
                            $data['paymentID'] = 5;
                        }
                        

			$userResource = \Shopware\Components\Api\Manager::getResource('customer');

			$newUser = $userResource->create($data);
			$newUserID = $newUser->getId();

			return $newUserID;
		}

		/**
		 * create the order main data
		 * @param Object $order The VIA eBay Order Ressource
		 * @return Int Order ID from Shopware
		 */
		protected static function createOrderMainData($VIAeBay, $order, $userID) {
			date_default_timezone_set('Europe/Berlin');

			$config = Shopware()->Plugins()->Backend()->viaebay()->Config();

			$products_comment = '';
			$shipping_tax = 0;
                        $totalprice_tax = 0;
                        
                        $shippingCountry = ($order->ShippingAddress->Country) ? $order->ShippingAddress->Country : $order->Address->Country;
                        $shippingCountryData = self::getCounzryData($shippingCountry);
                        $net = 0;
                        $taxfree = 0;
                        
                        if(is_array($shippingCountryData) && count($shippingCountryData)>0) {
                         
                            if($shippingCountryData['taxfree']  == "1") {
                                        
                                $net = 1;
                                $taxfree = 1;
                                        
                            }
                                    
                        }
                        
                        

			foreach($order->SalesOrderItems as $orderDetail) {
				$articleordernumber = false;

                                
                                if($orderDetail->ProductVariationId)
					$articleordernumber = Shopware()->Db()->fetchOne('SELECT ad.ordernumber FROM s_articles_details AS ad INNER JOIN swp_viaebay_articles AS va ON ad.id=va.articledetailsID WHERE va.swp_viaebay_id='.$orderDetail->ProductVariationId);
				elseif($orderDetail->ForeignId)
					$articleordernumber = $orderDetail->ForeignId;
				else
					$articleordernumber = $orderDetail->ProductId;
                                

				if(!$articleordernumber)
					$articleordernumber = '-';

				$products_comment .= PHP_EOL.$articleordernumber.' - '.$orderDetail->PlatformItemId;

				$tax = self::getArticleTax($orderDetail->ForeignId);

				if($tax > $shipping_tax)
					$shipping_tax = $tax;
                                
                                if($tax > $totalprice_tax)
					$totalprice_tax = $tax;
			}
                        
                        if ($net == 1)
                        {
                            $invoice_shipping_net = $order->ShippingServiceCost;
                            $invoice_amount_net = ($order->TotalPrice + $order->ShippingServiceCost);
                        }
                        else
                        {
                            $invoice_shipping_net = round($order->ShippingServiceCost/(100+$shipping_tax)*100, 2);
                            $invoice_amount_net = round($order->TotalPrice/(100+$totalprice_tax)*100, 2);
                            $invoice_amount_net += $invoice_shipping_net;
                        }
                        
                        
                        $repository = Shopware()->Models()->getRepository('Shopware\Models\Shop\Shop');
                        $shop = $repository->getActiveById(1);
                        $shop->registerResources(Shopware()->Bootstrap());
                        $mainShop = $shop->getMain() !== null ? $shop->getMain() : $shop;
                        
                        
			$sOrder = array(
				'ordernumber' => Shopware()->System()->sMODULES['sOrder']->sGetOrderNumber(),
				'userID' => $userID,
				'invoice_amount' => ($order->TotalPrice + $order->ShippingServiceCost),
                                //'invoice_amount_net' => ($order->TotalPrice + $order->ShippingServiceCost), // dieser eintrag wird fuer die statistik vom shopware partnerprogramm benoetigt
                                'invoice_amount_net' => $invoice_amount_net, // dieser eintrag wird fuer die statistik vom shopware partnerprogramm benoetigt
				'invoice_shipping' => $order->ShippingServiceCost,
				// 'invoice_shipping_net' => round($order->ShippingServiceCost/(100+$shipping_tax)*100, 2),
                                'invoice_shipping_net' => $invoice_shipping_net,
				//'language' => Shopware()->Db()->fetchOne('SELECT id FROM s_core_multilanguage WHERE `default`=1'),
                                'language' => $shop->getId(),
				'ordertime' => date('Y-m-d H:i:s', preg_replace('/[^\d]/','', $order->CreationDate)/1000),
				'net' => $net,
				'internalcomment' => 'VIA eBay Import'.PHP_EOL.$order->ShippingService.PHP_EOL.$order->Buyer->BuyerName.PHP_EOL.$products_comment,
				'taxfree' => $taxfree,
				//'dispatchID' => Shopware()->Db()->fetchOne('SELECT id FROM s_premium_dispatch WHERE name="Versand"'),
				'currency' => $order->CurrencyCode,
                                'currencyFactor' => '1',
				//'subshopID' => Shopware()->Db()->fetchOne('SELECT id FROM s_core_shops WHERE main_id IS NULL'),
                                'subshopID' => $mainShop->getId(),
			);
                        
                        $dispatchID = self::getShopShippingID($order->ShippingService);

                        if($dispatchID) {
                            $sOrder['dispatchID'] = $dispatchID;
                        } else {
                            $sOrder['dispatchID'] = Shopware()->Db()->fetchOne('SELECT id FROM s_premium_dispatch WHERE name="eBay"');
                        }
                        

			$paymentID = self::getShopPaymentID($order->PaymentOption);

                        if($paymentID) {
                            $sOrder['paymentID'] = $paymentID;
                        } else {
                            $sOrder['paymentID'] = 5;
                        }

			if($order->PaymentTransactionId)
				$sOrder['transactionID'] = $order->PaymentTransactionId;

			if($order->MarkedAsShipped && $config->shippingcompletestatus)
				$sOrder['status'] = $config->shippingcompletestatus;
			else
				$sOrder['status'] = '0';

                        
                        $paymentcompletestatus_config = self::getPaymentOptionPaymentCompleteConfig($order->PaymentOption);
                        if($order->MarkedAsPayed && $config->$paymentcompletestatus_config)
				$sOrder['cleared'] = $config->$paymentcompletestatus_config;
			else
				$sOrder['cleared'] = '17';
                        
                        
			if($order->PaidDate)
				$sOrder['cleareddate'] = date('Y-m-d H:i:s', preg_replace('/[^\d]/','', $order->PaidDate)/1000);

			if($order->BuyerCheckoutMessage)
				$sOrder['customercomment'] = $order->BuyerCheckoutMessage;
                        
                        
                        // partnerprogramm / bestellstatistik
                        $sOrder['partnerID'] = 'viaebay';

                        
			Shopware()->Db()->insert('s_order', $sOrder);

			$orderID = Shopware()->Db()->lastInsertId();

			$sOrderAttributes = array(
				'orderID' => $orderID,
				'swp_viaebay_id' => $order->Id,
                                'swp_viaebay_byer_package_enclosure' => $order->BuyerPackageEnclosure,
                                //'swp_viaebay_carrier_used' => $order->ShippingService,
                                'swp_viaebay_carrier_used' => self::getShippingServiceToVersandartBezeichnung($order->ShippingService),
                                'swp_viaebay_payment_option' => $order->PaymentOption,
			);
                        
			Shopware()->Db()->insert('s_order_attributes', $sOrderAttributes);

			$VIAeBay->updateForeignOrderID($order->Id, (string)$sOrder['ordernumber']);

			return $orderID;
		}

		/**
		 * create the Order Billing Address in Shopware
		 * @param Int $orderID Order ID
		 * @param Object $billingAddress VIA eBay Billing Adress Ressource
		 */
		protected static function createOrderBillingAddressData($orderID, $userID, $billingAddress) {
			self::splitStreetAndHouseNo($street, $billingAddress->Street);
			$countryID = self::getCounzryID($billingAddress->Country);

			if($countryID) {
				$StateID = self::getStateID($countryID, $billingAddress->State);
                        } else {
				$countryID = 0;
				$StateID = 0;
			}

			$sOrderBillingAddress = array(
				'userID' => $userID,
				'orderID' => $orderID,
				'company' => ($billingAddress->Company && $billingAddress->Company != '-') ?: '',
				'salutation' => self::getSalutation($billingAddress->Salutation),
				'firstname' => ($billingAddress->Name) ?: '',
				'lastname' => ($billingAddress->Surname) ?: '',
				//'street' => ($street->Street) ?: '',
				//'streetnumber' => ($street->HouseNo) ?: '',
				'zipcode' => ($billingAddress->PostalCode) ?: '',
				'city' => ($billingAddress->Town) ?: '',
				'phone' => ($billingAddress->Phone) ?: '-', // muss so seit der 5.2 wenn telefon als pflichtfeld eingestellt
				'countryID' => $countryID,
				'stateID' => $StateID
			);
                        // weil ab SW5 strasse und hausnummer nicht mehr getrennt sind
                        if(Shopware_Plugins_Backend_viaebay_Bootstrap::FieldExists('streetnumber', 's_order_billingaddress')){
                            $sOrderBillingAddress['street'] = ($street->Street) ?: '';
                            $sOrderBillingAddress['streetnumber'] = ($street->HouseNo) ?: '';
                        } else {
                            $sOrderBillingAddress['street'] = ($billingAddress->Street) ?: '';
                        }

			Shopware()->Db()->insert('s_order_billingaddress', $sOrderBillingAddress);

			$billingID = Shopware()->Db()->lastInsertId();

			$sOrderBillingAddressAttributes = array(
				'billingID' => $billingID,
				'swp_viaebay_id' => $billingAddress->Id
			);

			Shopware()->Db()->insert('s_order_billingaddress_attributes', $sOrderBillingAddressAttributes);
		}

		/**
		 * create the Order Shipping Address in Shopware
		 * @param Int $orderID Order ID
		 * @param Object $shippingAddress VIA eBay Shipping Adress Ressource
		 */
		protected static function createOrderShippingAddressData($orderID, $userID, $shippingAddress) {
			self::splitStreetAndHouseNo($street, $shippingAddress->Street);
			$countryID = self::getCounzryID($shippingAddress->Country);

			if($countryID) {
				$StateID = self::getStateID($countryID, $shippingAddress->State);
                        } else {
				$countryID = 0;
				$StateID = 0;
			}

			$sOrderShippingAddress = array(
				'userID' => $userID,
				'orderID' => $orderID,
				'company' => ($shippingAddress->Company && $shippingAddress->Company != '-') ?: '',
				'salutation' => self::getSalutation($shippingAddress->Salutation),
				'firstname' => ($shippingAddress->Name) ?: '',
				'lastname' => ($shippingAddress->Surname) ?: '',
				//'street' => ($street->Street) ?: '',
				//'streetnumber' => ($street->HouseNo) ?: '',
				'zipcode' => ($shippingAddress->PostalCode) ?: '',
				'city' => ($shippingAddress->Town) ?: '',
				'countryID' => $countryID,
				'stateID' => $StateID                                
			);
                        // weil ab SW5 strasse und hausnummer nicht mehr getrennt sind
                        if(Shopware_Plugins_Backend_viaebay_Bootstrap::FieldExists('streetnumber', 's_order_shippingaddress')){
                            $sOrderShippingAddress['street'] = ($street->Street) ?: '';
                            $sOrderShippingAddress['streetnumber'] = ($street->HouseNo) ?: '';
                        } else {
                            $sOrderShippingAddress['street'] = ($shippingAddress->Street) ?: '';
                        }

			Shopware()->Db()->insert('s_order_shippingaddress', $sOrderShippingAddress);

			$shippingID = Shopware()->Db()->lastInsertId();

			$sOrderShippingAddressAttributes = array(
				'shippingID' => $shippingID,
				'swp_viaebay_id' => $shippingAddress->Id
			);

			Shopware()->Db()->insert('s_order_shippingaddress_attributes', $sOrderShippingAddressAttributes);
		}

		/**
		 * create the ordered Articles in Shopware
		 * @param Int $orderID Order ID
		 * @param Array $orderDetails Array with ordered Articles
		 */
		protected static function createOrderDetailsData($VIAeBay, $orderID, $orderDetails, $shippingCountryData) {
			foreach($orderDetails as $orderDetail) {
                            
                            $taxID = self::getArticleTaxID($orderDetail->ForeignId);
                            $tax_rate = self::getArticleTax($orderDetail->ForeignId);
                            
                            if(is_array($shippingCountryData) && count($shippingCountryData)>0) {

                                if($shippingCountryData['taxfree']  == "1") {
                                    
                                    $taxID = 0;
                                    $tax_rate = 0;

                                } else {
                                    
                                    $shippingCountryTaxRule = self::getCounzryTaxRule($shippingCountryData['id'], $taxID);
                                    
                                    if(is_array($shippingCountryTaxRule) && count($shippingCountryTaxRule)>0) {
                                        
                                        $tax_rate = $shippingCountryTaxRule['tax'];
                                        
                                    }
                                    
                                }

                            }
                            
                            // mit tax
                            $articlePrice = $orderDetail->Price;
                            
                            
                            // ohne tax - nicht noetig, da shopware preis als brutto in datenbank speichert
                            //$articlePrice = ($articlePrice / (($tax_rate +100) / 100));
                            
                            
                                
                                if($orderDetail->ProductVariationId)
					$name = Shopware()->Db()->fetchOne('SELECT a.name FROM s_articles AS a INNER JOIN swp_viaebay_articles as va ON a.id=va.articleID WHERE va.swp_viaebay_id='.$orderDetail->ProductVariationId);
				elseif($orderDetail->Name)
					$name = $orderDetail->Name;

                                
				if(!$name)
					$name = '-';

                                
                                if($orderDetail->ProductVariationId)
					$articleordernumber = Shopware()->Db()->fetchOne('SELECT ad.ordernumber FROM s_articles_details AS ad INNER JOIN swp_viaebay_articles AS va ON ad.id=va.articledetailsID WHERE va.swp_viaebay_id='.$orderDetail->ProductVariationId);
				elseif($orderDetail->ForeignId)
					$articleordernumber = $orderDetail->ForeignId;
				else
					$articleordernumber = $orderDetail->ProductId;
                                

				if(!$articleordernumber)
					$articleordernumber = '-';
                                
                                //__d($orderDetail);
                                
                                
                                if($orderDetail->ProductVariationId) {
                                    $articleID = Shopware()->Db()->fetchOne('SELECT articleID FROM swp_viaebay_articles WHERE swp_viaebay_id='.$orderDetail->ProductVariationId);
                                } elseif($orderDetail->ForeignId) {
                                    $articleID = Shopware()->Db()->fetchOne('SELECT va.articleID FROM s_articles_details AS ad INNER JOIN swp_viaebay_articles AS va ON ad.id=va.articledetailsID WHERE ad.ordernumber="'.$orderDetail->ForeignId.'"');
                                } else {
                                    $articleID = Shopware()->Db()->fetchOne('SELECT articleID FROM swp_viaebay_articles WHERE swp_viaebay_id='.$orderDetail->ProductId);
                                }
                                

				$sOrderDetails = array(
					'orderID' => $orderID,
					'ordernumber' => Shopware()->Db()->fetchOne('SELECT ordernumber FROM s_order WHERE id='.$orderID),
                                        'articleID' => $articleID,
					'articleordernumber' => $articleordernumber,
					'price' => $articlePrice,
					'quantity' => $orderDetail->Amount,
					'name' => $name,
					'releasedate' => '0000-00-00',
					'modus' => '0',
					'esdarticle' => '0',
					'taxID' => $taxID,
					'tax_rate' => $tax_rate
				);

				Shopware()->Db()->insert('s_order_details', $sOrderDetails);

				$detailID = Shopware()->Db()->lastInsertId();

				$sOrderDetailsAttributes = array(
					'detailID' => $detailID,
					'swp_viaebay_id' => $orderDetail->Id
				);

				Shopware()->Db()->insert('s_order_details_attributes', $sOrderDetailsAttributes);

				if($orderDetail->ProductVariationId) {
                                        
                                        $stock = Shopware()->Db()->fetchOne('SELECT ad.instock FROM s_articles_details AS ad INNER JOIN swp_viaebay_articles AS va ON ad.id=va.articledetailsID WHERE va.swp_viaebay_id="'.$orderDetail->ProductVariationId.'"');

					if($stock !== false && $stock != '') {
						$newStock = (int)$stock - (int)$orderDetail->Amount;

                                                
                                                Shopware()->Db()->exec('UPDATE s_articles_details AS ad INNER JOIN swp_viaebay_articles AS va ON ad.id=va.articledetailsID SET ad.instock='.$newStock.' WHERE va.swp_viaebay_id="'.$orderDetail->ProductVariationId.'"');
					}

					if($newStock < 0 || !isset($newStock)) $newStock = 0;
                                       
					if($newStock !== false && $newStock !== '') {
					
                                            $newStock = self::checkAbverkaufForOrderProduct($newStock, $orderDetail->ProductVariationId);
                            
                                            $VIAeBay->updateStockAmount($orderDetail->ProductVariationId, $newStock, 'variation');
                                        }
				} elseif($orderDetail->ForeignId) {
					$stock = Shopware()->Db()->fetchOne('SELECT instock FROM s_articles_details WHERE ordernumber="'.$orderDetail->ForeignId.'"');

					if($stock !== false && $stock != '') {
						$newStock = (int)$stock - (int)$orderDetail->Amount;

						Shopware()->Db()->exec('UPDATE s_articles_details SET instock='.$newStock.' WHERE ordernumber="'.$orderDetail->ForeignId.'"');
					}

                                        
                                        $articleRessourceID = Shopware()->Db()->fetchOne('SELECT va.swp_viaebay_id FROM swp_viaebay_articles AS va INNER JOIN s_articles_details AS ad ON va.articledetailsID=ad.id WHERE ad.ordernumber="'.$orderDetail->ForeignId.'"');
                                        

					if($newStock < 0 || !isset($newStock)) $newStock = 0;
                                        
					if($articleRessourceID && $newStock !== false && $newStock !== '') {
                                            
                                            $newStock = self::checkAbverkaufForOrderProduct($newStock, $articleRessourceID);
                                            
                                            $VIAeBay->updateStockAmount($articleRessourceID, $newStock, 'default');
                                        }
				}
			}
		}
                
		/**
		 * map VIA eBay payment to shop payment
		 * @param String $paymentCode Payment Code from VIA eBay
		 * @return Boolean/Int False on error or paymentID from Shopware
		 */
		protected static function getShopPaymentID($paymentCode) {
                    
			switch($paymentCode) {
				case 'CashOnPickup':
					$paymentName = 'Bar bei Abholung';

					break;
				case 'COD':
					$paymentName = 'Nachnahme';

					break;
				case 'MoneyXferAccepted':
				case 'MoneyXferAcceptedInCheckout':
					$paymentName = 'Vorkasse';

					break;
				case 'Paypal':
				case 'PayPal':
					$paymentName = 'PayPal';

					break;
				default:
					//return false;
                                        $paymentName = 'Vorkasse';
			}

			//$paymentID = Shopware()->Db()->fetchOne('SELECT id FROM s_core_paymentmeans WHERE description="'.$paymentName.'"');
                        //$paymentID = Shopware()->Db()->fetchOne('SELECT id FROM s_core_paymentmeans WHERE description="'.$paymentName.'" OR description=LOWER("'.$paymentName.'") OR description=UPPER("'.$paymentName.'")');
                        //$paymentID = Shopware()->Db()->fetchOne('SELECT id FROM s_core_paymentmeans WHERE description="'.$paymentName.'" OR description=LOWER("'.$paymentName.'") OR description=UPPER("'.$paymentName.'")');
                        $paymentID = Shopware()->Db()->fetchOne('SELECT id FROM s_core_paymentmeans WHERE (description="'.$paymentName.'" OR description=LOWER("'.$paymentName.'") OR description=UPPER("'.$paymentName.'")) OR (name="'.$paymentName.'" OR name=LOWER("'.$paymentName.'") OR name=UPPER("'.$paymentName.'"))');
                        
			if($paymentID)
				return $paymentID;
			else
				return false;
		}
                
                /**
		 * map VIA eBay payment to config for payment complete status
		 * @param String $paymentCode Payment Code from VIA eBay
		 * @return Boolean/Int False on error or config for payment complete status
		 */
		protected static function getPaymentOptionPaymentCompleteConfig($paymentCode) {
                    
			switch($paymentCode) {
				case 'CashOnPickup':
					$configName = 'paymentcashcompletestatus';

					break;
				case 'COD':
					$configName = 'paymentcodcompletestatus';

					break;
				case 'MoneyXferAccepted':
				case 'MoneyXferAcceptedInCheckout':
					$configName = 'paymentmoneyxcompletestatus';

					break;
				case 'Paypal':
				case 'PayPal':
					$configName = 'paymentpaypalcompletestatus';

					break;
				default:
                                        $configName = 'paymentcompletestatus';
			}

			return $configName;
		}
                
                /**
		 * map VIA eBay shipping to shop shipping
                 * 
                 * plan.io Ticket 1827 - Methode enthaelt Anpassungen zur Umsetzung des Tickets
                 * 
		 * @param String $shippingCode Shipping Code from VIA eBay
		 * @return Boolean/Int False on error or shippingID from Shopware
		 */
		protected static function getShopShippingID($shippingCode) {
                  
                    $config = Shopware()->Plugins()->Backend()->viaebay()->Config();
                    
                    if(preg_match('/eBayPlus/', $shippingCode))
                    {
        		$shippingID = Shopware()->Db()->fetchOne('SELECT id FROM s_premium_dispatch WHERE name="eBayPLUS"');
                    }
                    else if(preg_match('/International/', $shippingCode) || preg_match('/Intl/', $shippingCode))
                    {
                        $shippingID = $config->shipping_international;
                    }
                    else
                    {
                        $shippingID = $config->shipping_de;
                    }
                    
                        
                    if($shippingID)
                        return $shippingID;
                    else
                        return false;
		}

		/**
		 * get the correct salutation for Shopware
		 * @param String $salutation Salutation from VIA eBay
		 * @return String Salutaion for Shopware
		 */
		protected static function getSalutation($salutation) {
			switch($salutation) {
				case 'Firma':
					return 'company';
					break;
				case 'Herr':
					return 'mr';
					break;
				case 'Frau':
					return 'ms';
					break;
				default:
					return 'mr';
					break;
			}
		}

		/**
		 * split the full Street in Street and Housenumber
		 * @param Object $obj Object to modify to split the Street and Housenumber
		 * @param String $street the full Street
		 */
		protected static function splitStreetAndHouseNo(&$obj, $street) {
			if(preg_match ('/(.*)(\d+)$/U', $street, $m)) {
				$obj->Street = $m[1];
				$obj->HouseNo = $m[2];
			} elseif (preg_match ('/(.*)\s+(\S+)$/', $street, $m)) {
				$obj->Street = $m[1];
				$obj->HouseNo = $m[2];
			} else {
				$obj->Street = $street;
				$obj->HouseNo = '1';
			}

			$obj->Street = trim($obj->Street);
			$obj->HouseNo = trim($obj->HouseNo);
		}

		/**
		 * get the Country ID from Shopware
		 * @param String $country ISO Code for Country
		 * @return Int ID for the Country
		 */
		protected static function getCounzryID($country) {
			return Shopware()->Db()->fetchOne('SELECT id FROM s_core_countries WHERE countryiso="'.$country.'"');
		}
                
                /**
		 * get the Country data from Shopware
		 * @param String $country ISO Code for Country
		 * @return array data for the Country
		 */
		protected static function getCounzryData($country) {
			return Shopware()->Db()->fetchRow('SELECT * FROM s_core_countries WHERE countryiso="'.$country.'"');
		}
                
                /**
		 * get the Country tax rule from Shopware
		 * @param Int $countryID Id for Country
                 * @param Int $taxID Id for tax
		 * @return array tax rule for country
		 */
		protected static function getCounzryTaxRule($countryID, $taxID) {
			return Shopware()->Db()->fetchRow('SELECT * FROM s_core_tax_rules WHERE countryID="'.$countryID.'" AND groupID="'.$taxID.'"');
		}

		/**
		 * get the State ID from Shopware
		 * @param Int $countryID Coubtry ID
		 * @param String $state shortcode for state
		 * @return Int ID for the State
		 */
		protected static function getStateID($countryID, $state) {
			return Shopware()->Db()->fetchOne('SELECT id FROM s_core_countries_states WHERE countryID='.$countryID.' AND shortcode="'.$state.'"');
		}

		/**
		 * get the Tax and the net Price for the Article
		 * @param String $foreignId Shopware ordernumber for the Article
		 * @param Double $price
		 * @return Object with Tax and net Price for this Article
		 */
		protected static function getArticleTax($foreignId) {
			if($foreignId) {
				$taxID = Shopware()->Db()->fetchOne('SELECT a.taxID FROM s_articles AS a INNER JOIN s_articles_details AS ad ON a.id = ad.articleID  WHERE ad.ordernumber="'.$foreignId.'"');

				if($taxID === false)
					return '19';
				else
					return Shopware()->Db()->fetchOne('SELECT tax FROM s_core_tax WHERE id='.$taxID);
			} else
				return '19';
		}
                
                /**
		 * get the Tax ID for the Article
		 * @param String $foreignId Shopware ordernumber for the Article
		 * @param Double $price
		 * @return Object with Tax and net Price for this Article
		 */
		protected static function getArticleTaxID($foreignId) {
			if($foreignId) {
				$taxID = Shopware()->Db()->fetchOne('SELECT a.taxID FROM s_articles AS a INNER JOIN s_articles_details AS ad ON a.id = ad.articleID  WHERE ad.ordernumber="'.$foreignId.'"');

				if($taxID != false)
					return $taxID;
                        }
                        
                        return Shopware()->Db()->fetchOne('SELECT id FROM s_core_tax WHERE tax="19"');
		}

		/**
		 * update the order status from VIA eBay to Shopware
		 * @param Object $order Order from VIA eBay
		 * @param Int $orderStatus Shopware order status configured in Plugin
		 * @param Int $paymentStatus Shopware payment status configured in Plugin
		 */
		protected static function updateOrderStatus($order, $orderStatus, $paymentStatus) {
			date_default_timezone_set('Europe/Berlin');

			$sOrder = array();

			$orderID = Shopware()->Db()->fetchOne('SELECT orderID FROM s_order_attributes WHERE swp_viaebay_id='.$order->Id);

			if(!$orderID) return;

			if(!$order->MarkedAsShipped && !$order->MarkedAsPayed && !$order->PaidDate) return;

			if($order->MarkedAsShipped && $orderStatus)
				$sOrder['status'] = $orderStatus;

			if($order->MarkedAsPayed && $paymentStatus)
				$sOrder['cleared'] = $paymentStatus;

			if($order->PaidDate)
				$sOrder['cleareddate'] = date('Y-m-d H:i:s', preg_replace('/[^\d]/','', $order->PaidDate)/1000);

			Shopware()->Db()->update ('s_order', $sOrder, 'id='.$orderID);
                                              
                        
		}

		#########################
		### Import Orders END ###
		#########################

		####################
		### Others START ###
		####################
                
                protected static function checkAbverkaufForOrderProduct($old_stock, $swp_viaebay_id) {
                    
                    $laststock = Shopware()->Db()->fetchOne('SELECT laststock FROM s_articles WHERE id = (SELECT ad.id FROM swp_viaebay_articles AS va INNER JOIN s_articles_details AS ad ON va.articledetailsID=ad.id WHERE va.swp_viaebay_id="'.$swp_viaebay_id.'")');
                                
                    if ($laststock) {
                        
                        $config = Shopware()->Plugins()->Backend()->viaebay()->Config();

                        //if($config->sale_actice == true && (int)$laststock < (int)0) {
                        if($config->sale_actice == true && (int)$laststock == (int)0) {
                            
                            if((int)$old_stock <= (int)0) {
                                return (int)$config->default_stock_amount;
                            }
                        }                        
                    }
                                    
                    return $old_stock;
                }

		/**
		 * update the stock amount for the product in VIA eBay after a order was submitted in Shopware
		 * @param Array $order Shopware Order
		 */
		public function updateStockAmountAfterOrder($order) {
			try {
				$VIAeBay = new VIAeBay();
			} catch (Exception $e) {
				return;
			}

			foreach($order['sBasket']['content'] as $product) {
                                
                                $articleRessourceID = Shopware()->Db()->fetchOne('SELECT va.swp_viaebay_id FROM swp_viaebay_articles AS va INNER JOIN s_articles_details AS ad ON ad.id=va.articledetailsID WHERE ad.ordernumber="'.$product['ordernumber'].'"');
                                
                                if(Shopware()->Db()->fetchOne('SELECT va.swp_viaebay_container_id FROM swp_viaebay_articles AS va INNER JOIN s_articles_details AS ad ON ad.articleID=va.articleID WHERE ad.ordernumber="'.$product['ordernumber'].'" AND va.swp_viaebay_container_id IS NOT NULL'))
					$type = 'variation';
				else
					$type = 'default';

				if($articleRessourceID) {
					$stock = Shopware()->Db()->fetchOne('SELECT instock FROM s_articles_details WHERE ordernumber="'.$product['ordernumber'].'"');

					if($stock !== false) {
                                                         
                                            $stock = self::checkAbverkaufForOrderProduct($stock, $articleRessourceID);
                                            
                                            if($stock < 0 || !isset($stock)) $stock = 0;
                                            
                                            $VIAeBay->updateStockAmount($articleRessourceID, $stock, $type);
                                        }
				}
			}
		}

		/**
		 * update the order tracking number Shopware to VIA eBay
		 * @param Mixed $request Request variable from Shopware
		 */
		public static function updateVIAeBayTrackingCode($request) {
			$config = Shopware()->Plugins()->Backend()->viaebay()->Config();

			$id = $request->getParam('id');
			$trackingCode = $request->getParam('trackingCode');

			if(!$id || !$trackingCode) return;

			$orderdetailsVIAeBayOrderID = Shopware()->Db()->fetchRow('SELECT oda.swp_viaebay_id, oa.swp_viaebay_carrier_used FROM s_order_details_attributes AS oda INNER JOIN s_order_details AS od ON od.id=oda.detailID INNER JOIN s_order_attributes oa ON oa.orderID=od.orderID WHERE od.orderID='.$id);

			if(!is_array($orderdetailsVIAeBayOrderID) || count($orderdetailsVIAeBayOrderID) == 0) return;

                        if(isset($orderdetailsVIAeBayOrderID['swp_viaebay_id']) && $orderdetailsVIAeBayOrderID['swp_viaebay_id'] != '' && $orderdetailsVIAeBayOrderID['swp_viaebay_id'] != 0) {
                            
                            $VIAeBay = new VIAeBay();

                            $VIAeBay->updateOrderTrackingCode(array($orderdetailsVIAeBayOrderID), $trackingCode);
                            
                        }
		}

		/**
		 * update the order status from Shopware to VIA eBay
		 * @param Mixed $request Request variable from Shopware
		 */
		public static function updateVIAeBayOrderStatus($request) {
			$config = Shopware()->Plugins()->Backend()->viaebay()->Config();

			$id = $request->getParam('id');

			if(!$id) return;

			$VIAeBayOrderID = Shopware()->Db()->fetchOne('SELECT swp_viaebay_id FROM s_order_attributes WHERE orderID='.$id);

			if(!$VIAeBayOrderID) return;

			$VIAeBay = new VIAeBay();

			$repository = Shopware()->Models()->getRepository('Shopware\Models\Order\Order');
			$order = $repository->find($id);

			$statusBefore  = $order->getOrderStatus();
                        $clearedBefore = $order->getPaymentStatus();

			if($request->getParam('status') !== $statusBefore->getId() && $request->getParam('status') == $config->shippingcompletestatus) {
				$VIAeBay->updateOrderShippingStatus($VIAeBayOrderID);
			}

                        
                        $VIAeBayPaymentOption = Shopware()->Db()->fetchOne('SELECT swp_viaebay_payment_option FROM s_order_attributes WHERE orderID='.$id);
			if(!$VIAeBayPaymentOption) $VIAeBayPaymentOption = '-';

                        $paymentcompletestatus_config = self::getPaymentOptionPaymentCompleteConfig($VIAeBayPaymentOption);

			if($request->getParam('cleared') !== $clearedBefore->getId() && $request->getParam('cleared') == $config->$paymentcompletestatus_config) {
				$amount = Shopware()->Db()->fetchOne('SELECT invoice_amount FROM s_order WHERE id='.$id);
                                
				$VIAeBay->updateOrderPaidStatus($VIAeBayOrderID, $amount);
			}
		}

		/**
		 * update the order status from Shopware to VIA eBay (in batch processing)
		 */
		public function updateVIAeBayOrderStatusInBatchProcessing($request) {
			$VIAeBay = new VIAeBay();

			$config = Shopware()->Plugins()->Backend()->viaebay()->Config();

			$orders = $request->getParam('orders', array(0 => $request->getParams()));

			foreach($orders as $key => $data) {
				if(empty($data) || empty($data['id'])) continue;

				$VIAeBayOrderID = Shopware()->Db()->fetchOne('SELECT swp_viaebay_id FROM s_order_attributes WHERE orderID='.$data['id']);

				if(!$VIAeBayOrderID) continue;

				$repository = Shopware()->Models()->getRepository('Shopware\Models\Order\Order');
				$order = $repository->find($data['id']);

				$statusBefore = $order->getOrderStatus();
				$clearedBefore = $order->getPaymentStatus();

				if($data['status'] !== $statusBefore->getId() && $data['status'] == $config->shippingcompletestatus) {
					$VIAeBay->updateOrderShippingStatus($VIAeBayOrderID);
				}

                                
                                $VIAeBayPaymentOption = Shopware()->Db()->fetchOne('SELECT swp_viaebay_payment_option FROM s_order_attributes WHERE orderID='.$data['id']);
                                if(!$VIAeBayPaymentOption) $VIAeBayPaymentOption = '-';
                        
                                $paymentcompletestatus_config = self::getPaymentOptionPaymentCompleteConfig($VIAeBayPaymentOption);
                                
				if($data['cleared'] !== $clearedBefore->getId() && $data['cleared'] == $config->$paymentcompletestatus_config) {
					$amount = Shopware()->Db()->fetchOne('SELECT invoice_amount FROM s_order WHERE id='.$data['id']);
                                        
					$VIAeBay->updateOrderPaidStatus($VIAeBayOrderID, $amount);
				}
			}
		}
                
                /**
		 * update the order status and the order tracking number from Shopware to VIA eBay (by model events)
		 */
		public function updateVIAeBayOrderByModelEvents($orderID = false) {
			$VIAeBay = new VIAeBay();

			$config = Shopware()->Plugins()->Backend()->viaebay()->Config();

                        
                        if($orderID === false || empty($orderID)) return false;

			$VIAeBayOrderID = Shopware()->Db()->fetchOne('SELECT swp_viaebay_id FROM s_order_attributes WHERE orderID='.$orderID);

			if(!$VIAeBayOrderID) return false;
                        
                        
                        $repository = Shopware()->Models()->getRepository('Shopware\Models\Order\Order');
			$order = $repository->find($orderID);

                        
                        $trackingCode = $order->getTrackingCode();
                        if (isset($trackingCode) && $trackingCode != '') {
                            
                            $orderdetailsVIAeBayOrderID = Shopware()->Db()->fetchRow('SELECT oda.swp_viaebay_id, oa.swp_viaebay_carrier_used FROM s_order_details_attributes AS oda INNER JOIN s_order_details AS od ON od.id=oda.detailID INNER JOIN s_order_attributes oa ON oa.orderID=od.orderID WHERE od.orderID='.$orderID);

                            if(is_array($orderdetailsVIAeBayOrderID) && count($orderdetailsVIAeBayOrderID) > 0) {

                                if(isset($orderdetailsVIAeBayOrderID['swp_viaebay_id']) && $orderdetailsVIAeBayOrderID['swp_viaebay_id'] != '' && $orderdetailsVIAeBayOrderID['swp_viaebay_id'] != 0) {
                            
                                    $VIAeBay = new VIAeBay();

                                    $VIAeBay->updateOrderTrackingCode(array($orderdetailsVIAeBayOrderID), $trackingCode);
                            
                                }
                            }
                        }
                        

			$status = $order->getOrderStatus();
			$cleared = $order->getPaymentStatus();
                        
			if($status->getId() == $config->shippingcompletestatus) {
				$VIAeBay->updateOrderShippingStatus($VIAeBayOrderID);
			}

                        
                        $VIAeBayPaymentOption = Shopware()->Db()->fetchOne('SELECT swp_viaebay_payment_option FROM s_order_attributes WHERE orderID='.$orderID);
			if(!$VIAeBayPaymentOption) $VIAeBayPaymentOption = '-';

                        $paymentcompletestatus_config = self::getPaymentOptionPaymentCompleteConfig($VIAeBayPaymentOption);
                        
			if($cleared->getId() == $config->$paymentcompletestatus_config) {
				$amount = Shopware()->Db()->fetchOne('SELECT invoice_amount FROM s_order WHERE id='.$orderID);
                                
				$VIAeBay->updateOrderPaidStatus($VIAeBayOrderID, $amount);
                        }
		}
                
                
                /**
		 * update the order status and the order tracking number from Shopware to VIA eBay (by cron)
		 */
		public function updateVIAeBayOrderData()
                {
                    $VIAeBay = new VIAeBay();

                    $config = Shopware()->Plugins()->Backend()->viaebay()->Config();

                    $days = ($config->daysfororderscronjob > 0) ? $config->daysfororderscronjob : 3;

                    //$_orders = Shopware()->Db()->fetchAll('SELECT id FROM s_order WHERE ordertime < DATE_ADD(NOW(), INTERVAL - ' . (int)$days . ' DAY) OR cleareddate < DATE_ADD(NOW(), INTERVAL - ' . (int)$days . ' DAY)');
                    $_orders = Shopware()->Db()->fetchAll('SELECT id FROM s_order WHERE (ordertime BETWEEN DATE_ADD(NOW(), INTERVAL - ' . (int)$days . ' DAY) AND NOW()) OR (cleareddate BETWEEN DATE_ADD(NOW(), INTERVAL - ' . (int)$days . ' DAY) AND NOW())');

                    if(!is_array($_orders) || count($_orders) == 0) return;

                    foreach($_orders as $key => $val)
                    {
                        self::updateVIAeBayOrderByModelEvents($val['id']);
                    }
		}
                
                
                /**
		 * update the order status and the order tracking number from Shopware to VIA eBay (by external cron)
		 */
                public function cronUpdateVIAeBayOrderDataAction()
                {
                    $config = Shopware()->Plugins()->Backend()->viaebay()->Config();
                    
                    $cronPassword = $this->Request()->getParam('pass');
                    
                    $offset = $this->Request()->getParam('offset', 0);
                    $limit = ($config->cronjoblimitorders != '') ? $config->cronjoblimitorders : 50; 
                    
                    if($config->cronjobpass === $cronPassword)
                    {
                        $VIAeBay = new VIAeBay();

                        $config = Shopware()->Plugins()->Backend()->viaebay()->Config();

                        $days = ($config->daysfororderscronjob > 0) ? $config->daysfororderscronjob : 3;

                        $_orders = Shopware()->Db()->fetchAll('SELECT id FROM s_order WHERE (ordertime BETWEEN DATE_ADD(NOW(), INTERVAL - ' . (int)$days . ' DAY) AND NOW()) OR (cleareddate BETWEEN DATE_ADD(NOW(), INTERVAL - ' . (int)$days . ' DAY) AND NOW()) ORDER BY id ASC LIMIT '.$offset.', '.$limit);

                        if(!is_array($_orders) || count($_orders) == 0)
                        {
                            header('HTTP/1.1 200 OK');
                            exit(0);
                            return;
                        }

                        foreach($_orders as $key => $val)
                        {
                            self::updateVIAeBayOrderByModelEvents($val['id']);
                        }
                        
                        
                        $url_array = (array('sViewport' => 'viaebay', 'action' => 'cronUpdateVIAeBayOrderData', 'offset' => ($offset+$limit), 'pass' => $cronPassword));
                        $url = Shopware()->Front()->Router()->assemble($url_array);
                        header('Location: '.$url);
                        exit(0);
                    }
                    else
                    {
                        die('Permission denied');
                    }
                }
                
                                

		/**
		 * delete the category and the subcategories in VIA-eBay
		 */
		public function deleteCategoriesStructureInVIAeBay($categoryID) {
			$repository = Shopware()->Models()->getRepository('Shopware\Models\Shop\Shop');
			$shop = $repository->getActiveById(Shopware()->Db()->fetchOne('SELECT id FROM s_core_shops WHERE main_id IS NULL'));
			$shop->registerResources(Shopware()->Bootstrap());

                        
                        if(!$mainCategoryVIAeBayID = Shopware()->Db()->fetchOne('SELECT swp_viaebay_id FROM swp_viaebay_categories WHERE categoryID='.$categoryID)) return false;
                        
                        
			$VIAeBayIDs = array_reverse(self::getCategoryTreeVIAeBayIDs(Shopware()->Modules()->Categories()->sGetWholeCategoryTree($categoryID), array($categoryID => $mainCategoryVIAeBayID)));

			if(is_array($VIAeBayIDs) && count($VIAeBayIDs) > 0) {
				$VIAeBay = new VIAeBay();

				foreach($VIAeBayIDs as $VIAeBayID) {
					$VIAeBay->deleteCatalogs($VIAeBayID);
                                        
                                        Shopware()->Db()->exec('UPDATE swp_viaebay_categories SET swp_viaebay_id=NULL WHERE swp_viaebay_id='.$VIAeBayID);
				}
			}
		}

		/**
		 * build the VIA-eBay IDs cat path from an cat tree
		 */
		protected function getCategoryTreeVIAeBayIDs($categoryTree, $VIAeBayIDs = array()) {
			foreach($categoryTree as $categoryTreeItem) {
				if($categoryTreeItem['attribute']['swpViaebayId']) {
					$VIAeBayIDs[] = $categoryTreeItem['attribute']['swpViaebayId'];

					if(is_array($categoryTreeItem['sub']) && count($categoryTreeItem['sub']) > 0)
						$VIAeBayIDs = self::getCategoryTreeVIAeBayIDs($categoryTreeItem['sub'], $VIAeBayIDs);
				}
			}

			return $VIAeBayIDs;
		}

		/**
		 * test the login data in the plugin config
		 */
		public function checkLoginAction() {
			try {
				$result1 = $VIAeBay = new VIAeBay();
				$result2 = $VIAeBay->getSalesOrders();

				$result = ($result1 && $result2);

				if($result)
					$this->View()->assign(array('success' => 'true'));
				else
					$this->View()->assign(array('success' => 'false'));
			} catch(Exception $e) {
				$this->View()->assign(array('success' => 'false'));
			}
		}

		/**
		 * check if the via ebay api occurs any errors while the runtime
		 */
		protected function checkApiError($VIAeBay) {
			return $VIAeBay->checkApiError();
		}

		protected function resetApiError($VIAeBay) {
			$VIAeBay->resetApiError();
		}
                
                
                /**
		 * check if the via ebay api occurs any errors while the runtime
		 */
                public static function keepCronjobActive($cronjob_name, $cronjob_status_message = false) {
                    
                    try {
                        
                        /** @var $cronManager Enlight_Components_Cron_Manager */
                        $cronManager = Shopware()->Cron();

                        $job = $cronManager->getAdapter()->getJobByName($cronjob_name);

                        
                        $job->setActive(true);
                        $cronManager->getAdapter()->updateJob($job);
                        
                        $job->setInterval(7200); // 2 stunden
                        //$job->setInterval(120); // 2 minuten
                        $cronManager->getAdapter()->updateJob($job);
                        
                        if ($cronjob_status_message !== false) {
                            
                            
                            $job->setData($cronjob_status_message);
                            $cronManager->getAdapter()->updateJob($job);
                            
                            $now = new Zend_Date();
                            $now = $now->getTimestamp();
                            $interval =  $job->getInterval();
                            $next = $job->getNext()->getTimestamp();

                            do {
                                $next += $interval;
                            } while ($now >= $next);
                            $job->setNext($next);
                            $job->setEnd($now);
                            $cronManager->getAdapter()->updateJob($job);
                        }
                    
                    } catch (Exception $ex) {
                        
                    }
                }
                
                
                /*
                 * 
                 * Da jwejeilige Mapping ist in Doku zu finden unter:
                 * http://bbox-wiki.dus.via.de/bin/view/REST-Api/SalesOrders
                 * Die ShippingService spiegeln die eBay Versandartenbezeichnung wieder.
                 * 
                 */
                public static function getShippingServiceToVersandartBezeichnung($ShippingService) {
                    
                    switch($ShippingService)
                    {
                        case "DE_DeutschePostBrief":
                            return "Deutsche Post Brief";
                            break;
                        
                        case "DE_DHLPackchen":
                            return "DHL Päckchen";
                            break;
                        
                        case "DE_Paket":
                            return "Paketversand";
                            break;
                        
                        case "DE_Express":
                            return "Expressversand";
                            break;
                        
                        case "DE_DHLPaket":
                            return "DHL Paket";
                            break;
                        
                        case "DE_DPBuecherWarensendung":
                            return "Deutsche Post Bücher-/Warensendung";
                            break;
                        
                        case "DE_HermesPaket":
                            return "Hermes Paket";
                            break;
                        
                        case "DE_IloxxTransport";
                            return "iloxx Transport";
                            break;
                        
                        case "DE_SonstigeDomestic":
                            return "Sonstige 1-2 Werktage";
                            break;
                        
                        case "DE_Einschreiben":
                            return "Einschreiben (inkl. aller Gebühren)";
                            break;
                        
                        case "DE_Nachname":
                            return "Nachnahme (inkl. aller Gebühren)";
                            break;
                        
                        case "DE_SpecialDelivery":
                            return "Sonderversand";
                            break;
                        
                        case "DE_SparversandAusDemAusland":
                            return "Sparversand aus dem Ausland";
                            break;
                        
                        case "DE_StandardversandAusDemAusland":
                            return "Standardversand aus dem Ausland";
                            break;
                        
                        case "DE_ExpressversandAusDemAusland":
                            return "Expressversand aus dem Ausland";
                            break;
                        
                        case "DE_DPDExpress":
                            return "DPD Express";
                            break;
                        
                        case "DE_UPSExpress":
                            return "UPS Express";
                            break;
                        
                        case "DE_GLSPaket":
                            return "GLS Paket";
                            break;
                        
                        case "DE_EbayHermesPaketShop2Shop":
                            return "eBay Hermes Paket Shop2Shop";
                            break;
                        
                        case "DE_eBayHermesPaketSperrgutShop2Shop":
                            return "eBay Hermes Paket Sperrgut Shop2Shop (Abgabe und Zustellung im Paketshop)";
                            break;
                        
                        case "DE_HermesPaketSperrgut":
                            return "Hermes Paket Sperrgut";
                            break;
                        
                        case "DE_DPDClassic":
                            return "DPD Classic";
                            break;
                        
                        case "DE_UPSStandard":
                            return "UPS Standard";
                            break;
                        
                        case "DE_DeutschePostBriefInternational":
                            return "Deutsche Post Brief";
                            break;
                        
                        case "DE_DHLPackchenInternational":
                            return "DHL Päckchen International";
                            break;
                        
                        case "DE_PaketInternational":
                            return "Standard Int'l Versand";
                            break;
                        
                        case "DE_ExpressInternational":
                            return "Express Int'l Versand";
                            break;
                        
                        case "DE_DHLPaketInternational":
                            return "DHL Paket International";
                            break;
                        
                        case "DE_IloxxTransportInternational":
                            return "iloxx Transport International";
                            break;
                        
                        case "DE_SonstigeInternational":
                            return "Economy Int'l Versand";
                            break;
                        
                        case "DE_HermesPaketInternational":
                            return "Hermes Paket International";
                            break;
                        
                        case "DE_DeutschePostBriefIntlEcon":
                            return "Deutsche Post Presse und Bücher Economy";
                            break;
                        
                        case "DE_DeutschePostBriefIntlPri":
                            return "Deutsche Post Presse und Bücher Priority";
                            break;
                        
                        case "PromotionalShippingMethod":
                            return "Versand zum Sonderpreis";
                            break;
                        
                        default:
                            return $ShippingService;
                            break;
                    }
                    
                    
                    return $ShippingService;
                }
                

		##################
		### Others End ###
		##################
	}
?>
