<?php

namespace Shopware\CustomModels\viaebay;
 
use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Validator\Constraints as Assert;
use Doctrine\Common\Collections\ArrayCollection;
use Shopware\Components\Model\ModelEntity;
 
/**
 * Shopware VIAeBay Plugin - SwpViaebayArticles Model
 * @ORM\Entity
 * @ORM\Table(name="swp_viaebay_articles")
 */
class SwpViaebayArticles extends ModelEntity {
    
    /****************************************************************
     *                           Columns                            *
     ****************************************************************/
    
    /**
     * Unique identifier
     * @var integer
     * @ORM\Column(name="id", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    protected $id;
    
    /**
     * Contains the articleID of the product
     * @var integer  
     * @ORM\Column(name="articleID", type="integer", nullable=true)
     */  
    protected $articleID;    
    
    /**
     * Contains the articledetailsID of the product
     * @var integer
     * @ORM\Column("articledetailsID", type="integer", nullable=true)
     */
    protected $articledetailsID;
    
    /**
     * Contains the VIA-eBay Container ID of the product
     * @var integer  
     * @ORM\Column(name="swp_viaebay_container_id", type="integer", nullable=true)
     */  
    protected $swp_viaebay_container_id;
    
    /**
     * Contains the VIA-eBay ID of the product
     * @var integer  
     * @ORM\Column(name="swp_viaebay_id", type="integer", nullable=true)
     */  
    protected $swp_viaebay_id;
    
    /**
     * Contains the Best Offer Auto Accept Price of the product
     * @var float
     * @ORM\Column(name="best_offer_auto_accept_price", type="decimal", precision=15, scale=4, nullable=true)
     */
    protected $best_offer_auto_accept_price;
    
    /**
     * Contains the Best Offer Minimum Price of the product
     * @var float
     * @ORM\Column(name="best_offer_minimum_price", type="decimal", precision=15, scale=4, nullable=true)
     */
    protected $best_offer_minimum_price;
    
    
    /****************************************************************
     *                  Property Getter & Setter                    *
     ****************************************************************/
    
    /**
     * Getter function for the unique id identifier property
     * @return integer
     */    
    public function getId()
    {
        return $this->id;
    }
    
    /**
     * Setter function for the articleID column property.
     * @param  integer         $articleID
     * @return 
     */
    public function setarticleID($articleID)
    {
        $this->articleID = $articleID;
        return $this;
    }
 
    /**
     * Getter function for the articleID column property.
     * @return string
     */
    public function getarticleID()
    {
        return $this->articleID;
    } 
    
    /**
     * Setter function for the articledetailsID column property.
     * @param  integer         $articledetailsID
     * @return 
     */
    public function setarticledetailsID($articledetailsID)
    {
        $this->articledetailsID = $articledetailsID;
        return $this;
    }
 
    /**
     * Getter function for the articledetailsID column property.
     * @return string
     */
    public function getarticledetailsID()
    {
        return $this->articledetailsID;
    }
    
    /**
     * Setter function for the swp_viaebay_container_id column property.
     * @param  integer         $swp_viaebay_container_id
     * @return 
     */
    public function setOptionID($swp_viaebay_container_id)
    {
        $this->swp_viaebay_container_id = $swp_viaebay_container_id;
        return $this;
    }
 
    /**
     * Getter function for the swp_viaebay_container_id column property.
     * @return string
     */
    public function getswp_viaebay_container_id()
    {
        return $this->swp_viaebay_container_id;
    }
    
    /**
     * Setter function for the swp_viaebay_id column property.
     * @param  integer         $swp_viaebay_id
     * @return 
     */
    public function setswp_viaebay_id($swp_viaebay_id)
    {
        $this->swp_viaebay_id = $swp_viaebay_id;
        return $this;
    }
 
    /**
     * Getter function for the swp_viaebay_id column property.
     * @return string
     */
    public function getswp_viaebay_id()
    {
        return $this->swp_viaebay_id;
    }    
    
    /**
     * Setter function for the best_offer_auto_accept_price column property.
     * @param  decimal         $best_offer_auto_accept_price
     * @return 
     */
    public function setbest_offer_auto_accept_price($best_offer_auto_accept_price)
    {
        $this->best_offer_auto_accept_price = $best_offer_auto_accept_price;
        return $this;
    }
 
    /**
     * Getter function for the best_offer_auto_accept_price column property.
     * @return decimal
     */
    public function getbest_offer_auto_accept_price()
    {
        return $this->best_offer_auto_accept_price;
    }
    
    /**
     * Setter function for the best_offer_minimum_price column property.
     * @param  decimal         $best_offer_minimum_price
     * @return 
     */
    public function setbest_offer_minimum_price($best_offer_minimum_price)
    {
        $this->best_offer_minimum_price = $best_offer_minimum_price;
        return $this;
    }
 
    /**
     * Getter function for the best_offer_minimum_price column property.
     * @return decimal
     */
    public function getbest_offer_minimum_price()
    {
        return $this->best_offer_minimum_price;
    }
    
    
    /****************************************************************
     *                  construct ArrayCollection                   *
     ****************************************************************/        
    
}
?>
